DROP TABLE TMP_PEDIDOCOLETA
/

CREATE GLOBAL TEMPORARY TABLE TMP_PEDIDOCOLETA (
    NRPEDIDOCOLETA NUMBER,
    NRPEDCOL       NUMBER,
    CDREGIAO       VARCHAR2(03), 
    CDOPERADOR     VARCHAR2(12), 
    CDFORNECED     VARCHAR2(21),  
    CDPRODUTO      VARCHAR2(10), 
    CDMARCA        VARCHAR2(05), 
    CDMARCAPADR    VARCHAR2(05), 
    QTACOMPRAR     FLOAT(126),
    NRCOLEPRECO    VARCHAR2(10),
    NRSEQPRELIST   VARCHAR2(10),
    CDLEILAO       VARCHAR2(10),
    CDOPERLANC     VARCHAR2(12),
    CDFILIAL       VARCHAR2(4),
    NRCOMPRA       VARCHAR2(10),
    CDPRODINI      VARCHAR2(20),
    CDPRODFIN      VARCHAR2(20),
    DTPERIODOINI   DATE,
    DTPERIODOFIM   DATE,
    NRORG          NUMBER,
    CONSTRAINT PK_PEDIDOCOLETA PRIMARY KEY (NRPEDIDOCOLETA)
) ON COMMIT PRESERVE ROWS
/

CREATE SEQUENCE SEQ_PEDCOL_NRPEDIDOCOLETA INCREMENT BY 1 MINVALUE 1
/

CREATE SEQUENCE SEQ_PEDCOL_NRPEDCOL INCREMENT BY 1 MINVALUE 1
/

CREATE OR REPLACE PACKAGE PEDIDO_COLETA IS

   /**
    * Package responsável por tratar todos os processos que envolvem a rotina de Pedido de Coleta.
    *
    * @autor João Paulo Rodrigues Côrte
    * @data 06/03/2023
    *
    */

    /* Constantes */
    K_A   CONSTANT VARCHAR2(01) := 'A';
    K_C   CONSTANT VARCHAR2(01) := 'C';
    K_D   CONSTANT VARCHAR2(01) := 'D';
    K_M   CONSTANT VARCHAR2(01) := 'M';
    K_N   CONSTANT VARCHAR2(01) := 'N';
    K_O   CONSTANT VARCHAR2(01) := 'O';
    K_R   CONSTANT VARCHAR2(01) := 'R';
    K_S   CONSTANT VARCHAR2(01) := 'S';
    K_Z   CONSTANT VARCHAR2(01) := 'Z';
    K_CP  CONSTANT VARCHAR2(01) := '%';

    /* Types e Subtypes */
    TYPE REGISTRO IS RECORD
    (
        CDREGIAO     REGIAO.CDREGIAO%TYPE,
        NMREGIAO     REGIAO.NMREGIAO%TYPE,
        CDOPERADOR   OPERADOR.CDOPERADOR%TYPE,
        NMOPERADOR   OPERADOR.NMOPERADOR%TYPE,
        CDFORNECED   FORNECEDOR.CDFORNECED%TYPE,
        NRINSJURFORN FORNECEDOR.NRINSJURFORN%TYPE,
        IDTPIJURFORN FORNECEDOR.IDTPIJURFORN%TYPE,
        NMRAZSOCFORN FORNECEDOR.NMRAZSOCFORN%TYPE,
        NMFANTFORN   FORNECEDOR.NMFANTFORN%TYPE,
        CDPRODUTO    PRODUTO.CDPRODUTO%TYPE,
        NMPRODUTO    PRODUTO.NMPRODUTO%TYPE,
        SGUNIDADE    PRODUTO.SGUNIDADE%TYPE,
        CDPRODESTO   PRODUTO.CDPRODESTO%TYPE,
        IDTPFRETFORN FORNECEDOR.IDTPFRETFORN%TYPE,
        CDMARCA      MARCA.CDMARCA%TYPE,
        NMMARCA      MARCA.NMMARCA%TYPE,
        CDMARCAPADR  MARCA.CDMARCA%TYPE,
        CDARVPROD    PRODUTO.CDARVPROD%TYPE,
        QTACOMPRAR   FLOAT,
        NRCOMPRA     ITEMCOLE.NRCOLEPRECO%TYPE
    );
   
    TYPE TABELA IS TABLE OF REGISTRO;

    SUBTYPE S_RECORD_TMP_PEDIDOCOLETA IS TMP_PEDIDOCOLETA%ROWTYPE;
    
    /*
     * Procedure responsável por buscar as informações da tabela PARASUPRI
     *
     * @entrada P_CDFILIAL: Código da unidade
     * @saida   P_PARASUPRI: Registro da tabela PARASUPRI
     */
    PROCEDURE GET_PARASUPRI(P_CDFILIAL   IN FILIAL.CDFILIAL%TYPE,
                            P_PARASUPRI OUT PARASUPRI%ROWTYPE);

    /*
     * Procedure responsável por buscar as informações da tabela FILIAL
     *
     * @entrada P_CDFILIAL: Código da unidade
     * @saida   P_FILIAL: Registro da tabela FILIAL
     */
    PROCEDURE GET_DADOSFILIAL(P_CDFILIAL IN FILIAL.CDFILIAL%TYPE,
                              P_FILIAL  OUT FILIAL%ROWTYPE);

    /*
     * Procedure responsável por inserir registros a tabela TMP_PEDIDOCOLETA
     *
     * @entrada P_ITEMS: Registro com dados do pedido de coleta
     */
    PROCEDURE INSERT_TMPPEDIDOCOLETA(P_ITEMS IN S_RECORD_TMP_PEDIDOCOLETA);

    /*
     * Procedure responsável por buscar as informações do pedido de coleta
     *
     * @entrada P_CDFILIAL: Código da unidade
     * @entrada P_CDFILIPROC: Código da unidade de processamento
     * @entrada P_CDCOMPRADOR: Código do(s) comprador(es)
     * @entrada P_CDPRODINI: Código do produto inicial (CDARVPROD)
     * @entrada P_CDPRODFIN: Código do produto final (CDARVPROD)
     * @entrada P_CDFORNECED: Código do(s) fornecedor(es)
     * @entrada P_CDREGIAO: Código da(s) região(ões)
     * @entrada P_CDMARCA: Código da(s) marca(s)
     * @entrada P_DTINI: Data inicial
     * @entrada P_DTFIN: Data final
     * @entrada P_TIPOPEDIDO: Tipo do pedido (a comprar ou todos)
     * @entrada P_NRCOLEPRECO: Código da coleta de preços (Planilha de cotação)
     * @entrada P_NRCOMPRA: Código da compra
     * @entrada P_CDLEILAO: Código do leilão
     * @entrada P_NRSEQPRELIST: Código da lista de preços
     * @entrada P_CDOPERLANC: Código do operador de lançamento
     * @entrada P_NRORG: Código da orçanização
     * @saida   P_NRPEDCOL: Código do pedido de coleta
     * @saida   P_ERROR: Código/descrição possível inconsistência
     */
    PROCEDURE GETDATAPEDIDOCOLETA(P_CDFILIAL     IN FILIAL.CDFILIAL%TYPE,
                                  P_CDFILIPROC   IN FILIAL.CDFILIAL%TYPE,
                                  P_CDCOMPRADOR  IN VARCHAR2,
                                  P_CDPRODINI    IN VARCHAR2,
                                  P_CDPRODFIN    IN VARCHAR2,
                                  P_CDFORNECED   IN VARCHAR2,
                                  P_CDREGIAO     IN VARCHAR2,
                                  P_CDMARCA      IN VARCHAR2,
                                  P_DTINI        IN DATE,
                                  P_DTFIN        IN DATE,
                                  P_TIPOPEDIDO   IN VARCHAR2,
                                  P_NRCOLEPRECO  IN ITEMCOLE.NRCOLEPRECO%TYPE,
                                  P_NRCOMPRA     IN ITEMCOLE.NRCOLEPRECO%TYPE,
                                  P_CDLEILAO     IN PEDCOLETA.CDLEILAO%TYPE,
                                  P_NRSEQPRELIST IN ITEMCOLE.NRSEQPRELIST%TYPE,
                                  P_CDOPERLANC   IN OPERADOR.CDOPERADOR%TYPE,
                                  P_NRORG        IN FILIAL.NRORG%TYPE,
                                  P_NRPEDCOL     IN OUT TMP_PEDIDOCOLETA.NRPEDCOL%TYPE,
                                  P_ERROR       OUT VARCHAR2);

    /*
     * Procedure responsável por acrescentar itens contidos na previsão de consumo do período
     *
     * @entrada P_CDFILIAL: Código da unidade
     * @entrada P_CDPRODINI: Código do produto inicial (CDARVPROD)
     * @entrada P_CDPRODFIN: Código do produto final (CDARVPROD)
     * @entrada P_CDMARCA: Código da(s) marca(s)
     * @entrada P_CDCOMPRADOR: Código do(s) comprador(es)
     * @entrada P_CDREGIAO: Código da(s) região(ões)
     * @entrada P_CDFORNECED: Código do(s) fornecedor(es)
     * @entrada P_DTINI: Data inicial
     * @entrada P_DTFIN: Data final
     * @entrada P_NRORG: Código da orçanização
     * @entrada P_NRPEDCOL: Código do pedido de coleta
     */
    PROCEDURE SAVEPEDCOL_PREVCONS(P_CDFILIAL    IN VARCHAR2,
                                  P_CDPRODINI   IN VARCHAR2,
                                  P_CDPRODFIN   IN VARCHAR2,
                                  P_CDMARCA     IN VARCHAR2,
                                  P_CDCOMPRADOR IN VARCHAR2,
                                  P_CDREGIAO    IN VARCHAR2,
                                  P_CDFORNECED  IN VARCHAR2,
                                  P_DTINI       IN DATE,
                                  P_DTFIN       IN DATE,
                                  P_NRORG       IN FILIAL.NRORG%TYPE,
                                  P_NRPEDCOL    IN TMP_PEDIDOCOLETA.NRPEDCOL%TYPE DEFAULT NULL);

    /*
     * Procedure responsável inserir os registros do pedido de coleta em todas as tabelas do processo
     *
     * @entrada P_NRPEDCOL: Código do pedido de coleta
     * @entrada P_CDFILIAL: Código da unidade
     * @entrada P_CDFILIPROC: Código da unidade de processamento
     * @entrada P_QTMESES: Quantidade de meses a considerar para estipular quantidades a comprar
     * @entrada P_DTEXPIRAPEDCOL: Data de expiração do pedido de coleta
     * @entrada P_IDPEDGERALREG: Consolida todas as regiões em um único pedido de coleta por comprador
     * @entrada P_IDPEDGERALFORN: Consolida todos os fornecedores em um único pedido de coleta por comprador
     * @entrada P_IDCURVAABCAF: Considerar AF's do último mês para estipular quantidades a comprar
     * @entrada P_IDCONSFORNAF: Considera somente AF's do mesmo fornecedor
     * @saida   P_ERROR: Código/descrição possível inconsistência
     */
    PROCEDURE SAVEPEDIDOCOLETA(P_NRPEDCOL       IN TMP_PEDIDOCOLETA.NRPEDCOL%TYPE, 
                               P_CDFILIAL       IN FILIAL.CDFILIAL%TYPE,
                               P_CDFILIPROC     IN FILIAL.CDFILIAL%TYPE,
                               P_QTMESES        IN FLOAT,
                               P_DTEXPIRAPEDCOL IN DATE,
                               P_IDPEDGERALREG  IN VARCHAR2,
                               P_IDPEDGERALFORN IN VARCHAR2,
                               P_IDCURVAABCAF   IN VARCHAR2,
                               P_IDCONSFORNAF   IN VARCHAR2,
                               P_ERROR         OUT VARCHAR2);

    PROCEDURE PEDIDO_NRCOTACAO(P_CDCOMPRADOR IN COMPRADOR.CDOPERADOR%TYPE, 
                               P_CDFILIAL    IN FILIAL.CDFILIAL%TYPE,
                               P_CDFILIPROC  IN FILIAL.CDFILIAL%TYPE,
                               P_CDPRODINI   IN VARCHAR2, 
                               P_CDPRODFIN   IN VARCHAR2, 
                               P_CDFORNECED  IN VARCHAR2,
                               P_CDREGIAO    IN VARCHAR2, 
                               P_CDMARCA     IN VARCHAR2, 
                               P_DTINI       IN DATE, 
                               P_DTFIN       IN DATE, 
                               P_NRCOTACAO   IN VARCHAR2,
                               P_ERROR      OUT VARCHAR2);
    
    /******************adqPedColTodos******************/
    FUNCTION PED_COL_TODOS(P_CDCOMPRADOR   VARCHAR2,
                           P_CDFILIAL      VARCHAR2,
                           P_CDPRODINI     VARCHAR2,
                           P_CDPRODFIN     VARCHAR2,
                           P_TPRODUTO      VARCHAR2,
                           P_CDFORNECED    VARCHAR2,
                           P_CDREGIAO      VARCHAR2,
                           P_CDMARCA       VARCHAR2,
                           P_CDFILIPROC    VARCHAR2,
                           P_DTINI         DATE,
                           P_DTFIN         DATE) RETURN TABELA PIPELINED;
    
    /******************adqPedColAComp******************/
    FUNCTION PED_COL_ACOMP(P_CDCOMPRADOR   VARCHAR2,
                           P_CDFILIAL      VARCHAR2,
                           P_CDPRODINI     VARCHAR2,
                           P_CDPRODFIN     VARCHAR2,
                           P_TPRODUTO      VARCHAR2,
                           P_CDFORNECED    VARCHAR2,
                           P_CDREGIAO      VARCHAR2,
                           P_CDMARCA       VARCHAR2,
                           P_CDFILIPROC    VARCHAR2,
                           P_DTINI         DATE,
                           P_DTFIN         DATE) RETURN TABELA PIPELINED;

    /******************adqCotacao******************/
    FUNCTION PED_COL_COTACAO(P_CDCOMPRADOR   VARCHAR2,
                             P_CDFILIAL      VARCHAR2,
                             P_CDPRODINI     VARCHAR2,
                             P_CDPRODFIN     VARCHAR2,
                             P_TPRODUTO      VARCHAR2,
                             P_CDFORNECED    VARCHAR2,
                             P_CDREGIAO      VARCHAR2,
                             P_CDMARCA       VARCHAR2,
                             P_CDFILIPROC    VARCHAR2,
                             P_NRCOLEPRECO   VARCHAR2,
                             P_DTINI         DATE,
                             P_DTFIN         DATE) RETURN TABELA PIPELINED;

    /******************adqCotacaoForn******************/
    FUNCTION PED_COL_COTAFORN(P_CDCOMPRADOR   VARCHAR2,
                              P_CDFILIAL      VARCHAR2,
                              P_CDPRODINI     VARCHAR2,
                              P_CDPRODFIN     VARCHAR2,
                              P_TPRODUTO      VARCHAR2,
                              P_CDFORNECED    VARCHAR2,
                              P_CDREGIAO      VARCHAR2,
                              P_CDMARCA       VARCHAR2,
                              P_CDFILIPROC    VARCHAR2,
                              P_NRCOLEPRECO   VARCHAR2,
                              P_DTINI         DATE,
                              P_DTFIN         DATE) RETURN TABELA PIPELINED;

    /******************adqGeraListaPrec******************/
    FUNCTION PED_COL_GERALISTPREC(P_CDCOMPRADOR   VARCHAR2,
                                  P_CDFILIAL      VARCHAR2,
                                  P_CDPRODINI     VARCHAR2,
                                  P_CDPRODFIN     VARCHAR2,
                                  P_TPRODUTO      VARCHAR2,
                                  P_CDFORNECED    VARCHAR2,
                                  P_CDREGIAO      VARCHAR2,
                                  P_CDMARCA       VARCHAR2,
                                  P_CDFILIPROC    VARCHAR2,
                                  P_NRSEQPRELIST  VARCHAR2,
                                  P_DTINI         DATE,
                                  P_DTFIN         DATE) RETURN TABELA PIPELINED;

    /******************adqListaPrec******************/
    FUNCTION PED_COL_LISTAPREC(P_CDCOMPRADOR   VARCHAR2,
                               P_CDFILIAL      VARCHAR2,
                               P_CDPRODINI     VARCHAR2,
                               P_CDPRODFIN     VARCHAR2,
                               P_TPRODUTO      VARCHAR2,
                               P_CDFORNECED    VARCHAR2,
                               P_CDREGIAO      VARCHAR2,
                               P_CDMARCA       VARCHAR2,
                               P_CDFILIPROC    VARCHAR2,
                               P_NRSEQPRELIST  VARCHAR2,
                               P_DTINI         DATE,
                               P_DTFIN         DATE) RETURN TABELA PIPELINED;

    /******************adqPedCompra******************/
    FUNCTION PED_COMPRA(P_CDPRODINI     VARCHAR2,
                        P_CDPRODFIN     VARCHAR2,
                        P_TPRODUTO      VARCHAR2,
                        P_CDFORNECED    VARCHAR2,
                        P_CDMARCA       VARCHAR2,
                        P_NRCOMPRA      VARCHAR2,
                        P_DTINI         DATE,
                        P_DTFIN         DATE) RETURN TABELA PIPELINED;

    /******************adqPedColeta******************/
    FUNCTION GETPEDCOLETA(P_IDPEDCOL         IN VARCHAR2,
                          P_NRCOTACAO        IN VARCHAR2,
                          P_COMPRADOR        IN VARCHAR2,
                          P_MARCA            IN VARCHAR2,
                          P_FORNECED         IN VARCHAR2,
                          P_REGIAO           IN VARCHAR2,
                          P_PRODINI          IN VARCHAR2,
                          P_PRODFIN          IN VARCHAR2,
                          P_CDFILIAL         IN VARCHAR2,
                          P_CDFILIPROC       IN VARCHAR2,
                          P_NRCOMPRA         IN VARCHAR2,
                          P_CDLEILAO         IN VARCHAR2,
                          P_NRSEQPRELIST     IN VARCHAR2,
                          P_CDOPERLANC       IN VARCHAR2,
                          P_DESCFORNECEDOR   IN VARCHAR2,
                          P_LISTFORNECEDOR   IN VARCHAR2,
                          P_QTMESES          IN VARCHAR2,
                          P_DTINI            IN DATE,
                          P_DTFIN            IN DATE,
                          P_DTEXPIRAPEDCOL   IN DATE,
                          P_BOPEDEMAIL       IN VARCHAR2,
                          P_IDPEDGERALREG    IN VARCHAR2,
                          P_IDPEDGERALFORN   IN VARCHAR2,
                          P_IDCURVAABCAF     IN VARCHAR2,
                          P_IDENVMERCADUM    IN VARCHAR2,
                          P_BOACRESITEM      IN VARCHAR2,
                          P_IDCONSFORNAF     IN VARCHAR2,
                          P_NRORG            IN VARCHAR2 DEFAULT '1') RETURN TABELA PIPELINED;

    TYPE REG_PEDCOLETA IS RECORD
    (
        IDORDPLCOT       PARASUPRI.IDORDPLCOT%TYPE,
        IDPRODINCLFOR    PRMARCPEDCOL.IDPRODINCLFOR%TYPE,
        CDFILIAL         PRMARCPEDCOL.CDFILIAL%TYPE,
        VRPRECREN        PRMARCPEDCOL.VRPRECREN%TYPE,
        NRPEDIDOCOL      PRMARCPEDCOL.NRPEDIDOCOL%TYPE,
        QTDISPPRODMARC   PRMARCPEDCOL.QTDISPPRODMARC%TYPE,
        VRPRECUNIPRMARC  PRMARCPEDCOL.VRPRECUNIPRMARC%TYPE,
        VRULTPRECPRMARC  PRMARCPEDCOL.VRULTPRECPRMARC%TYPE,
        VRPRECOOBJETIVO  PRMARCPEDCOL.VRPRECOOBJETIVO%TYPE,
        DSOBSRENEGOCIA   PRMARCPEDCOL.DSOBSRENEGOCIA%TYPE,
        IDITPEDPRIONEG   PRMARCPEDCOL.IDITPEDPRIONEG%TYPE,
        NRORG            PRMARCPEDCOL.NRORG%TYPE,
        CDPRODUTO        PRODUTO.CDPRODUTO%TYPE,
        CDARVPROD        PRODUTO.CDARVPROD%TYPE,
        NMPRODUTO        PRODUTO.NMPRODUTO%TYPE,
        CDPRODESTO       PRODUTO.CDPRODESTO%TYPE,
        SGUNIDADE        PRODUTO.SGUNIDADE%TYPE,
        DSOBSNUTR        PRODUTO.DSOBSNUTR%TYPE,
        CDMARCA          MARCA.CDMARCA%TYPE,
        NMMARCA          MARCA.NMMARCA%TYPE,
        VRPERVARPREPRFO  PRODFORNCOMP.VRPERVARPREPRFO%TYPE,
        VRPERVARDESCPRFO PRODFORNCOMP.VRPERVARDESCPRFO%TYPE,
        QTPRODPEDCOL     ITEMPEDCOL.QTPRODPEDCOL%TYPE,
        IDITEMPEDCOLALT  ITEMPEDCOL.IDITEMPEDCOLALT%TYPE,
        VRPERDESPEDCOL   ITEMPEDCOL.VRPERDESPEDCOL%TYPE,
        IDRENEGOCIAPCOL  PEDCOLGERAL.IDRENEGOCIAPCOL%TYPE,
        QTDIASPRAZOEXPED PRAZOFORNEXPEDFILPROD.QTDIASPRAZOEXPED%TYPE,
        VRMINFORNREG     PRAZOFORNEXPEDFILPROD.VRMINFORNREG%TYPE,
        QTMINFORNREG     PRAZOFORNEXPEDFILPROD.QTMINFORNREG%TYPE
    );
                            
    TYPE TAB_PEDCOLETA IS TABLE OF REG_PEDCOLETA;
   
   /*
    * Função criada para retonar os campos utilizados na tela Pedido Cotação 
    * do Portal E-commerce
    *
    */
    FUNCTION SELECT_PEDCOLETA(P_CDFILIAL    IN FILIAL.CDFILIAL%TYPE,
                              P_NRPEDIDOCOL IN PEDCOLETA.NRPEDIDOCOL%TYPE,
                              P_CDFORNECED  IN FORNECEDOR.CDFORNECED%TYPE,
                              P_NRORG       IN PRMARCPEDCOL.NRORG%TYPE) RETURN TAB_PEDCOLETA PIPELINED;    

END PEDIDO_COLETA;
/

CREATE OR REPLACE PACKAGE BODY PEDIDO_COLETA IS
    PROCEDURE GET_PARASUPRI(P_CDFILIAL  IN FILIAL.CDFILIAL%TYPE,
                            P_PARASUPRI OUT PARASUPRI%ROWTYPE) IS
    BEGIN
        SELECT *
          INTO P_PARASUPRI
          FROM PARASUPRI
         WHERE CDFILIAL = P_CDFILIAL;
    EXCEPTION
        WHEN NO_DATA_FOUND THEN
            NULL;
    END GET_PARASUPRI;

    PROCEDURE GET_DADOSFILIAL(P_CDFILIAL IN FILIAL.CDFILIAL%TYPE,
                              P_FILIAL  OUT FILIAL%ROWTYPE) IS
    BEGIN
        SELECT *
          INTO P_FILIAL
          FROM FILIAL
         WHERE CDFILIAL = P_CDFILIAL;
    EXCEPTION
        WHEN NO_DATA_FOUND THEN
            NULL;
    END GET_DADOSFILIAL;

    PROCEDURE INSERT_TMPPEDIDOCOLETA(P_ITEMS IN S_RECORD_TMP_PEDIDOCOLETA) IS
        R_RECORD S_RECORD_TMP_PEDIDOCOLETA;
    BEGIN
        R_RECORD := P_ITEMS;
        R_RECORD.NRPEDIDOCOLETA := SEQ_PEDCOL_NRPEDIDOCOLETA.NEXTVAL;
        INSERT INTO TMP_PEDIDOCOLETA VALUES R_RECORD;
    END INSERT_TMPPEDIDOCOLETA;
    
    PROCEDURE GETDATAPEDIDOCOLETA(P_CDFILIAL     IN FILIAL.CDFILIAL%TYPE,
                                  P_CDFILIPROC   IN FILIAL.CDFILIAL%TYPE,
                                  P_CDCOMPRADOR  IN VARCHAR2,
                                  P_CDPRODINI    IN VARCHAR2,
                                  P_CDPRODFIN    IN VARCHAR2,
                                  P_CDFORNECED   IN VARCHAR2,
                                  P_CDREGIAO     IN VARCHAR2,
                                  P_CDMARCA      IN VARCHAR2,
                                  P_DTINI        IN DATE,
                                  P_DTFIN        IN DATE,
                                  P_TIPOPEDIDO   IN VARCHAR2,
                                  P_NRCOLEPRECO  IN ITEMCOLE.NRCOLEPRECO%TYPE,
                                  P_NRCOMPRA     IN ITEMCOLE.NRCOLEPRECO%TYPE,
                                  P_CDLEILAO     IN PEDCOLETA.CDLEILAO%TYPE,
                                  P_NRSEQPRELIST IN ITEMCOLE.NRSEQPRELIST%TYPE,
                                  P_CDOPERLANC   IN OPERADOR.CDOPERADOR%TYPE,
                                  P_NRORG        IN FILIAL.NRORG%TYPE,
                                  P_NRPEDCOL     IN OUT TMP_PEDIDOCOLETA.NRPEDCOL%TYPE,
                                  P_ERROR       OUT VARCHAR2) IS
        
        TYPE CURTYPE IS REF CURSOR;
        C_PEDIDOS    CURTYPE;
        C_PARASUPRI  PARASUPRI%ROWTYPE;
        C_FILIAL     FILIAL%ROWTYPE;
        R_ITEMS      S_RECORD_TMP_PEDIDOCOLETA;
        V_NRPEDCOL   TMP_PEDIDOCOLETA.NRPEDCOL%TYPE;
        V_CDREGIAO   REGIAO.CDREGIAO%TYPE;
        V_CDOPERADOR OPERADOR.CDOPERADOR%TYPE;
        V_CDFORNECED FORNECEDOR.CDFORNECED%TYPE;
        V_CDPRODUTO  PRODUTO.CDPRODUTO%TYPE;
        V_CDMARCA    MARCA.CDMARCA%TYPE;
        V_QTACOMPRAR FLOAT;

        FUNCTION MONTA_SQL RETURN VARCHAR2 IS
            V_SQL        VARCHAR2(32000);
            
        BEGIN
            V_SQL := 
                ' SELECT CDREGIAO, CDOPERADOR, CDFORNECED, CDPRODUTO, CDMARCA, SUM(QTACOMPRAR) QTACOMPRAR'||
                '   FROM (SELECT COMPLETO.CDREGIAO, COMPLETO.CDOPERADOR, COMPLETO.CDFORNECED,'||
                '                COMPLETO.CDPRODUTO, COMPLETO.CDMARCA,'||
                '                NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR'||
                '           FROM (SELECT REGIAO.CDREGIAO, OPERADOR.CDOPERADOR, FORNECEDOR.CDFORNECED,'||
                '                        PRODUTO.CDPRODUTO, MARCA.CDMARCA'|| 
                '                   FROM OPERADOR, REGIAO, PRODFORNCOMP'||
                '                   JOIN FORNECEDOR ON PRODFORNCOMP.CDFORNECED = FORNECEDOR.CDFORNECED'||
                '                   JOIN PRODUTO ON PRODFORNCOMP.CDPRODCOMPL = PRODUTO.CDPRODUTO'||				
                '                   LEFT JOIN (SELECT MA.CDMARCA, MP.CDPRMARCOMPL,'||
                '                                     NVL(MP.CDMARCA, '''|| C_PARASUPRI.CDMARCA ||''') CDMARCACOMPL'|| 
                '                                FROM MARCA MA'||
                '                                LEFT JOIN MARCPRODCOMP MP ON MA.CDMARCA = MP.CDMARCA'||
                '                               WHERE MA.IDMARCAATIVA = ''' || K_A ||'''';

            IF P_CDMARCA IS NOT NULL THEN
                V_SQL := V_SQL ||  ' AND INSTR('''|| P_CDMARCA ||''', MA.CDMARCA) > 0 ';
            END IF;

            V_SQL := V_SQL ||
                '                                 AND NVL(MP.CDMARCA, '''|| C_PARASUPRI.CDFILIAL ||''') IS NOT NULL) MARCA'||
                '                         ON PRODFORNCOMP.CDPRODCOMPL = MARCA.CDPRMARCOMPL'||
                '                  WHERE NVL(PRODUTO.IDPRODATIVPR, '''|| K_N ||''') =  '''|| K_S ||'''';
            IF P_CDCOMPRADOR IS NOT NULL THEN
                V_SQL := V_SQL ||  ' AND INSTR('''|| P_CDCOMPRADOR ||''', OPERADOR.CDOPERADOR) > 0 ';
            END IF;

            IF P_CDFORNECED IS NOT NULL THEN
                V_SQL := V_SQL || ' AND INSTR('''|| P_CDFORNECED ||''', FORNECEDOR.CDFORNECED) > 0 ';
            END IF;

            IF P_CDREGIAO IS NOT NULL THEN
                V_SQL := V_SQL || ' AND INSTR('''|| P_CDREGIAO ||''', REGIAO.CDREGIAO) > 0 ';
            END IF;

            IF NVL(C_PARASUPRI.IDUTLPROCMP, K_N) = K_S THEN
                V_SQL := V_SQL || ' AND PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO ';
            END IF;

            IF P_CDPRODINI IS NOT NULL AND P_CDPRODFIN IS NOT NULL THEN
                V_SQL := V_SQL || ' AND PRODUTO.CDARVPROD BETWEEN '''|| P_CDPRODINI ||''' AND RPAD('''|| P_CDPRODFIN ||''', 20, '''|| K_Z || ''') ';
            END IF;
            
            V_SQL := V_SQL ||
                ' AND NOT EXISTS (SELECT 1'|| 
                '                   FROM REFOREG'||
                '                  WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO'||
                '               AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)'||
                ' AND EXISTS (SELECT 1'||
                '               FROM PRODCOMP, PRODUTO PR'||
                '              WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO'||
                '                AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '''|| K_CP ||''''||
                '                AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR) ';
                
            IF C_PARASUPRI.IDULTIDTVALQ = K_D THEN
                V_SQL := V_SQL || 
                    ' AND NOT EXISTS (SELECT 1'|| 
                    '                   FROM QUALIFICACAO QF'||
                    '                  WHERE FORNECEDOR.CDQUALIF = QF.CDQUALIF'||
                    '                    AND FORNECEDOR.IDFORNAUTO = '''|| K_N ||''''||
                    '                    AND (QF.IDPERCOTCMP = 2 OR'||  
                    '                         TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF))'||
                    ' AND NOT EXISTS (SELECT 1'||
                    '                   FROM QFOMARPROD QF'||
                    '                  WHERE QF.CDPRODUTO = PRODUTO.CDPRODUTO'||
                    '                    AND QF.CDMARCA = MARCA.CDMARCACOMPL'|| 
                    '                    AND ((QF.IDAPRMARPRO = '''|| K_N ||''' AND'||
                    '                          QF.IDAUTMARPRO = '''|| K_N ||''') OR (QF.IDAPRMARPRO = '''|| K_S ||''' AND'||
                    '                                                                TO_DATE(SYSDATE) > QF.DTVALAPROVA)))'||
                    ' AND NOT EXISTS (SELECT 1'||
                    '                   FROM QFOPRODFORN'|| 
                    '                  WHERE QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL'||
                    '                    AND QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED'||
                    '                    AND ((QFOPRODFORN.IDFORNAPROV = '''|| K_N ||''' AND'||
                    '                          QFOPRODFORN.IDFORNAUTOR = '''|| K_N ||''') OR'||
                    '                         (QFOPRODFORN.IDFORNAPROV = '''|| K_S ||''' AND'|| 
                    '                          TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN))) ';
            END IF;
            
            IF C_PARASUPRI.IDULTIDTVALQ = K_M THEN
                V_SQL := V_SQL ||
                    ' AND NOT EXISTS (SELECT 1'|| 
                    '                   FROM QUALIFICACAO QF'||
                    '                  WHERE FORNECEDOR.CDQUALIF = QF.CDQUALIF'||
                    '                    AND FORNECEDOR.IDFORNAUTO = '''|| K_N ||''''||
                    '                    AND (QF.IDPERCOTCMP = 2 OR'||  
                    '                         TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))'||
                    ' AND NOT EXISTS (SELECT 1'||
                    '                   FROM QFOMARPROD QF'||
                    '                  WHERE QF.CDPRODUTO = PRODUTO.CDPRODUTO'||
                    '                    AND QF.CDMARCA = MARCA.CDMARCACOMPL'|| 
                    '                    AND ((QF.IDAPRMARPRO = '''|| K_N ||''' AND'||
                    '                          QF.IDAUTMARPRO = '''|| K_N ||''') OR (QF.IDAPRMARPRO = '''|| K_S ||''' AND'|| 
                    '                                                                TO_DATE(SYSDATE) > LAST_DAY(QF.DTVALAPROVA))))'||
                    ' AND NOT EXISTS (SELECT 1'||
                    '                   FROM QFOPRODFORN'|| 
                    '                  WHERE QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL'||
                    '                    AND QFOPRODFORN.CDFORNECED = PRODFORNCOMP.CDFORNECED'||
                    '                    AND ((QFOPRODFORN.IDFORNAPROV = '''|| K_N ||''' AND'||
                    '                          QFOPRODFORN.IDFORNAUTOR = '''|| K_N ||''') OR'||
                    '                         (QFOPRODFORN.IDFORNAPROV = '''|| K_S ||''' AND'|| 
                    '                          TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)))) ';
            END IF;

            IF NVL(C_PARASUPRI.IDMARSEMQUA, K_N) = K_S THEN
                V_SQL := V_SQL ||
                    ' AND EXISTS (SELECT 1'||
                    '               FROM QFOMARPROD'||
                    '              WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO'||
                    '                AND QFOMARPROD.CDMARCA = MARCA.CDMARCACOMPL) ';
            END IF;

            V_SQL := V_SQL ||
                ' AND EXISTS (SELECT 1'|| 
                '               FROM MARCFORNPEDCOL'|| 
                '              WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED'||
                '                AND MARCFORNPEDCOL.CDMARCA = MARCA.CDMARCA'|| 
                '              UNION ALL'||
                '             SELECT 1'|| 
                '               FROM DUAL'||
                '              WHERE NOT EXISTS (SELECT 1'||
                '                                  FROM MARCFORNPEDCOL'||
                '                                 WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))';
            
            IF P_TIPOPEDIDO = 'TODOS' THEN
                V_SQL := V_SQL || ' ) COMPLETO LEFT JOIN ';
            ELSIF P_TIPOPEDIDO = 'COMPRAR' THEN
                V_SQL := V_SQL || ' ) COMPLETO JOIN ';
            END IF;
                        
            IF NVL(C_PARASUPRI.IDCONSPRSOL, K_N) = K_N THEN
                V_SQL := V_SQL ||
                    ' (SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL,'||
                    '	      PRODACOMPRAR.CDPRODUTO, PRODACOMPRAR.QTACOMPRAR'||
                    '    FROM (SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO,'|| 
                    '                 COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/NVL(COMP.VRFATOCONV,1),0) QTACOMPRAR'||
                    '            FROM (SELECT ITEMSOLI.CDFILSOLI CDFILIAL, ITEMSOLI.DTPROGENTR,'|| 
                    '                         ESTOQUE.CDPRODUTO, ESTOQUE.CDPRODESTO, ESTOQUE.VRFATOCONV,'||
                    '                         SUM((ITEMSOLI.QTSOLIPROD*NVL(PRODUTO.VRFATOCONV,1))/NVL(ESTOQUE.VRFATOCONV,1)) QTDECOMP'||
                    '                    FROM PRODUTO ESTOQUE'||
                    '                    JOIN PRODUTO ON ESTOQUE.CDPRODESTO = PRODUTO.CDPRODESTO'||
                    '                    JOIN ITEMSOLI ON PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO'||
                    '                   WHERE ITEMSOLI.IDITMCONS = '''|| K_N ||''''||
                    '                     AND NVL(ITEMSOLI.IDSOLIAPROV, '''|| K_S ||''') = '''|| K_S ||'''';
                
                IF P_CDPRODINI IS NOT NULL AND P_CDPRODFIN IS NOT NULL THEN
                    V_SQL := V_SQL || ' AND ESTOQUE.CDARVPROD BETWEEN '''|| P_CDPRODINI ||''' AND RPAD('''|| P_CDPRODFIN ||''', 20, '''|| K_Z || ''') ';
                END IF;
                
                V_SQL := V_SQL ||
                    '                     AND (ITEMSOLI.DTPROGENTR BETWEEN '''|| P_DTINI ||''' AND '''|| P_DTFIN ||''')'||              
                    '                   GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR,'||
                    '                            ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO,'||
                    '                            ESTOQUE.VRFATOCONV'||
                    '               ) COMP LEFT JOIN';
            END IF;

            IF NVL(C_PARASUPRI.IDCONSPRSOL, K_N) = K_S THEN
                V_SQL := V_SQL ||
                    ' ( SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL, PRODACOMPRAR.CDPRODUTO,'||
                    '          PRODACOMPRAR.QTACOMPRAR'||  
                    '     FROM (SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO,'|| 
                    '                  COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/NVL(COMP.VRFATOCONV,1),0) QTACOMPRAR'|| 
                    '             FROM (SELECT ITEMSOLI.CDFILSOLI AS CDFILIAL, ITEMSOLI.DTPROGENTR,'||
                    '                          PRODUTO.CDPRODUTO, PRODUTO.CDPRODESTO, PRODUTO.VRFATOCONV,'||
                    '                          SUM(ITEMSOLI.QTSOLIPROD*NVL(PRODUTO.VRFATOCONV,1)) QTDECOMP'||
                    '                     FROM PRODUTO'||
                    '                     JOIN ITEMSOLI ON PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO'||
                    '                    WHERE ITEMSOLI.IDITMCONS = '''|| K_N ||''''||
                    '                      AND NVL(ITEMSOLI.IDSOLIAPROV,'''|| K_S ||''') = '''|| K_S ||'''';
                
                IF P_CDPRODINI IS NOT NULL AND P_CDPRODFIN IS NOT NULL THEN
                    V_SQL := V_SQL || ' AND PRODUTO.CDARVPROD BETWEEN '''|| P_CDPRODINI ||''' AND RPAD('''|| P_CDPRODFIN ||''', 20, '''|| K_Z || ''') ';
                END IF;
                
                V_SQL := V_SQL ||
                    '                      AND (ITEMSOLI.DTPROGENTR BETWEEN '''|| P_DTINI ||''' AND '''|| P_DTFIN ||''')'||
                    '                    GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR,'||
                    '                             PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO,'||
                    '                             PRODUTO.VRFATOCONV'||  
                    '           ) COMP LEFT JOIN';
            END IF;
            
            V_SQL := V_SQL ||
                '            (SELECT ITEMAUTF.CDFILDEST CDFILIAL, ITEMAUTF.DTENTRITMSOL,'||
                '                    PRODUTO.CDPRODESTO,'||
                '                    SUM(ITEMAUTF.QTPROGENTAF*NVL(PRODUTO.VRFATOCONV,1)) QTDECOMP'||
                '               FROM ITEMAUTF'||
                '               JOIN PRODUTO ON ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO'||
                '               JOIN AUTOFORNE ON ITEMAUTF.CDFILDEST = AUTOFORNE.CDFILDEST'|| 
                '                             AND ITEMAUTF.CDFILLANC = AUTOFORNE.CDFILLANC'||
                '                             AND ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN'|| 
                '              WHERE AUTOFORNE.IDSITUATUAAF IS NULL'||
                '                AND AUTOFORNE.IDAFFORALIM = '''|| K_N ||''''||
                '                AND AUTOFORNE.IDAUTOFORNEX = '''|| K_N ||''''||
                '                AND (ITEMAUTF.DTENTRITMSOL BETWEEN '''|| P_DTINI ||''' AND '''|| P_DTFIN ||''')'||
                '                AND NVL(AUTOFORNE.IDBAIXAAF, 0) <> 5'||
                '              GROUP BY ITEMAUTF.CDFILDEST, ITEMAUTF.DTENTRITMSOL,'||
                '                       PRODUTO.CDPRODESTO'||
                '            ) JACOMP ON COMP.CDFILIAL = JACOMP.CDFILIAL'||
                '                    AND COMP.DTPROGENTR = JACOMP.DTENTRITMSOL'||
                '                    AND COMP.CDPRODESTO = JACOMP.CDPRODESTO'||
                '                    AND COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/NVL(COMP.VRFATOCONV,1),0) > 0'||
                '       ) PRODACOMPRAR JOIN FILIAL ON PRODACOMPRAR.CDFILIAL = FILIAL.CDFILIAL'||
                ' WHERE NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = '''|| P_CDFILIAL ||'''';

            IF P_CDREGIAO IS NOT NULL THEN
                V_SQL := V_SQL || ' AND INSTR('''|| P_CDREGIAO ||''', FILIAL.CDREGIAO) <> 0 ';
            END IF;

            V_SQL := V_SQL || 
                ' ) PRODACOMPRAR ON COMPLETO.CDPRODUTO = PRODACOMPRAR.CDPRODUTO'||
                '               AND COMPLETO.CDREGIAO  = PRODACOMPRAR.CDREGIAO';

            IF NVL(C_FILIAL.IDFUNCAOFILI, K_O) = K_C THEN 
                V_SQL := V_SQL ||
                    ' JOIN (SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO'||
                    '         FROM PARAMPRODSUP'||
                    '         JOIN FILIAL ON PARAMPRODSUP.CDFILICTRL = FILIAL.CDFILIAL'||
                    '        WHERE FILIAL.CDFILIAL = '''|| P_CDFILIPROC ||''''||
                    '          AND PARAMPRODSUP.IDFILINEGCOR = '''|| K_S ||''')'||
                    '   ON COMPLETO.CDPRODUTO = PARAMPRODSUP.CDPRODUTO'||
                    '  AND COMPLETO.CDREGIAO = PARAMPRODSUP.CDREGIAO';
            END IF;

            IF NVL(C_FILIAL.IDFUNCAOFILI, K_O) = K_R THEN 
                V_SQL := V_SQL ||
                    ' JOIN (SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO'||
                    '         FROM PARAMPRODSUP'||
                    '         JOIN FILIAL ON PARAMPRODSUP.CDFILICTRL = FILIAL.CDFILIAL'||
                    '        WHERE FILIAL.CDFILIAL = '''|| P_CDFILIPROC ||''''||
                    '          AND PARAMPRODSUP.IDFILINEGREG = '''|| K_S ||''')'||
                    '   ON COMPLETO.CDPRODUTO = PARAMPRODSUP.CDPRODUTO'||
                    '  AND COMPLETO.CDREGIAO = PARAMPRODSUP.CDREGIAO';
            END IF;

            V_SQL := V_SQL || 
                ' WHERE NOT EXISTS (SELECT 1'||
                '                      FROM REFORFIL'|| 
                '                     WHERE REFORFIL.CDFORNECED = COMPLETO.CDFORNECED'||
                '                       AND REFORFIL.CDFILIAL  = PRODACOMPRAR.CDFILIAL'||
                '                       AND REFORFIL.CDPERIENTR IS NULL))'||
                ' GROUP BY CDREGIAO, CDOPERADOR, CDFORNECED, CDPRODUTO, CDMARCA';
            
            RETURN V_SQL;
        END MONTA_SQL;
    BEGIN
        IF P_NRPEDCOL IS NULL THEN
            V_NRPEDCOL := SEQ_PEDCOL_NRPEDCOL.NEXTVAL;
        ELSE
            V_NRPEDCOL := P_NRPEDCOL;
        END IF;

        GET_PARASUPRI(P_CDFILIAL  => P_CDFILIAL,
                      P_PARASUPRI => C_PARASUPRI);

        GET_DADOSFILIAL(P_CDFILIAL => P_CDFILIPROC,
                        P_FILIAL   => C_FILIAL);

        IF C_PARASUPRI.CDFILIAL IS NOT NULL AND C_FILIAL.CDFILIAL IS NOT NULL THEN 
            OPEN C_PEDIDOS FOR MONTA_SQL;
            LOOP
                FETCH C_PEDIDOS INTO V_CDREGIAO, V_CDOPERADOR, V_CDFORNECED, V_CDPRODUTO, V_CDMARCA, V_QTACOMPRAR;
                EXIT WHEN C_PEDIDOS%NOTFOUND;

                R_ITEMS.NRPEDCOL     := V_NRPEDCOL;
                R_ITEMS.CDFILIAL     := P_CDFILIAL;
                R_ITEMS.CDREGIAO     := V_CDREGIAO; 
                R_ITEMS.CDOPERADOR   := V_CDOPERADOR; 
                R_ITEMS.CDFORNECED   := V_CDFORNECED; 
                R_ITEMS.CDPRODUTO    := V_CDPRODUTO; 
                R_ITEMS.CDMARCA      := V_CDMARCA; 
                R_ITEMS.CDMARCAPADR  := C_PARASUPRI.CDMARCA;
                R_ITEMS.QTACOMPRAR   := V_QTACOMPRAR;
                R_ITEMS.NRCOLEPRECO  := P_NRCOLEPRECO;
                R_ITEMS.NRCOMPRA     := P_NRCOMPRA;
                R_ITEMS.NRSEQPRELIST := P_NRSEQPRELIST;
                R_ITEMS.CDLEILAO     := P_CDLEILAO;
                R_ITEMS.CDOPERLANC   := P_CDOPERLANC;
                R_ITEMS.DTPERIODOINI := P_DTINI;
                R_ITEMS.DTPERIODOFIM := P_DTFIN;
                R_ITEMS.CDPRODINI    := P_CDPRODINI;
                R_ITEMS.CDPRODFIN    := P_CDPRODFIN;
                R_ITEMS.NRORG        := P_NRORG;

                INSERT_TMPPEDIDOCOLETA(P_ITEMS => R_ITEMS);
            END LOOP;
            CLOSE C_PEDIDOS;
            
            P_NRPEDCOL := V_NRPEDCOL;
        ELSIF C_PARASUPRI.CDFILIAL IS NULL THEN
            P_ERROR := 'PARASUPRI_NAO_CADASTRADO';
        ELSIF C_FILIAL.CDFILIAL IS NULL THEN
            P_ERROR := 'FILIAL_NAO_CADASTRADA';
        END IF;
    END GETDATAPEDIDOCOLETA;

    PROCEDURE SAVEPEDCOL_PREVCONS(P_CDFILIAL    IN VARCHAR2,
                                  P_CDPRODINI   IN VARCHAR2,
                                  P_CDPRODFIN   IN VARCHAR2,
                                  P_CDMARCA     IN VARCHAR2,
                                  P_CDCOMPRADOR IN VARCHAR2,
                                  P_CDREGIAO    IN VARCHAR2,
                                  P_CDFORNECED  IN VARCHAR2,
                                  P_DTINI       IN DATE,
                                  P_DTFIN       IN DATE,
                                  P_NRORG       IN FILIAL.NRORG%TYPE,
                                  P_NRPEDCOL    IN TMP_PEDIDOCOLETA.NRPEDCOL%TYPE DEFAULT NULL) IS
   
        TYPE CURTYPE IS REF CURSOR;
        C_PREVCONS   CURTYPE;
        C_ITEMS      CURTYPE;
        C_PARASUPRI  PARASUPRI%ROWTYPE;
        R_ITEMS      S_RECORD_TMP_PEDIDOCOLETA;
        V_PREVCONS   VARCHAR2(32000);
        V_ITEMS      VARCHAR2(32000);
        V_COUNTER    FLOAT;
        V_CDPRODUTO  PRODUTO.CDPRODUTO%TYPE;
        V_CDFILIAL   FILIAL.CDFILIAL%TYPE;
        V_QTPREVCONS PREVCONS.QTPREVCONS%TYPE;
        V_QTSOLIPROD ITEMSOLI.QTSOLIPROD%TYPE;
        V_CDMARCA    MARCA.CDMARCA%TYPE;
        V_CDREGIAO   REGIAO.CDREGIAO%TYPE;
        V_CDFORNECED FORNECEDOR.CDFORNECED%TYPE;
        V_CDOPERADOR OPERADOR.CDOPERADOR%TYPE;
    BEGIN
        IF P_CDFILIAL IS NULL THEN 
            V_PREVCONS := 'SELECT PREVCONS.CDPRODUTO, PREVCONS.CDFILIAL, SUM(PREVCONS.QTPREVCONS) QTPREVCONS'||
                          '  FROM PREVCONS'||
                          '  JOIN PRODUTO ON PREVCONS.CDPRODUTO = PRODUTO.CDPRODUTO'||
                          ' WHERE PRODUTO.CDARVPROD BETWEEN '''|| P_CDPRODINI || ''' AND RPAD('''|| P_CDPRODFIN ||''', 20, '''|| K_Z || ''') '||
                          '   AND PREVCONS.DTPREVCONS BETWEEN ''' || P_DTINI || ''' AND ''' || P_DTFIN || ''')'||
                          '   AND NOT EXISTS (SELECT 1'||
                          '                     FROM TMP_PEDCOLETA' ||
                          '                    WHERE TMP_PEDCOLETA.CDPRODUTO = PREVCONS.CDPRODUTO))' ||
                          ' GROUP BY PREVCONS.CDPRODUTO, PREVCONS.CDFILIAL';
        ELSE
            V_PREVCONS := 'SELECT PREVCONS.CDPRODUTO, PREVCONS.CDFILIAL, SUM(PREVCONS.QTPREVCONS) QTPREVCONS'||
                          '  FROM PREVCONS'||
                          '  JOIN PRODUTO ON PREVCONS.CDPRODUTO = PRODUTO.CDPRODUTO'||
                          ' WHERE INSTR(''' || P_CDFILIAL || ''', PREVCONS.CDFILIAL) > 0'||
                          '   AND PRODUTO.CDARVPROD BETWEEN '''|| P_CDPRODINI || ''' AND RPAD('''|| P_CDPRODFIN ||''', 20, '''|| K_Z || ''') '||
                          '   AND PREVCONS.DTPREVCONS BETWEEN ''' || P_DTINI || ''' AND ''' || P_DTFIN || ''')'||
                          '   AND NOT EXISTS (SELECT 1'||
                          '                     FROM TMP_PEDCOLETA' ||
                          '                    WHERE TMP_PEDCOLETA.CDPRODUTO = PREVCONS.CDPRODUTO))' ||
                          ' GROUP BY PREVCONS.CDPRODUTO, PREVCONS.CDFILIAL';
        END IF;

        OPEN C_PREVCONS FOR V_PREVCONS;
        LOOP
            FETCH C_PREVCONS INTO V_CDPRODUTO, V_CDFILIAL, V_QTPREVCONS;
            EXIT WHEN C_PREVCONS%NOTFOUND;
               
            V_COUNTER := 0;

            GET_PARASUPRI(P_CDFILIAL  => V_CDFILIAL,
                          P_PARASUPRI => C_PARASUPRI);

            SELECT NVL(SUM(QTSOLIPROD), 0) QTACOMPRAR
              INTO V_QTSOLIPROD
              FROM ITEMSOLI
             WHERE DTPROGENTR BETWEEN P_DTINI AND P_DTFIN
               AND CDPRODUTO = V_CDPRODUTO
               AND CDFILSOLI = V_CDFILIAL;

            IF V_QTSOLIPROD = 0 THEN
                V_QTSOLIPROD := V_QTPREVCONS;
            END IF;
            
            FOR C_ITEMS IN (SELECT ITEMPEDCOL.CDMARCA, ITEMPEDCOL.CDREGIAO, ITEMPEDCOL.CDFORNECED,
                                   PEDCOLETA.CDOPERADOR, ITEMPEDCOL.CDPRODUTO, MAX(PEDCOLETA.DTPEDCOLETA) DTPEDCOLETA
                              FROM PEDCOLETA 
                              JOIN ITEMPEDCOL ON PEDCOLETA.CDFILIAL    = ITEMPEDCOL.CDFILIAL
                                             AND PEDCOLETA.NRPEDCOLETA = ITEMPEDCOL.NRPEDCOLETA
                                             AND PEDCOLETA.CDREGIAO    = ITEMPEDCOL.CDREGIAO
                                             AND PEDCOLETA.CDFORNECED  = ITEMPEDCOL.CDFORNECED                                  
                             WHERE PEDCOLETA.CDFILIAL   = V_CDFILIAL
                               AND ITEMPEDCOL.CDPRODUTO = V_CDPRODUTO
                             GROUP BY ITEMPEDCOL.CDMARCA, ITEMPEDCOL.CDREGIAO, ITEMPEDCOL.CDFORNECED, 
                                      PEDCOLETA.CDOPERADOR, ITEMPEDCOL.CDPRODUTO)
            LOOP
                V_COUNTER := V_COUNTER + 1;

                R_ITEMS.NRPEDCOL    := P_NRPEDCOL; 
                R_ITEMS.CDREGIAO    := C_ITEMS.CDREGIAO; 
                R_ITEMS.CDOPERADOR  := C_ITEMS.CDOPERADOR; 
                R_ITEMS.CDFORNECED  := C_ITEMS.CDFORNECED; 
                R_ITEMS.CDPRODUTO   := C_ITEMS.CDPRODUTO; 
                R_ITEMS.CDMARCA     := C_ITEMS.CDMARCA; 
                R_ITEMS.CDMARCAPADR := C_PARASUPRI.CDMARCA;
                R_ITEMS.QTACOMPRAR  := V_QTSOLIPROD;
                R_ITEMS.NRORG       := P_NRORG;

                INSERT_TMPPEDIDOCOLETA(P_ITEMS => R_ITEMS);
            END LOOP;
            
            IF V_COUNTER = 0 THEN
                V_ITEMS := 'SELECT MARCA.CDMARCA, REGIAO.CDREGIAO, FORNECEDOR.CDFORNECED, OPERADOR.CDOPERADOR'||
                           '  FROM OPERADOR, REGIAO, MARCA, FORNECEDOR, PRODUTO'||
                           ' WHERE MARCA.IDMARCAATIVA = ''' || K_A ||''''||
                           '   AND PRODUTO.CDPRODUTO = '''|| V_CDPRODUTO ||'''';
                IF P_CDMARCA IS NOT NULL THEN
                    V_ITEMS := V_ITEMS || ' AND INSTR('''|| P_CDMARCA ||''', MARCA.CDMARCA) > 0 ';
                END IF;
                IF P_CDCOMPRADOR IS NOT NULL THEN
                    V_ITEMS := V_ITEMS || ' AND INSTR('''|| P_CDCOMPRADOR ||''', OPERADOR.CDOPERADOR) > 0 ';
                END IF;
                IF P_CDREGIAO IS NOT NULL THEN
                    V_ITEMS := V_ITEMS || ' AND INSTR('''|| P_CDREGIAO ||''', REGIAO.CDREGIAO) > 0 ';
                END IF;
                IF P_CDFORNECED IS NOT NULL THEN
                    V_ITEMS := V_ITEMS || ' AND INSTR('''|| P_CDFORNECED ||''', FORNECEDOR.CDFORNECED) > 0 ';
                END IF;

                V_ITEMS := V_ITEMS || 
                    ' AND EXISTS (SELECT 1'||
                    '               FROM PRODCOMP, PRODUTO PR'||
                    '              WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO'||
                    '                AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '''|| K_CP ||''''||
                    '                AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR) ';

                V_ITEMS := V_ITEMS || 
                    ' AND NOT EXISTS (SELECT 1'|| 
                    '                   FROM REFOREG'||
                    '                  WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO'||
                    '               AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)';
                
                V_ITEMS := V_ITEMS || 
                    ' AND NOT EXISTS (SELECT 1'||
                    '                   FROM REFORFIL'|| 
                    '                  WHERE REFORFIL.CDFORNECED = FORNECEDOR.CDFORNECED'||
                    '                    AND REFORFIL.CDFILIAL = '''|| V_CDFILIAL|| ''''||
                    '                    AND REFORFIL.CDPERIENTR IS NULL))';

                V_ITEMS := V_ITEMS || 
                    ' AND EXISTS (SELECT 1'||
                    '               FROM MARCPRODCOMP'||
                    '              WHERE MARCPRODCOMP.CDMARCA = MARCA.CDMARCA'||
                    '                AND MARCPRODCOMP.CDPRMARCOMPL = PRODUTO.CDPRODUTO)';

                V_ITEMS := V_ITEMS || 
                    ' AND EXISTS (SELECT 1'||
                    '               FROM MARCFORNPEDCOL'||
                    '              WHERE MARCFORNPEDCOL.CDMARCA = MARCA.CDMARCA'||
                    '                AND MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED)';

                IF C_PARASUPRI.IDULTIDTVALQ = K_D THEN
                    V_ITEMS := V_ITEMS ||
                        ' AND NOT EXISTS (SELECT 1'|| 
                        '                   FROM QUALIFICACAO QF'||
                        '                  WHERE FORNECEDOR.CDQUALIF = QF.CDQUALIF'||
                        '                    AND FORNECEDOR.IDFORNAUTO = '''|| K_N ||''''||
                        '                    AND (QF.IDPERCOTCMP = 2 OR'||  
                        '                         TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF))'||
                        ' AND NOT EXISTS (SELECT 1'||
                        '                   FROM QFOMARPROD QF'||
                        '                  WHERE QF.CDPRODUTO = PRODUTO.CDPRODUTO'||
                        '                    AND QF.CDMARCA = MARCA.CDMARCACOMPL'|| 
                        '                    AND ((QF.IDAPRMARPRO = '''|| K_N ||''' AND'||
                        '                          QF.IDAUTMARPRO = '''|| K_N ||''') OR (QF.IDAPRMARPRO = '''|| K_S ||''' AND'||
                        '                                                                TO_DATE(SYSDATE) > QF.DTVALAPROVA)))'||
                        ' AND NOT EXISTS (SELECT 1'||
                        '                   FROM QFOPRODFORN'|| 
                        '                  WHERE QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL'||
                        '                    AND QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED'||
                        '                    AND ((QFOPRODFORN.IDFORNAPROV = '''|| K_N ||''' AND'||
                        '                          QFOPRODFORN.IDFORNAUTOR = '''|| K_N ||''') OR'||
                        '                         (QFOPRODFORN.IDFORNAPROV = '''|| K_S ||''' AND'|| 
                        '                          TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN))) ';
                END IF;
        
                IF C_PARASUPRI.IDULTIDTVALQ = K_M THEN
                    V_ITEMS := V_ITEMS ||
                        ' AND NOT EXISTS (SELECT 1'|| 
                        '                   FROM QUALIFICACAO QF'||
                        '                  WHERE FORNECEDOR.CDQUALIF = QF.CDQUALIF'||
                        '                    AND FORNECEDOR.IDFORNAUTO = '''|| K_N ||''''||
                        '                    AND (QF.IDPERCOTCMP = 2 OR'||  
                        '                         TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))'||
                        ' AND NOT EXISTS (SELECT 1'||
                        '                   FROM QFOMARPROD QF'||
                        '                  WHERE QF.CDPRODUTO = PRODUTO.CDPRODUTO'||
                        '                    AND QF.CDMARCA = MARCA.CDMARCACOMPL'|| 
                        '                    AND ((QF.IDAPRMARPRO = '''|| K_N ||''' AND'||
                        '                          QF.IDAUTMARPRO = '''|| K_N ||''') OR (QF.IDAPRMARPRO = '''|| K_S ||''' AND'|| 
                        '                                                                TO_DATE(SYSDATE) > LAST_DAY(QF.DTVALAPROVA))))'||
                        ' AND NOT EXISTS (SELECT 1'||
                        '                   FROM QFOPRODFORN'|| 
                        '                  WHERE QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL'||
                        '                    AND QFOPRODFORN.CDFORNECED = PRODFORNCOMP.CDFORNECED'||
                        '                    AND ((QFOPRODFORN.IDFORNAPROV = '''|| K_N ||''' AND'||
                        '                          QFOPRODFORN.IDFORNAUTOR = '''|| K_N ||''') OR'||
                        '                         (QFOPRODFORN.IDFORNAPROV = '''|| K_S ||''' AND'|| 
                        '                          TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)))) ';
                END IF;

                IF NVL(C_PARASUPRI.IDMARSEMQUA, K_N) = K_S THEN
                    V_ITEMS := V_ITEMS ||
                        ' AND EXISTS (SELECT 1'||
                        '               FROM QFOMARPROD'||
                        '              WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO'||
                        '                AND QFOMARPROD.CDMARCA = MARCA.CDMARCACOMPL) ';
                END IF;

                OPEN C_ITEMS FOR V_ITEMS;
                LOOP
                    FETCH C_ITEMS INTO V_CDMARCA, V_CDREGIAO, V_CDFORNECED, V_CDOPERADOR;
                    EXIT WHEN C_ITEMS%NOTFOUND;

                    R_ITEMS.NRPEDCOL    := P_NRPEDCOL; 
                    R_ITEMS.CDREGIAO    := V_CDREGIAO; 
                    R_ITEMS.CDOPERADOR  := V_CDOPERADOR; 
                    R_ITEMS.CDFORNECED  := V_CDFORNECED; 
                    R_ITEMS.CDPRODUTO   := V_CDPRODUTO; 
                    R_ITEMS.CDMARCA     := V_CDMARCA; 
                    R_ITEMS.CDMARCAPADR := C_PARASUPRI.CDMARCA;
                    R_ITEMS.QTACOMPRAR  := V_QTPREVCONS;
                    R_ITEMS.NRORG       := P_NRORG;

                    INSERT_TMPPEDIDOCOLETA(P_ITEMS => R_ITEMS);
                END LOOP;
                CLOSE C_ITEMS;
            END IF;
        END LOOP;
        CLOSE C_PREVCONS;
    END SAVEPEDCOL_PREVCONS;

    PROCEDURE SAVEPEDIDOCOLETA(P_NRPEDCOL       IN TMP_PEDIDOCOLETA.NRPEDCOL%TYPE, 
                               P_CDFILIAL       IN FILIAL.CDFILIAL%TYPE,
                               P_CDFILIPROC     IN FILIAL.CDFILIAL%TYPE,
                               P_QTMESES        IN FLOAT,
                               P_DTEXPIRAPEDCOL IN DATE,
                               P_IDPEDGERALREG  IN VARCHAR2,
                               P_IDPEDGERALFORN IN VARCHAR2,
                               P_IDCURVAABCAF   IN VARCHAR2,
                               P_IDCONSFORNAF   IN VARCHAR2,
                               P_ERROR         OUT VARCHAR2) IS
        V_DTINIABCAF      DATE;
        V_DTFINABCAF      DATE;
        V_IDSISDOS        PARAMGERAL.IDSISDOS%TYPE;
        V_NRPEDCOLETA     VARCHAR2(20);
        V_NRPEDIDOCOL     VARCHAR2(20);
        V_COMPFORN        VARCHAR2(200) := ' ';
        V_COMPCONSREG     VARCHAR2(200) := ' ';
        V_COMPCONSFORN    VARCHAR2(200) := ' ';
        V_COMPCONSCOMP    VARCHAR2(200) := ' ';
        V_COMPCOTACAO     VARCHAR2(200) := ' ';
        V_QTPRODPEDCOL    ITEMPEDCOL.QTPRODPEDCOL%TYPE;
        V_VRPRECOANT      FLOAT;
    BEGIN
        BEGIN
            SELECT TO_DATE('01/'||TO_CHAR(ADD_MONTHS(SYSDATE, - NVL(P_QTMESES, 1)), 'MM/YYYY'), 'DD/MM/YYYY') AS DTINICIAL,
                LAST_DAY(ADD_MONTHS(SYSDATE, -1)) AS DTFINAL,
                NVL(IDSISDOS, '1') IDSISDOS
            INTO V_DTINIABCAF, V_DTFINABCAF, V_IDSISDOS
            FROM PARAMGERAL;
        EXCEPTION
            WHEN NO_DATA_FOUND THEN
                P_ERROR := 'PARAMGERAL_NOTFOUND';
        END;

        FOR C_ITEMS IN (SELECT TMP_PEDIDOCOLETA.NRPEDCOL, TMP_PEDIDOCOLETA.CDREGIAO, TMP_PEDIDOCOLETA.CDOPERADOR, 
                               TMP_PEDIDOCOLETA.CDFORNECED, PRODUTO.CDPRODUTO, PRODUTO.CDPRODESTO, TMP_PEDIDOCOLETA.CDMARCA, 
                               TMP_PEDIDOCOLETA.CDMARCAPADR, TMP_PEDIDOCOLETA.QTACOMPRAR, TMP_PEDIDOCOLETA.NRCOLEPRECO,
                               TMP_PEDIDOCOLETA.NRSEQPRELIST, TMP_PEDIDOCOLETA.DTPERIODOINI, TMP_PEDIDOCOLETA.DTPERIODOFIM,
                               TMP_PEDIDOCOLETA.CDOPERLANC, TMP_PEDIDOCOLETA.CDLEILAO,
                               DECODE(FORNECEDOR.IDTPDESCFORN, K_C, NVL(FORNECEDOR.VRPEDESCFORN, 0), 0) VRPEDESCFORN
                          FROM TMP_PEDIDOCOLETA
                          JOIN PRODUTO ON TMP_PEDIDOCOLETA.CDPRODUTO = PRODUTO.CDPRODUTO
                          JOIN FORNECEDOR ON TMP_PEDIDOCOLETA.CDFORNECED = FORNECEDOR.CDFORNECED
                         WHERE TMP_PEDIDOCOLETA.NRPEDCOL = P_NRPEDCOL
                         ORDER BY CDOPERADOR, NRCOLEPRECO, CDFORNECED, CDREGIAO, NMPRODUTO)
        LOOP
            IF V_COMPFORN <> C_ITEMS.CDREGIAO||C_ITEMS.CDOPERADOR||C_ITEMS.CDFORNECED THEN 
                NOVO_CODIGO_SC('PEDCOLETA'||P_CDFILIAL||C_ITEMS.CDFORNECED||C_ITEMS.CDREGIAO, V_NRPEDCOLETA, 1);
                V_NRPEDCOLETA := SUBSTR(V_NRPEDCOLETA, 11, 10);

                IF (
                    (P_IDPEDGERALREG <> 'S'           AND V_COMPCONSREG  <> C_ITEMS.CDOPERADOR||C_ITEMS.CDREGIAO    AND (C_ITEMS.NRSEQPRELIST IS NULL OR V_IDSISDOS <> '3')) OR
                    (P_IDPEDGERALFORN <> 'S'          AND V_COMPCONSFORN <> C_ITEMS.CDOPERADOR||C_ITEMS.CDFORNECED  AND (C_ITEMS.NRSEQPRELIST IS NULL OR V_IDSISDOS <> '3')) OR
                    (C_ITEMS.NRSEQPRELIST IS NOT NULL AND V_COMPCOTACAO  <> C_ITEMS.CDOPERADOR||C_ITEMS.NRCOLEPRECO AND V_IDSISDOS = '3')                              OR 
                    (V_COMPCONSCOMP <> C_ITEMS.CDOPERADOR)
                ) 
                THEN
                    NOVO_CODIGO_SC('PEDCOLGERAL'||P_CDFILIAL, V_NRPEDIDOCOL, 1);
                    V_NRPEDIDOCOL := SUBSTR(V_NRPEDIDOCOL, 11, 10);

                    INSERT INTO PEDCOLGERAL (CDFILIAL, NRPEDIDOCOL, DTPEDCOLGERAL, DTINIPERGERAL, DTFINPERGERAL, IDPEDCOLCONS, CDOPERADOR, CDOPERLANC, DTEXPIRAPEDCOL)
                    VALUES (P_CDFILIAL, V_NRPEDIDOCOL, SYSDATE, C_ITEMS.DTPERIODOINI, C_ITEMS.DTPERIODOFIM, 'S', C_ITEMS.CDOPERADOR, C_ITEMS.CDOPERLANC, P_DTEXPIRAPEDCOL);
                END IF;
                
                INSERT INTO PEDCOLETA (CDFILIAL, NRPEDCOLETA, CDFORNECED, DTPEDCOLETA, CDOPERADOR, DTINIPERCOT, DTFINPERCOT, CDREGIAO, CDLEILAO, NRPEDIDOCOL)
                VALUES (P_CDFILIAL, V_NRPEDCOLETA, C_ITEMS.CDFORNECED, SYSDATE, C_ITEMS.CDOPERADOR, C_ITEMS.DTPERIODOINI, C_ITEMS.DTPERIODOFIM, C_ITEMS.CDREGIAO, C_ITEMS.CDLEILAO, V_NRPEDIDOCOL);
            
                INSERT INTO FORNEPEDCOL (CDFILIAL, NRPEDIDOCOL, CDFORNECED)
                SELECT P_CDFILIAL, V_NRPEDIDOCOL, C_ITEMS.CDFORNECED
                  FROM DUAL
                  WHERE NOT EXISTS (SELECT 1
                                      FROM FORNEPEDCOL F
                                     WHERE F.CDFILIAL    = P_CDFILIAL
                                       AND F.NRPEDIDOCOL = V_NRPEDIDOCOL
                                       AND F.CDFORNECED  = C_ITEMS.CDFORNECED);

                INSERT INTO REGIAOPEDCOL (CDFILIAL, NRPEDIDOCOL, CDREGIAO)
                SELECT P_CDFILIAL, V_NRPEDIDOCOL, C_ITEMS.CDREGIAO
                  FROM DUAL
                 WHERE NOT EXISTS (SELECT 1
                                     FROM REGIAOPEDCOL R
                                    WHERE R.CDFILIAL    = P_CDFILIAL
                                      AND R.NRPEDIDOCOL = V_NRPEDIDOCOL
                                      AND R.CDREGIAO    = C_ITEMS.CDREGIAO);
            END IF;
        
            IF V_IDSISDOS = '3' THEN
                IF P_IDCURVAABCAF = 'S' THEN
                    BEGIN
                        SELECT SUM(ITEMAUTF.QTPROGENTAF * PRODUTO.VRFATOCONV)
                          INTO V_QTPRODPEDCOL
                          FROM AUTOFORNE
                          JOIN ITEMAUTF ON AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                          JOIN FILIAL   ON AUTOFORNE.CDFILDEST  = FILIAL.CDFILIAL
                          JOIN PRODUTO  ON ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO                      
                         WHERE AUTOFORNE.IDSITUATUAAF IS NULL
                           AND AUTOFORNE.IDAFFORALIM = K_N
                           AND NVL(AUTOFORNE.IDBAIXAAF,'0') <> '6'
                           AND FILIAL.CDREGIAO    = C_ITEMS.CDREGIAO
                           AND PRODUTO.CDPRODESTO = C_ITEMS.CDPRODESTO
                           AND ITEMAUTF.DTPROGENTAF BETWEEN V_DTINIABCAF AND V_DTFINABCAF;
                    EXCEPTION
                        WHEN NO_DATA_FOUND THEN
                            V_QTPRODPEDCOL := 0;
                    END;
                ELSE
                    V_QTPRODPEDCOL := C_ITEMS.QTACOMPRAR;
                END IF;
            ELSE
                IF(P_QTMESES IS NOT NULL) THEN
                    IF (P_IDCONSFORNAF = 'S') THEN
                        BEGIN
                            SELECT SUM(NVL(AF.QTDEACOMPRAR, 0))
                              INTO V_QTPRODPEDCOL
                              FROM (SELECT (SUM(ITEMAUTF.QTEFETENTRAF * PRODUTO.VRFATOCONV) / P_QTMESES) QTDEACOMPRAR
                                      FROM ITEMAUTF 
                                      JOIN AUTOFORNE    ON AUTOFORNE.CDFILDEST     = ITEMAUTF.CDFILDEST
                                                       AND AUTOFORNE.CDFILLANC     = ITEMAUTF.CDFILLANC
                                                       AND AUTOFORNE.NRAUTOFORN    = ITEMAUTF.NRAUTOFORN
                                      JOIN RELACPRODOL  ON ITEMAUTF.CDPRODUTO      = RELACPRODOL.CDPRODARVOL
                                      JOIN PRODUTO      ON RELACPRODOL.CDPRARVORIG = PRODUTO.CDPRODUTO
                                                       AND RELACPRODOL.CDMARCA     = C_ITEMS.CDMARCA
                                      JOIN FILIAL       ON AUTOFORNE.CDFILDEST     = FILIAL.CDFILIAL
                                     WHERE AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND NVL(AUTOFORNE.IDBAIXAAF,'0') <> '6'
                                       AND ITEMAUTF.IDBAIXITMAF IN ('1', '2')
                                       AND AUTOFORNE.IDAFFORALIM = K_N
                                       AND FILIAL.CDREGIAO       = C_ITEMS.CDREGIAO
                                       AND PRODUTO.CDPRODUTO     = C_ITEMS.CDPRODUTO 
                                       AND ITEMAUTF.DTPROGENTAF BETWEEN V_DTINIABCAF AND V_DTFINABCAF
                                       AND AUTOFORNE.CDFORNECED  = NVL(C_ITEMS.CDFORNECED, AUTOFORNE.CDFORNECED)
                                     UNION
                                    SELECT (SUM((ITEMAUTF.QTEFETENTRAF * PRODESTO.VRFATOCONV)/PRODUTO.VRFATOCONV) / P_QTMESES) QTDEACOMPRAR
                                      FROM ITEMAUTF 
                                      JOIN AUTOFORNE        ON AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
                                                           AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
                                                           AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                      JOIN PRODUTO PRODESTO ON ITEMAUTF.CDPRODUTO   = PRODESTO.CDPRODUTO
                                      JOIN PRODUTO          ON ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO
                                      JOIN FILIAL           ON AUTOFORNE.CDFILDEST  = FILIAL.CDFILIAL
                                     WHERE AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND NVL(AUTOFORNE.IDBAIXAAF,'0') <> '6'
                                       AND ITEMAUTF.IDBAIXITMAF IN ('1', '2')
                                       AND AUTOFORNE.IDAFFORALIM = K_N
                                       AND FILIAL.CDREGIAO       = C_ITEMS.CDREGIAO
                                       AND PRODESTO.CDPRODESTO   = C_ITEMS.CDPRODESTO
                                       AND PRODUTO.CDPRODUTO     = C_ITEMS.CDPRODUTO
                                       AND ITEMAUTF.DTPROGENTAF BETWEEN V_DTINIABCAF AND V_DTFINABCAF
                                       AND AUTOFORNE.CDFORNECED  = NVL(C_ITEMS.CDFORNECED, AUTOFORNE.CDFORNECED)) AF;
                        EXCEPTION
                            WHEN NO_DATA_FOUND THEN
                                V_QTPRODPEDCOL := 0;
                        END;
                    ELSE
                        BEGIN
                            SELECT SUM(NVL(AF.QTDEACOMPRAR, 0))
                              INTO V_QTPRODPEDCOL
                              FROM (SELECT (SUM(ITEMAUTF.QTEFETENTRAF * PRODUTO.VRFATOCONV) / P_QTMESES) QTDEACOMPRAR
                                      FROM ITEMAUTF 
                                      JOIN AUTOFORNE    ON AUTOFORNE.CDFILDEST     = ITEMAUTF.CDFILDEST
                                                       AND AUTOFORNE.CDFILLANC     = ITEMAUTF.CDFILLANC
                                                       AND AUTOFORNE.NRAUTOFORN    = ITEMAUTF.NRAUTOFORN
                                      JOIN RELACPRODOL  ON ITEMAUTF.CDPRODUTO      = RELACPRODOL.CDPRODARVOL
                                      JOIN PRODUTO      ON RELACPRODOL.CDPRARVORIG = PRODUTO.CDPRODUTO
                                                       AND RELACPRODOL.CDMARCA     = C_ITEMS.CDMARCA
                                      JOIN FILIAL       ON AUTOFORNE.CDFILDEST     = FILIAL.CDFILIAL
                                     WHERE AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND NVL(AUTOFORNE.IDBAIXAAF,'0') <> '6'
                                       AND ITEMAUTF.IDBAIXITMAF IN ('1', '2')
                                       AND AUTOFORNE.IDAFFORALIM = K_N
                                       AND FILIAL.CDREGIAO       = C_ITEMS.CDREGIAO
                                       AND PRODUTO.CDPRODUTO     = C_ITEMS.CDPRODUTO 
                                       AND ITEMAUTF.DTPROGENTAF BETWEEN V_DTINIABCAF AND V_DTFINABCAF 
                                     UNION
                                    SELECT (SUM((ITEMAUTF.QTEFETENTRAF * PRODESTO.VRFATOCONV)/PRODUTO.VRFATOCONV) / P_QTMESES) QTDEACOMPRAR
                                      FROM ITEMAUTF 
                                      JOIN AUTOFORNE        ON AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
                                                           AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
                                                           AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                      JOIN PRODUTO PRODESTO ON ITEMAUTF.CDPRODUTO   = PRODESTO.CDPRODUTO
                                      JOIN PRODUTO          ON ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO
                                      JOIN FILIAL           ON AUTOFORNE.CDFILDEST  = FILIAL.CDFILIAL
                                     WHERE AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND NVL(AUTOFORNE.IDBAIXAAF,'0') <> '6'
                                       AND ITEMAUTF.IDBAIXITMAF IN ('1', '2')
                                       AND AUTOFORNE.IDAFFORALIM = K_N
                                       AND FILIAL.CDREGIAO       = C_ITEMS.CDREGIAO
                                      AND PRODESTO.CDPRODESTO   = C_ITEMS.CDPRODESTO
                                       AND PRODUTO.CDPRODUTO     = C_ITEMS.CDPRODUTO
                                       AND ITEMAUTF.DTPROGENTAF BETWEEN V_DTINIABCAF AND V_DTFINABCAF) AF;
                        EXCEPTION
                            WHEN NO_DATA_FOUND THEN
                                V_QTPRODPEDCOL := 0;
                        END;
                    END IF;
                ELSE
                    V_QTPRODPEDCOL := C_ITEMS.QTACOMPRAR;
                END IF;
            END IF;
        
            IF C_ITEMS.NRCOLEPRECO IS NOT NULL THEN 
                BEGIN
                    SELECT MIN(I.VRPRECUNIITM)
                      INTO V_VRPRECOANT
                      FROM ITEMCOLE I
                     WHERE I.CDFILIAL    = P_CDFILIAL
                       AND I.NRCOLEPRECO = C_ITEMS.NRCOLEPRECO
                       AND I.CDMARCA     = C_ITEMS.CDMARCA
                       AND I.CDREGIAO    = C_ITEMS.CDREGIAO
                       AND I.CDFORNECED  = C_ITEMS.CDFORNECED
                       AND I.CDPRODUTO   = C_ITEMS.CDPRODUTO
                       AND I.VRPRECUNIITM > 0;
                EXCEPTION
                    WHEN NO_DATA_FOUND THEN
                        V_VRPRECOANT := 0;
                END;
            ELSE
                IF C_ITEMS.NRSEQPRELIST IS NOT NULL THEN
                    IF V_IDSISDOS = '3' THEN
                        BEGIN
                            SELECT MIN(I.VRPRECUNIITM)
                              INTO V_VRPRECOANT
                              FROM ITEMCOLE I
                             WHERE I.CDFILIAL     = P_CDFILIAL
                               AND I.NRSEQPRELIST = C_ITEMS.NRSEQPRELIST
                               AND I.CDMARCA      = C_ITEMS.CDMARCA
                               AND I.CDREGIAO     = C_ITEMS.CDREGIAO
                               AND I.CDFORNECED   = C_ITEMS.CDFORNECED
                               AND I.CDPRODUTO    = C_ITEMS.CDPRODUTO
                               AND I.VRPRECUNIITM > 0;
                        EXCEPTION
                            WHEN NO_DATA_FOUND THEN
                                V_VRPRECOANT := 0;
                        END;
                    ELSE
                        BEGIN
                            SELECT MIN(I.VRPRECUNIITM)
                              INTO V_VRPRECOANT
                              FROM ITEMCOLE I
                             WHERE I.CDFILIAL     = P_CDFILIAL
                               AND I.NRSEQPRELIST = C_ITEMS.NRSEQPRELIST
                               AND I.CDMARCA      = C_ITEMS.CDMARCA
                               AND I.CDREGIAO     = C_ITEMS.CDREGIAO
                               AND I.CDFORNECED   = C_ITEMS.CDFORNECED
                               AND I.CDPRODUTO    = C_ITEMS.CDPRODUTO
                               AND I.VRPRECUNIITM > 0;
                        EXCEPTION
                            WHEN NO_DATA_FOUND THEN
                                V_VRPRECOANT := 0;
                        END;
                    END IF;
                ELSE
                    BEGIN
                        SELECT MIN(I.VRPRECUNIITM)
                          INTO V_VRPRECOANT
                          FROM ITEMCOLE I
                         WHERE I.CDFILIAL     = P_CDFILIAL
                           AND I.CDMARCA      = C_ITEMS.CDMARCA
                           AND I.CDREGIAO     = C_ITEMS.CDREGIAO
                           AND I.CDFORNECED   = C_ITEMS.CDFORNECED
                           AND I.CDPRODUTO    = C_ITEMS.CDPRODUTO
                           AND I.VRPRECUNIITM > 0
                           AND I.NRCOLEPRECO  = (SELECT MAX(NRCOLEPRECO)
                                                   FROM ITEMCOLE IT
                                                  WHERE IT.CDFILIAL     = I.CDFILIAL
                                                    AND IT.CDMARCA      = I.CDMARCA
                                                    AND IT.CDREGIAO     = I.CDREGIAO
                                                    AND IT.CDFORNECED   = I.CDFORNECED
                                                    AND IT.CDPRODUTO    = I.CDPRODUTO
                                                    AND IT.VRPRECUNIITM > 0);
                    EXCEPTION
                        WHEN NO_DATA_FOUND THEN
                            V_VRPRECOANT := 0;
                    END;
                END IF;
            END IF;

            INSERT INTO ITEMPEDCOL (CDFILIAL, 
                                    CDFORNECED, 
                                    NRPEDCOLETA, 
                                    CDREGIAO, 
                                    CDPRODUTO, 
                                    CDMARCA, 
                                    QTPRODPEDCOL, 
                                    IDSELELEILAO,
                                    VRANTITPEDCOL, 
                                    VRPERDESPEDCOL)
            SELECT P_CDFILIAL,
                   C_ITEMS.CDFORNECED,
                   V_NRPEDCOLETA,
                   C_ITEMS.CDREGIAO,
                   C_ITEMS.CDPRODUTO,
                   C_ITEMS.CDMARCA,
                   V_QTPRODPEDCOL,
                   'N',
                   V_VRPRECOANT,
                   C_ITEMS.VRPEDESCFORN
              FROM DUAL
             WHERE NOT EXISTS (SELECT 1
                                 FROM ITEMPEDCOL I
                                WHERE I.CDFILIAL    = P_CDFILIAL
                                  AND I.CDFORNECED  = C_ITEMS.CDFORNECED
                                  AND I.NRPEDCOLETA = V_NRPEDCOLETA
                                  AND I.CDREGIAO    = C_ITEMS.CDREGIAO
                                  AND I.CDPRODUTO   = C_ITEMS.CDPRODUTO
                                  AND I.CDMARCA     = C_ITEMS.CDMARCA);
            
            INSERT INTO PRMARCPEDCOL (CDFILIAL, NRPEDIDOCOL, CDPRODUTO, CDMARCA, VRULTPRECPRMARC)
            SELECT P_CDFILIAL, V_NRPEDIDOCOL, C_ITEMS.CDPRODUTO, C_ITEMS.CDMARCA, V_VRPRECOANT
              FROM DUAL
             WHERE NOT EXISTS (SELECT 1
                                 FROM PRMARCPEDCOL P
                                WHERE P.CDFILIAL    = P_CDFILIAL
                                  AND P.NRPEDIDOCOL = V_NRPEDIDOCOL
                                  AND P.CDPRODUTO   = C_ITEMS.CDPRODUTO
                                  AND P.CDMARCA     = C_ITEMS.CDMARCA);

            V_COMPCONSCOMP := C_ITEMS.CDOPERADOR;
            V_COMPCONSREG  := C_ITEMS.CDOPERADOR || C_ITEMS.CDREGIAO;
            V_COMPCONSFORN := C_ITEMS.CDOPERADOR || C_ITEMS.CDFORNECED;
            V_COMPCOTACAO  := C_ITEMS.CDOPERADOR || C_ITEMS.NRCOLEPRECO;
            V_COMPFORN     := C_ITEMS.CDREGIAO   || C_ITEMS.CDOPERADOR || C_ITEMS.CDFORNECED;
        END LOOP;
    END;

    PROCEDURE PEDIDO_NRCOTACAO(P_CDCOMPRADOR IN COMPRADOR.CDOPERADOR%TYPE, 
                               P_CDFILIAL    IN FILIAL.CDFILIAL%TYPE,
                               P_CDFILIPROC  IN FILIAL.CDFILIAL%TYPE,
                               P_CDPRODINI   IN VARCHAR2, 
                               P_CDPRODFIN   IN VARCHAR2, 
                               P_CDFORNECED  IN VARCHAR2,
                               P_CDREGIAO    IN VARCHAR2, 
                               P_CDMARCA     IN VARCHAR2, 
                               P_DTINI       IN DATE, 
                               P_DTFIN       IN DATE, 
                               P_NRCOTACAO   IN VARCHAR2,
                               P_ERROR      OUT VARCHAR2) IS
        TYPE CURTYPE IS REF CURSOR;
        C_PEDIDOS    CURTYPE;
        C_PARASUPRI  PARASUPRI%ROWTYPE;
        C_FILIAL     FILIAL%ROWTYPE;
        
        V_NRPEDCOL   TMP_PEDIDOCOLETA.NRPEDCOL%TYPE := SEQ_PEDCOL_NRPEDCOL.NEXTVAL;
        V_CDREGIAO   REGIAO.CDREGIAO%TYPE;
        V_CDOPERADOR OPERADOR.CDOPERADOR%TYPE;
        V_CDFORNECED FORNECEDOR.CDFORNECED%TYPE;
        V_CDPRODUTO  PRODUTO.CDPRODUTO%TYPE;
        V_CDMARCA    MARCA.CDMARCA%TYPE;
        V_QTACOMPRAR FLOAT;

        FUNCTION MONTA_SQL RETURN VARCHAR2 IS
            V_SQL        VARCHAR2(32000);
        BEGIN                         
            V_SQL := '';
            RETURN V_SQL;
        END MONTA_SQL;                               
    BEGIN
        GET_PARASUPRI(P_CDFILIAL  => P_CDFILIAL,
                      P_PARASUPRI => C_PARASUPRI);

        GET_DADOSFILIAL(P_CDFILIAL => P_CDFILIPROC,
                        P_FILIAL   => C_FILIAL);

        IF C_PARASUPRI.CDFILIAL IS NOT NULL AND C_FILIAL.CDFILIAL IS NOT NULL THEN
            BEGIN
                DBMS_OUTPUT.put_line(MONTA_SQL);
            EXCEPTION
                WHEN NO_DATA_FOUND THEN
                    NULL;
            END;
        ELSIF C_PARASUPRI.CDFILIAL IS NULL THEN
            P_ERROR := 'PARASUPRI_NAO_CADASTRADO';
        ELSIF C_FILIAL.CDFILIAL IS NULL THEN
            P_ERROR := 'FILIAL_NAO_CADASTRADA';
        END IF;
    END PEDIDO_NRCOTACAO;

	FUNCTION PED_COL_TODOS(	P_CDCOMPRADOR   VARCHAR2,
							P_CDFILIAL      VARCHAR2,
							P_CDPRODINI     VARCHAR2,
							P_CDPRODFIN     VARCHAR2,
							P_TPRODUTO      VARCHAR2,
							P_CDFORNECED    VARCHAR2,
							P_CDREGIAO      VARCHAR2,
							P_CDMARCA       VARCHAR2,
							P_CDFILIPROC    VARCHAR2,
							P_DTINI         DATE,
							P_DTFIN         DATE) RETURN TABELA PIPELINED IS
		V_PIPE TABELA := TABELA();
		V_INDICE NUMBER := 1;

      CURSOR PED_COL_TODOS IS
         SELECT CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
                IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
                CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD, SUM(QTACOMPRAR) AS QTACOMPRAR,
                ' ' AS NRCOMPRA
           FROM ( SELECT COMPLETO.CDREGIAO, COMPLETO.NMREGIAO, COMPLETO.CDOPERADOR, COMPLETO.NMOPERADOR,
                         COMPLETO.CDFORNECED, COMPLETO.NRINSJURFORN, COMPLETO.IDTPIJURFORN, COMPLETO.NMRAZSOCFORN,
                         COMPLETO.NMFANTFORN, COMPLETO.CDPRODUTO, COMPLETO.NMPRODUTO, COMPLETO.SGUNIDADE,
                         COMPLETO.CDPRODESTO, COMPLETO.IDTPFRETFORN, COMPLETO.CDMARCA, COMPLETO.NMMARCA,
                         COMPLETO.CDMARCAPADR, COMPLETO.CDARVPROD, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                    FROM PARASUPRI, FILIAL FILI,
                         ( SELECT REGIAO.CDREGIAO, REGIAO.NMREGIAO, OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR,
                                  PRODFORNCOMP.CDFORNECED, FORNECEDOR.NRINSJURFORN, FORNECEDOR.IDTPIJURFORN,
                                  FORNECEDOR.NMRAZSOCFORN, FORNECEDOR.NMFANTFORN, PRODUTO.CDPRODUTO,
                                  PRODUTO.NMPRODUTO, PRODUTO.SGUNIDADE, PRODUTO.CDPRODESTO, FORNECEDOR.IDTPFRETFORN,
                                  NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
                                  REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                                  PRODUTO.CDARVPROD, PARASUPRI.CDMARCA AS CDMARCAPADR
                             FROM OPERADOR, MARCA, PRODUTO, PRODFORNCOMP, MARCPRODCOMP, FORNECEDOR,
                                  REGIAO, PARASUPRI
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0
                              AND PARASUPRI.CDFILIAL = P_CDFILIAL
                              AND ((NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'N') OR (NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
                                                                               PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO))
                              AND ((PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN) OR (P_TPRODUTO = 'T'))
                              AND INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0
                              AND INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0
                              AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
                              AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA(+)), MARCPRODCOMP.CDMARCA(+))<> 0
                              AND FORNECEDOR.CDFORNECED = PRODFORNCOMP.CDFORNECED
                              AND PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                              AND PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL(+)
                              AND MARCA.IDMARCAATIVA = 'A'
                              AND MARCA.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                              AND NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S'
                              AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                                 FROM REFOREG
                                                WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                                  AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                              AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                             FROM PRODCOMP, PRODUTO PR
                                            WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                              AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                              AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                              AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   
                                                 FROM QUALIFICACAO
                                                WHERE (FORNECEDOR.CDQUALIF       = QUALIFICACAO.CDQUALIF)
                                                  AND (FORNECEDOR.IDFORNAUTO     = 'N')
                                                  AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ  = 'D' AND
                                                                                             TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF)
                                                                                        OR (PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                              AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   
                                                 FROM QFOMARPROD
                                                WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO)
                                                  AND (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))
                                                  AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND
                                                        QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND
                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA))
                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                          TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                              AND EXISTS ( SELECT QFOMARPROD.CDMARCA 
                                             FROM QFOMARPROD
                                            WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                              AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                            UNION
                                           SELECT PARASUPRI.CDMARCA
                                             FROM PARASUPRI
                                            WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                              AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                                              AND NOT EXISTS (SELECT QFOPRODFORN.CDPRODUTO 
                                                                FROM QFOPRODFORN
                                                               WHERE (QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)
                                                                 AND (QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED)
                                                                 AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND
                                                                       QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                                            TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN))
                                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                                          TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                              AND EXISTS ( SELECT 1
                                             FROM MARCFORNPEDCOL
                                            WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                              AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                              
                                            UNION ALL
                                           SELECT 1
                                             FROM DUAL
                                            WHERE NOT EXISTS (SELECT 1
                                                                FROM MARCFORNPEDCOL
                                                               WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                         ) COMPLETO,
                         ( SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL, PRODACOMPRAR.CDPRODUTO, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                             FROM ( SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO, ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) AS QTACOMPRAR
                                      FROM ( SELECT ITEMSOLI.CDFILSOLI AS CDFILIAL, ITEMSOLI.DTPROGENTR, ESTOQUE.CDPRODUTO, ESTOQUE.CDPRODESTO,
                                                     ESTOQUE.VRFATOCONV, SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV/ESTOQUE.VRFATOCONV) AS QTDECOMP
                                                FROM PRODUTO ESTOQUE, PRODUTO, ITEMSOLI
                                               WHERE (ITEMSOLI.IDITMCONS = 'N')
                                                 AND (NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                                                 AND (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                 AND (PRODUTO.CDPRODESTO = ESTOQUE.CDPRODESTO)
                                                 AND (ESTOQUE.CDARVPROD   BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                                                 AND (ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN)
                                               GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO,
                                                        ESTOQUE.VRFATOCONV
                                           ) COMP,
                                           ( SELECT ITEMAUTF.CDFILDEST AS CDFILIAL, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO,
                                                    SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMAUTF, AUTOFORNE
                                              WHERE (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST)
                                                AND (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC)
                                                AND (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN)
                                                AND (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (AUTOFORNE.IDSITUATUAAF IS NULL)
                                                AND (AUTOFORNE.IDAFFORALIM = 'N')
                                                AND (AUTOFORNE.IDAUTOFORNEX = 'N')
                                                AND (ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN)
                                                AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                              GROUP BY ITEMAUTF.CDFILDEST, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO
                                           ) JACOMP
                                     WHERE COMP.CDFILIAL = JACOMP.CDFILIAL (+)
                                       AND COMP.DTPROGENTR = JACOMP.DTENTRITMSOL (+)
                                       AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                                       AND ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) > 0
                                  ) PRODACOMPRAR, FILIAL
                            WHERE ((FILIAL.CDFILCENTCMP = P_CDFILIAL) OR (FILIAL.CDFILIAL = P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL))
                              AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                              AND (FILIAL.CDFILIAL = PRODACOMPRAR.CDFILIAL)
                         ) PRODACOMPRAR
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COMPLETO.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND COMPLETO.CDREGIAO  = PRODACOMPRAR.CDREGIAO(+)
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND NOT EXISTS (SELECT 1
                                       FROM REFORFIL
                                      WHERE REFORFIL.CDFORNECED = COMPLETO.CDFORNECED
                                        AND REFORFIL.CDFILIAL  = PRODACOMPRAR.CDFILIAL
                                        AND REFORFIL.CDPERIENTR IS NULL)

                  UNION ALL

                  SELECT COMPLETO.CDREGIAO, COMPLETO.NMREGIAO, COMPLETO.CDOPERADOR, COMPLETO.NMOPERADOR,
                         COMPLETO.CDFORNECED, COMPLETO.NRINSJURFORN, COMPLETO.IDTPIJURFORN, COMPLETO.NMRAZSOCFORN,
                         COMPLETO.NMFANTFORN, COMPLETO.CDPRODUTO, COMPLETO.NMPRODUTO, COMPLETO.SGUNIDADE,
                         COMPLETO.CDPRODESTO, COMPLETO.IDTPFRETFORN, COMPLETO.CDMARCA, COMPLETO.NMMARCA,
                         COMPLETO.CDMARCAPADR, COMPLETO.CDARVPROD, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                    FROM PARASUPRI,
                         ( SELECT REGIAO.CDREGIAO, REGIAO.NMREGIAO, OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR,
                                  PRODFORNCOMP.CDFORNECED, FORNECEDOR.NRINSJURFORN, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NMRAZSOCFORN,
                                  FORNECEDOR.NMFANTFORN, PRODUTO.CDPRODUTO, PRODUTO.NMPRODUTO, PRODUTO.SGUNIDADE,
                                  PRODUTO.CDPRODESTO, FORNECEDOR.IDTPFRETFORN, NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
                                  REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                                  PRODUTO.CDARVPROD, PARASUPRI.CDMARCA AS CDMARCAPADR
                             FROM OPERADOR, MARCA, PRODUTO, PRODFORNCOMP, MARCPRODCOMP, FORNECEDOR,
                                  REGIAO, PARASUPRI
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0
                              AND PARASUPRI.CDFILIAL = P_CDFILIAL
                              AND ((NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'N') OR (NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
                                                                               PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO))
                              AND ((PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN) OR (P_TPRODUTO = 'T'))
                              AND INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0
                              AND INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0
                              AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
                              AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA(+)), MARCPRODCOMP.CDMARCA(+))<> 0
                              AND FORNECEDOR.CDFORNECED = PRODFORNCOMP.CDFORNECED
                              AND PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                              AND PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL(+)
                              AND MARCA.IDMARCAATIVA       = 'A'
                              AND MARCA.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                              AND (NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S')
                              AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                                 FROM REFOREG
                                                WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                                  AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                              AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                             FROM PRODCOMP, PRODUTO PR
                                            WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                              AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                              AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                              AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   
                                                 FROM QUALIFICACAO
                                                WHERE (FORNECEDOR.CDQUALIF       = QUALIFICACAO.CDQUALIF)
                                                  AND (FORNECEDOR.IDFORNAUTO     = 'N')
                                                  AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ  = 'D' AND
                                                                                             TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF)
                                                                                        OR (PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                              AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA  
                                                 FROM QFOMARPROD
                                                WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO)
                                                  AND (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))
                                                  AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND
                                                        QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND
                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA))
                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                          TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                              AND EXISTS ( SELECT QFOMARPROD.CDMARCA 
                                             FROM QFOMARPROD
                                            WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                              AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                            UNION
                                           SELECT PARASUPRI.CDMARCA
                                             FROM PARASUPRI
                                            WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                              AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                              AND NOT EXISTS (SELECT QFOPRODFORN.CDPRODUTO
                                                FROM QFOPRODFORN
                                               WHERE (QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)
                                                 AND (QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED)
                                                 AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND
                                                       QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN))
                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                          TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                              AND EXISTS ( SELECT 1
                                             FROM MARCFORNPEDCOL
                                            WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                              AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                            UNION ALL
                                           SELECT 1
                                             FROM DUAL
                                            WHERE NOT EXISTS ( SELECT 1
                                                                 FROM MARCFORNPEDCOL
                                                                WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                         ) COMPLETO,
                         ( SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL, PRODACOMPRAR.CDPRODUTO, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                             FROM ( SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO,
                                           ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) AS QTACOMPRAR
                                      FROM ( SELECT ITEMSOLI.CDFILSOLI AS CDFILIAL, ITEMSOLI.DTPROGENTR, ESTOQUE.CDPRODUTO, ESTOQUE.CDPRODESTO,
                                                    ESTOQUE.VRFATOCONV, SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV/ESTOQUE.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO ESTOQUE, PRODUTO, ITEMSOLI
                                              WHERE (ITEMSOLI.IDITMCONS = 'N')
                                                AND (NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                                                AND (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (PRODUTO.CDPRODESTO = ESTOQUE.CDPRODESTO)
                                                AND (ESTOQUE.CDARVPROD   BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                                                AND (ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN)
                                              GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO,
                                                       ESTOQUE.VRFATOCONV
                                           ) COMP,
                                           ( SELECT ITEMAUTF.CDFILDEST AS CDFILIAL, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO,
                                                    SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMAUTF, AUTOFORNE
                                              WHERE (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST)
                                                AND (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC)
                                                AND (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN)
                                                AND (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (AUTOFORNE.IDSITUATUAAF IS NULL)
                                                AND (AUTOFORNE.IDAFFORALIM = 'N')
                                                AND (AUTOFORNE.IDAUTOFORNEX = 'N')
                                                AND (ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN)
                                                AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                              GROUP BY ITEMAUTF.CDFILDEST, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO
                                           ) JACOMP
                                     WHERE COMP.CDFILIAL = JACOMP.CDFILIAL (+)
                                       AND COMP.DTPROGENTR = JACOMP.DTENTRITMSOL (+)
                                       AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                                       AND ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) > 0
                                  ) PRODACOMPRAR, FILIAL
                            WHERE (FILIAL.CDFILCENTCMP = P_CDFILIAL OR FILIAL.CDFILIAL = P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL)
                              AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                              AND (FILIAL.CDFILIAL = PRODACOMPRAR.CDFILIAL)
                         ) PRODACOMPRAR,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S'
                         ) PARAMPRODSUP
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COMPLETO.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND COMPLETO.CDREGIAO  = PRODACOMPRAR.CDREGIAO(+)
                     AND PARAMPRODSUP.CDPRODUTO = COMPLETO.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = COMPLETO.CDREGIAO
                     AND NOT EXISTS ( SELECT 1
                                        FROM REFORFIL
                                       WHERE REFORFIL.CDFORNECED = COMPLETO.CDFORNECED
                                         AND REFORFIL.CDFILIAL  = PRODACOMPRAR.CDFILIAL
                                         AND REFORFIL.CDPERIENTR IS NULL)

                  UNION ALL

                  SELECT COMPLETO.CDREGIAO, COMPLETO.NMREGIAO, COMPLETO.CDOPERADOR, COMPLETO.NMOPERADOR,
                         COMPLETO.CDFORNECED, COMPLETO.NRINSJURFORN, COMPLETO.IDTPIJURFORN, COMPLETO.NMRAZSOCFORN,
                         COMPLETO.NMFANTFORN, COMPLETO.CDPRODUTO, COMPLETO.NMPRODUTO, COMPLETO.SGUNIDADE,
                         COMPLETO.CDPRODESTO, COMPLETO.IDTPFRETFORN, COMPLETO.CDMARCA, COMPLETO.NMMARCA,
                         COMPLETO.CDMARCAPADR, COMPLETO.CDARVPROD, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                    FROM PARASUPRI, FILIAL FILI,
                         ( SELECT REGIAO.CDREGIAO, REGIAO.NMREGIAO, OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR,
                                  PRODFORNCOMP.CDFORNECED, FORNECEDOR.NRINSJURFORN, FORNECEDOR.IDTPIJURFORN,
                                  FORNECEDOR.NMRAZSOCFORN, FORNECEDOR.NMFANTFORN, PRODUTO.CDPRODUTO,
                                  PRODUTO.NMPRODUTO, PRODUTO.SGUNIDADE, PRODUTO.CDPRODESTO, FORNECEDOR.IDTPFRETFORN,
                                  NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
                                  REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                                  PRODUTO.CDARVPROD, PARASUPRI.CDMARCA AS CDMARCAPADR
                             FROM OPERADOR, MARCA, PRODUTO, PRODFORNCOMP, MARCPRODCOMP, FORNECEDOR,
                                  REGIAO, PARASUPRI
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0
                              AND PARASUPRI.CDFILIAL = P_CDFILIAL
                              AND ((NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'N') OR (NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
                                                                               PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO))
                              AND ((PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN) OR (P_TPRODUTO = 'T'))
                              AND INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0
                              AND INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0
                              AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
                              AND MARCA.IDMARCAATIVA       = 'A'
                              AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA(+)), MARCPRODCOMP.CDMARCA(+))<> 0
                              AND FORNECEDOR.CDFORNECED = PRODFORNCOMP.CDFORNECED
                              AND PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                              AND PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL(+)
                              AND MARCA.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                              AND (NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S')
                              AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                                 FROM REFOREG
                                                WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                                  AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                              AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                             FROM PRODCOMP, PRODUTO PR
                                            WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                              AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                              AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                              AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   
                                                 FROM QUALIFICACAO
                                                WHERE (FORNECEDOR.CDQUALIF       = QUALIFICACAO.CDQUALIF)
                                                  AND (FORNECEDOR.IDFORNAUTO     = 'N')
                                                  AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ  = 'D' AND
                                                                                             TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF)
                                                                                        OR (PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                              AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   
                                                 FROM QFOMARPROD
                                                WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO)
                                                  AND (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))
                                                  AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND
                                                        QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND
                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                           TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA))
                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                              AND EXISTS ( SELECT QFOMARPROD.CDMARCA 
                                             FROM QFOMARPROD
                                            WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                              AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                            UNION
                                           SELECT PARASUPRI.CDMARCA
                                             FROM PARASUPRI
                                            WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                              AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                              AND NOT EXISTS ( SELECT QFOPRODFORN.CDPRODUTO
                                                 FROM QFOPRODFORN
                                                WHERE (QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)
                                                  AND (QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED)
                                                  AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND
                                                        QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                                                                           ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                             TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN))
                                                                                             OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                                 TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                              AND EXISTS ( SELECT 1
                                             FROM MARCFORNPEDCOL
                                            WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                              AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                            UNION ALL
                                           SELECT 1
                                             FROM DUAL
                                            WHERE NOT EXISTS ( SELECT 1
                                                                 FROM MARCFORNPEDCOL
                                                                WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                         ) COMPLETO,
                         ( SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL, PRODACOMPRAR.CDPRODUTO, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                             FROM ( SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO,
                                           ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                                      FROM ( SELECT ITEMSOLI.CDFILSOLI AS CDFILIAL, ITEMSOLI.DTPROGENTR, PRODUTO.CDPRODUTO, PRODUTO.CDPRODESTO,
                                                    PRODUTO.VRFATOCONV, SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMSOLI
                                              WHERE (ITEMSOLI.IDITMCONS = 'N')
                                                AND (NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                                                AND (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (PRODUTO.CDARVPROD   BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                                                AND (ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN)
                                              GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV
                                           ) COMP,
                                           ( SELECT ITEMAUTF.CDFILDEST AS CDFILIAL, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO,
                                                    SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMAUTF, AUTOFORNE
                                              WHERE (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST)
                                                AND (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC)
                                                AND (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN)
                                                AND (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (AUTOFORNE.IDSITUATUAAF IS NULL)
                                                AND (AUTOFORNE.IDAFFORALIM = 'N')
                                                AND (AUTOFORNE.IDAUTOFORNEX = 'N')
                                                AND (ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN)
                                                AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                              GROUP BY ITEMAUTF.CDFILDEST, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO
                                           ) JACOMP
                                     WHERE COMP.CDFILIAL = JACOMP.CDFILIAL (+)
                                       AND COMP.DTPROGENTR = JACOMP.DTENTRITMSOL (+)
                                       AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                                       AND ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0
                                  ) PRODACOMPRAR, FILIAL
                            WHERE (FILIAL.CDFILCENTCMP = P_CDFILIAL OR FILIAL.CDFILIAL = P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL)
                              AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                              AND (FILIAL.CDFILIAL = PRODACOMPRAR.CDFILIAL)
                         ) PRODACOMPRAR
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COMPLETO.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND COMPLETO.CDREGIAO  = PRODACOMPRAR.CDREGIAO(+)
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND NOT EXISTS ( SELECT 1
                                        FROM REFORFIL
                                       WHERE REFORFIL.CDFORNECED = COMPLETO.CDFORNECED
                                         AND REFORFIL.CDFILIAL  = PRODACOMPRAR.CDFILIAL
                                         AND REFORFIL.CDPERIENTR IS NULL)

                  UNION ALL

                  SELECT COMPLETO.CDREGIAO, COMPLETO.NMREGIAO, COMPLETO.CDOPERADOR, COMPLETO.NMOPERADOR,
                         COMPLETO.CDFORNECED, COMPLETO.NRINSJURFORN, COMPLETO.IDTPIJURFORN, COMPLETO.NMRAZSOCFORN,
                         COMPLETO.NMFANTFORN, COMPLETO.CDPRODUTO, COMPLETO.NMPRODUTO, COMPLETO.SGUNIDADE,
                         COMPLETO.CDPRODESTO, COMPLETO.IDTPFRETFORN, COMPLETO.CDMARCA, COMPLETO.NMMARCA,
                         COMPLETO.CDMARCAPADR, COMPLETO.CDARVPROD, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                    FROM PARASUPRI,
                         ( SELECT REGIAO.CDREGIAO, REGIAO.NMREGIAO, OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR,
                                  PRODFORNCOMP.CDFORNECED, FORNECEDOR.NRINSJURFORN, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NMRAZSOCFORN,
                                  FORNECEDOR.NMFANTFORN, PRODUTO.CDPRODUTO, PRODUTO.NMPRODUTO, PRODUTO.SGUNIDADE, PRODUTO.CDPRODESTO,
                                  FORNECEDOR.IDTPFRETFORN, NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
                                  REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                                  PRODUTO.CDARVPROD, PARASUPRI.CDMARCA AS CDMARCAPADR
                             FROM OPERADOR, MARCA, PRODUTO, PRODFORNCOMP, MARCPRODCOMP, FORNECEDOR, REGIAO, PARASUPRI
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0
                              AND PARASUPRI.CDFILIAL = P_CDFILIAL
                              AND ((NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'N') OR (NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
                                                                               PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO))
                              AND ((PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN) OR (P_TPRODUTO = 'T'))
                              AND INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0
                              AND INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0
                              AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
                              AND MARCA.IDMARCAATIVA       = 'A'
                              AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA(+)), MARCPRODCOMP.CDMARCA(+))<> 0
                              AND FORNECEDOR.CDFORNECED = PRODFORNCOMP.CDFORNECED
                              AND PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                              AND PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL(+)
                              AND MARCA.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                              AND (NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S')
                              AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                                 FROM REFOREG
                                                WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                                  AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                              AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                             FROM PRODCOMP, PRODUTO PR
                                            WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                              AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                              AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                              AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   
                                                 FROM QUALIFICACAO
                                                WHERE (FORNECEDOR.CDQUALIF       = QUALIFICACAO.CDQUALIF)
                                                  AND (FORNECEDOR.IDFORNAUTO     = 'N')
                                                  AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ  = 'D' AND
                                                                                             TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF) OR (PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                                                                            TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                              AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   
                                                 FROM QFOMARPROD
                                                WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO)
                                                  AND (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))
                                                  AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND
                                                                                                                           ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                                                             TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                                                                                                                            (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                              AND EXISTS ( SELECT QFOMARPROD.CDMARCA 
                                             FROM QFOMARPROD
                                            WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                              AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                            UNION
                                           SELECT PARASUPRI.CDMARCA
                                             FROM PARASUPRI
                                            WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                              AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                              AND NOT EXISTS ( SELECT QFOPRODFORN.CDPRODUTO
                                                 FROM QFOPRODFORN
                                                WHERE (QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)
                                                  AND (QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED)
                                                  AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND
                                                        QFOPRODFORN.IDFORNAUTOR = 'N') OR (QFOPRODFORN.IDFORNAPROV = 'S' AND
                                                                                           ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                             TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                                                                                            (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                             TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                              AND EXISTS (  SELECT 1
                                              FROM MARCFORNPEDCOL
                                             WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                               AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                             UNION ALL
                                            SELECT 1
                                              FROM DUAL
                                             WHERE NOT EXISTS (  SELECT 1
                                                                   FROM MARCFORNPEDCOL
                                                                  WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                         ) COMPLETO,
                         ( SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL, PRODACOMPRAR.CDPRODUTO, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                             FROM ( SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO, ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                                      FROM ( SELECT ITEMSOLI.CDFILSOLI AS CDFILIAL, ITEMSOLI.DTPROGENTR, PRODUTO.CDPRODUTO, PRODUTO.CDPRODESTO, PRODUTO.VRFATOCONV,
                                                    SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMSOLI
                                              WHERE (ITEMSOLI.IDITMCONS = 'N')
                                                AND (NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                                                AND (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (PRODUTO.CDARVPROD   BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                                                AND (ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN)
                                              GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV
                                           ) COMP,
                                           ( SELECT ITEMAUTF.CDFILDEST AS CDFILIAL, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO,
                                                    SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMAUTF, AUTOFORNE
                                              WHERE (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST)
                                                AND (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC)
                                                AND (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN)
                                                AND (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (AUTOFORNE.IDSITUATUAAF IS NULL)
                                                AND (AUTOFORNE.IDAFFORALIM = 'N')
                                                AND (AUTOFORNE.IDAUTOFORNEX = 'N')
                                                AND (ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN)
                                                AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                              GROUP BY ITEMAUTF.CDFILDEST, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO
                                           ) JACOMP
                                     WHERE COMP.CDFILIAL = JACOMP.CDFILIAL (+)
                                       AND COMP.DTPROGENTR = JACOMP.DTENTRITMSOL (+)
                                       AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                                       AND ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0
                                  ) PRODACOMPRAR, FILIAL
                            WHERE (FILIAL.CDFILCENTCMP = P_CDFILIAL OR FILIAL.CDFILIAL = P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL)
                              AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                              AND (FILIAL.CDFILIAL = PRODACOMPRAR.CDFILIAL)
                         ) PRODACOMPRAR,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S'
                         ) PARAMPRODSUP
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COMPLETO.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND COMPLETO.CDREGIAO  = PRODACOMPRAR.CDREGIAO(+)
                     AND PARAMPRODSUP.CDPRODUTO = COMPLETO.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = COMPLETO.CDREGIAO
                     AND NOT EXISTS ( SELECT 1
                                        FROM REFORFIL
                                       WHERE REFORFIL.CDFORNECED = COMPLETO.CDFORNECED
                                         AND REFORFIL.CDFILIAL  = PRODACOMPRAR.CDFILIAL
                                         AND REFORFIL.CDPERIENTR IS NULL)
                )
          GROUP BY CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
                  IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
                  CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD;
   BEGIN
      FOR CONTADOR IN PED_COL_TODOS LOOP
         V_PIPE.EXTEND;
         V_PIPE(V_INDICE) := CONTADOR;
         PIPE ROW(V_PIPE(V_INDICE));
         V_INDICE := V_INDICE+1;
      END LOOP;
      RETURN;
   END PED_COL_TODOS;

   FUNCTION PED_COL_ACOMP( P_CDCOMPRADOR   VARCHAR2,
                           P_CDFILIAL      VARCHAR2,
                           P_CDPRODINI     VARCHAR2,
                           P_CDPRODFIN     VARCHAR2,
                           P_TPRODUTO      VARCHAR2,
                           P_CDFORNECED    VARCHAR2,
                           P_CDREGIAO      VARCHAR2,
                           P_CDMARCA       VARCHAR2,
                           P_CDFILIPROC    VARCHAR2,
                           P_DTINI         DATE,
                           P_DTFIN         DATE) RETURN TABELA PIPELINED IS

      V_PIPE TABELA := TABELA();
      V_INDICE NUMBER := 1;

      CURSOR PED_COL_ACOMP IS
         SELECT CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
                IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
                CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD,SUM(QTACOMPRAR) AS QTACOMPRAR,
                ' ' AS NRCOMPRA
           FROM ( SELECT COMPLETO.CDREGIAO, COMPLETO.NMREGIAO, COMPLETO.CDOPERADOR, COMPLETO.NMOPERADOR,
                         COMPLETO.CDFORNECED, COMPLETO.NRINSJURFORN, COMPLETO.IDTPIJURFORN, COMPLETO.NMRAZSOCFORN,
                         COMPLETO.NMFANTFORN, COMPLETO.CDPRODUTO, COMPLETO.NMPRODUTO, COMPLETO.SGUNIDADE,
                         COMPLETO.CDPRODESTO, COMPLETO.IDTPFRETFORN, COMPLETO.CDMARCA, COMPLETO.NMMARCA,
                         COMPLETO.CDMARCAPADR, COMPLETO.CDARVPROD, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                    FROM PARASUPRI, FILIAL FILI,
                         ( SELECT REGIAO.CDREGIAO, REGIAO.NMREGIAO, OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR,
                                  PRODFORNCOMP.CDFORNECED, FORNECEDOR.NRINSJURFORN, FORNECEDOR.IDTPIJURFORN,
                                  FORNECEDOR.NMRAZSOCFORN, FORNECEDOR.NMFANTFORN, PRODUTO.CDPRODUTO,
                                  PRODUTO.NMPRODUTO, PRODUTO.SGUNIDADE, PRODUTO.CDPRODESTO, FORNECEDOR.IDTPFRETFORN,
                                  NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
                                  REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                                  PRODUTO.CDARVPROD, PARASUPRI.CDMARCA AS CDMARCAPADR
                             FROM OPERADOR, MARCA, PRODUTO, PRODFORNCOMP, MARCPRODCOMP, FORNECEDOR,
                                  REGIAO, PARASUPRI
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0
                              AND PARASUPRI.CDFILIAL = P_CDFILIAL
                              AND ((NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'N') OR (NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
                                                                               PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO))
                              AND ((PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN) OR (P_TPRODUTO = 'T'))
                              AND INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0
                              AND INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0
                              AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
                              AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA(+)), MARCPRODCOMP.CDMARCA(+))<> 0
                              AND FORNECEDOR.CDFORNECED = PRODFORNCOMP.CDFORNECED
                              AND PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                              AND PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL(+)
                              AND MARCA.IDMARCAATIVA = 'A'
                              AND MARCA.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                              AND NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S'
                              AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                                 FROM REFOREG
                                                WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                                  AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                              AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                             FROM PRODCOMP, PRODUTO PR
                                            WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                              AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                              AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                              AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                                                 FROM QUALIFICACAO
                                                WHERE (FORNECEDOR.CDQUALIF       = QUALIFICACAO.CDQUALIF)
                                                  AND (FORNECEDOR.IDFORNAUTO     = 'N')
                                                  AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ  = 'D' AND
                                                                                             TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF)
                                                                                        OR (PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                              AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                                                 FROM QFOMARPROD
                                                WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO)
                                                  AND (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))
                                                  AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND
                                                        QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND
                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA))
                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                          TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                              AND EXISTS ( SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                                             FROM QFOMARPROD
                                            WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                              AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                            UNION
                                           SELECT PARASUPRI.CDMARCA
                                             FROM PARASUPRI
                                            WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                              AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                                              AND NOT EXISTS (SELECT QFOPRODFORN.CDPRODUTO /* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                                                                FROM QFOPRODFORN
                                                               WHERE (QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)
                                                                 AND (QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED)
                                                                 AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND
                                                                       QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                                            TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN))
                                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                                          TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                              AND EXISTS ( SELECT 1
                                             FROM MARCFORNPEDCOL
                                            WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                              AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                            UNION ALL
                                           SELECT 1
                                             FROM DUAL
                                            WHERE NOT EXISTS (SELECT 1
                                                                FROM MARCFORNPEDCOL
                                                               WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                         ) COMPLETO,
                         ( SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL, PRODACOMPRAR.CDPRODUTO, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                             FROM ( SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO, ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) AS QTACOMPRAR
                                      FROM ( SELECT ITEMSOLI.CDFILSOLI AS CDFILIAL, ITEMSOLI.DTPROGENTR, ESTOQUE.CDPRODUTO, ESTOQUE.CDPRODESTO,
                                                     ESTOQUE.VRFATOCONV, SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV/ESTOQUE.VRFATOCONV) AS QTDECOMP
                                                FROM PRODUTO ESTOQUE, PRODUTO, ITEMSOLI
                                               WHERE (ITEMSOLI.IDITMCONS = 'N')
                                                 AND (NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                                                 AND (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                 AND (PRODUTO.CDPRODESTO = ESTOQUE.CDPRODESTO)
                                                 AND (ESTOQUE.CDARVPROD   BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                                                 AND (ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN)
                                               GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO,
                                                        ESTOQUE.VRFATOCONV
                                           ) COMP,
                                           ( SELECT ITEMAUTF.CDFILDEST AS CDFILIAL, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO,
                                                    SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMAUTF, AUTOFORNE
                                              WHERE (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST)
                                                AND (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC)
                                                AND (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN)
                                                AND (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (AUTOFORNE.IDSITUATUAAF IS NULL)
                                                AND (AUTOFORNE.IDAFFORALIM = 'N')
                                                AND (AUTOFORNE.IDAUTOFORNEX = 'N')
                                                AND (ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN)
                                                AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                              GROUP BY ITEMAUTF.CDFILDEST, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO
                                           ) JACOMP
                                     WHERE COMP.CDFILIAL = JACOMP.CDFILIAL (+)
                                       AND COMP.DTPROGENTR = JACOMP.DTENTRITMSOL (+)
                                       AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                                       AND ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) > 0
                                  ) PRODACOMPRAR, FILIAL
                            WHERE ((FILIAL.CDFILCENTCMP = P_CDFILIAL) OR (FILIAL.CDFILIAL = P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL))
                              AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                              AND (FILIAL.CDFILIAL = PRODACOMPRAR.CDFILIAL)
                         ) PRODACOMPRAR
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COMPLETO.CDPRODUTO = PRODACOMPRAR.CDPRODUTO
                     AND COMPLETO.CDREGIAO  = PRODACOMPRAR.CDREGIAO
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND NOT EXISTS (SELECT 1
                                       FROM REFORFIL
                                      WHERE REFORFIL.CDFORNECED = COMPLETO.CDFORNECED
                                        AND REFORFIL.CDFILIAL   = PRODACOMPRAR.CDFILIAL
                                        AND REFORFIL.CDPERIENTR IS NULL)

                  UNION ALL

                  SELECT COMPLETO.CDREGIAO, COMPLETO.NMREGIAO, COMPLETO.CDOPERADOR, COMPLETO.NMOPERADOR,
                         COMPLETO.CDFORNECED, COMPLETO.NRINSJURFORN, COMPLETO.IDTPIJURFORN, COMPLETO.NMRAZSOCFORN,
                         COMPLETO.NMFANTFORN, COMPLETO.CDPRODUTO, COMPLETO.NMPRODUTO, COMPLETO.SGUNIDADE,
                         COMPLETO.CDPRODESTO, COMPLETO.IDTPFRETFORN, COMPLETO.CDMARCA, COMPLETO.NMMARCA,
                         COMPLETO.CDMARCAPADR, COMPLETO.CDARVPROD, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                    FROM PARASUPRI,
                         ( SELECT REGIAO.CDREGIAO, REGIAO.NMREGIAO, OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR,
                                  PRODFORNCOMP.CDFORNECED, FORNECEDOR.NRINSJURFORN, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NMRAZSOCFORN,
                                  FORNECEDOR.NMFANTFORN, PRODUTO.CDPRODUTO, PRODUTO.NMPRODUTO, PRODUTO.SGUNIDADE,
                                  PRODUTO.CDPRODESTO, FORNECEDOR.IDTPFRETFORN, NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
                                  REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                                  PRODUTO.CDARVPROD, PARASUPRI.CDMARCA AS CDMARCAPADR
                             FROM OPERADOR, MARCA, PRODUTO, PRODFORNCOMP, MARCPRODCOMP, FORNECEDOR,
                                  REGIAO, PARASUPRI
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0
                              AND PARASUPRI.CDFILIAL = P_CDFILIAL
                              AND ((NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'N') OR (NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
                                                                               PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO))
                              AND ((PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN) OR (P_TPRODUTO = 'T'))
                              AND INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0
                              AND INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0
                              AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
                              AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA(+)), MARCPRODCOMP.CDMARCA(+))<> 0
                              AND FORNECEDOR.CDFORNECED = PRODFORNCOMP.CDFORNECED
                              AND PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                              AND PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL(+)
                              AND MARCA.IDMARCAATIVA       = 'A'
                              AND MARCA.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                              AND (NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S')
                              AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                                 FROM REFOREG
                                                WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                                  AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                              AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                             FROM PRODCOMP, PRODUTO PR
                                            WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                              AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                              AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                              AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                                                 FROM QUALIFICACAO
                                                WHERE (FORNECEDOR.CDQUALIF       = QUALIFICACAO.CDQUALIF)
                                                  AND (FORNECEDOR.IDFORNAUTO     = 'N')
                                                  AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ  = 'D' AND
                                                                                             TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF)
                                                                                        OR (PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                              AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                                                 FROM QFOMARPROD
                                                WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO)
                                                  AND (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))
                                                  AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND
                                                        QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND
                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA))
                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                          TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                              AND EXISTS ( SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                                             FROM QFOMARPROD
                                            WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                              AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                            UNION
                                           SELECT PARASUPRI.CDMARCA
                                             FROM PARASUPRI
                                            WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                              AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                              AND NOT EXISTS (SELECT QFOPRODFORN.CDPRODUTO /* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                                                FROM QFOPRODFORN
                                               WHERE (QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)
                                                 AND (QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED)
                                                 AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND
                                                       QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN))
                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                          TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                              AND EXISTS ( SELECT 1
                                             FROM MARCFORNPEDCOL
                                            WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                              AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                            UNION ALL
                                           SELECT 1
                                             FROM DUAL
                                            WHERE NOT EXISTS ( SELECT 1
                                                                 FROM MARCFORNPEDCOL
                                                                WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                         ) COMPLETO,
                         ( SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL, PRODACOMPRAR.CDPRODUTO, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                             FROM ( SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO,
                                           ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) AS QTACOMPRAR
                                      FROM ( SELECT ITEMSOLI.CDFILSOLI AS CDFILIAL, ITEMSOLI.DTPROGENTR, ESTOQUE.CDPRODUTO, ESTOQUE.CDPRODESTO,
                                                    ESTOQUE.VRFATOCONV, SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV/ESTOQUE.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO ESTOQUE, PRODUTO, ITEMSOLI
                                              WHERE (ITEMSOLI.IDITMCONS = 'N')
                                                AND (NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                                                AND (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (PRODUTO.CDPRODESTO = ESTOQUE.CDPRODESTO)
                                                AND (ESTOQUE.CDARVPROD   BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                                                AND (ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN)
                                              GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO,
                                                       ESTOQUE.VRFATOCONV
                                           ) COMP,
                                           ( SELECT ITEMAUTF.CDFILDEST AS CDFILIAL, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO,
                                                    SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMAUTF, AUTOFORNE
                                              WHERE (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST)
                                                AND (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC)
                                                AND (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN)
                                                AND (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (AUTOFORNE.IDSITUATUAAF IS NULL)
                                                AND (AUTOFORNE.IDAFFORALIM = 'N')
                                                AND (AUTOFORNE.IDAUTOFORNEX = 'N')
                                                AND (ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN)
                                                AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                              GROUP BY ITEMAUTF.CDFILDEST, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO
                                           ) JACOMP
                                     WHERE COMP.CDFILIAL = JACOMP.CDFILIAL (+)
                                       AND COMP.DTPROGENTR = JACOMP.DTENTRITMSOL (+)
                                       AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                                       AND ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) > 0
                                  ) PRODACOMPRAR, FILIAL
                            WHERE (FILIAL.CDFILCENTCMP = P_CDFILIAL OR FILIAL.CDFILIAL = P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL)
                              AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                              AND (FILIAL.CDFILIAL = PRODACOMPRAR.CDFILIAL)
                         ) PRODACOMPRAR,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S'
                         ) PARAMPRODSUP
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COMPLETO.CDPRODUTO = PRODACOMPRAR.CDPRODUTO
                     AND COMPLETO.CDREGIAO  = PRODACOMPRAR.CDREGIAO
                     AND PARAMPRODSUP.CDPRODUTO = COMPLETO.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = COMPLETO.CDREGIAO
                     AND NOT EXISTS ( SELECT 1
                                        FROM REFORFIL
                                       WHERE REFORFIL.CDFORNECED = COMPLETO.CDFORNECED
                                         AND REFORFIL.CDFILIAL  = PRODACOMPRAR.CDFILIAL
                                         AND REFORFIL.CDPERIENTR IS NULL)

                  /*######################### IDCONSPRSOL DA PARASUPRI ###############################################*/
                  UNION ALL

                  SELECT COMPLETO.CDREGIAO, COMPLETO.NMREGIAO, COMPLETO.CDOPERADOR, COMPLETO.NMOPERADOR,
                         COMPLETO.CDFORNECED, COMPLETO.NRINSJURFORN, COMPLETO.IDTPIJURFORN, COMPLETO.NMRAZSOCFORN,
                         COMPLETO.NMFANTFORN, COMPLETO.CDPRODUTO, COMPLETO.NMPRODUTO, COMPLETO.SGUNIDADE,
                         COMPLETO.CDPRODESTO, COMPLETO.IDTPFRETFORN, COMPLETO.CDMARCA, COMPLETO.NMMARCA,
                         COMPLETO.CDMARCAPADR, COMPLETO.CDARVPROD, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                    FROM PARASUPRI, FILIAL FILI,
                         ( SELECT REGIAO.CDREGIAO, REGIAO.NMREGIAO, OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR,
                                  PRODFORNCOMP.CDFORNECED, FORNECEDOR.NRINSJURFORN, FORNECEDOR.IDTPIJURFORN,
                                  FORNECEDOR.NMRAZSOCFORN, FORNECEDOR.NMFANTFORN, PRODUTO.CDPRODUTO,
                                  PRODUTO.NMPRODUTO, PRODUTO.SGUNIDADE, PRODUTO.CDPRODESTO, FORNECEDOR.IDTPFRETFORN,
                                  NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
                                  REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                                  PRODUTO.CDARVPROD, PARASUPRI.CDMARCA AS CDMARCAPADR
                             FROM OPERADOR, MARCA, PRODUTO, PRODFORNCOMP, MARCPRODCOMP, FORNECEDOR,
                                  REGIAO, PARASUPRI
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0
                              AND PARASUPRI.CDFILIAL = P_CDFILIAL
                              AND ((NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'N') OR (NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
                                                                               PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO))
                              AND ((PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN) OR (P_TPRODUTO = 'T'))
                              AND INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0
                              AND INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0
                              AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
                              AND MARCA.IDMARCAATIVA       = 'A'
                              AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA(+)), MARCPRODCOMP.CDMARCA(+))<> 0
                              AND FORNECEDOR.CDFORNECED = PRODFORNCOMP.CDFORNECED
                              AND PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                              AND PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL(+)
                              AND MARCA.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                              AND (NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S')
                              AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                                 FROM REFOREG
                                                WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                                  AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                              AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                             FROM PRODCOMP, PRODUTO PR
                                            WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                              AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                              AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                              AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                                                 FROM QUALIFICACAO
                                                WHERE (FORNECEDOR.CDQUALIF       = QUALIFICACAO.CDQUALIF)
                                                  AND (FORNECEDOR.IDFORNAUTO     = 'N')
                                                  AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ  = 'D' AND
                                                                                             TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF)
                                                                                        OR (PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                            TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                              AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                                                 FROM QFOMARPROD
                                                WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO)
                                                  AND (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))
                                                  AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND
                                                        QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND
                                                                                          ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                           TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA))
                                                                                      OR (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                              AND EXISTS ( SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                                             FROM QFOMARPROD
                                            WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                              AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                            UNION
                                           SELECT PARASUPRI.CDMARCA
                                             FROM PARASUPRI
                                            WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                              AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                              AND NOT EXISTS ( SELECT QFOPRODFORN.CDPRODUTO /* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                                                 FROM QFOPRODFORN
                                                WHERE (QFOPRODFORN.CDPRODUTO  = PRODFORNCOMP.CDPRODCOMPL)
                                                  AND (QFOPRODFORN.CDFORNECED = PRODFORNCOMP.CDFORNECED)
                                                  AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND
                                                        QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                                                                           ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                             TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN))
                                                                                             OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                                 TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                              AND EXISTS ( SELECT 1
                                             FROM MARCFORNPEDCOL
                                            WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                              AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                            UNION ALL
                                           SELECT 1
                                             FROM DUAL
                                            WHERE NOT EXISTS ( SELECT 1
                                                                 FROM MARCFORNPEDCOL
                                                                WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                         ) COMPLETO,
                         ( SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL, PRODACOMPRAR.CDPRODUTO, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                             FROM ( SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO,
                                           ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                                      FROM ( SELECT ITEMSOLI.CDFILSOLI AS CDFILIAL, ITEMSOLI.DTPROGENTR, PRODUTO.CDPRODUTO, PRODUTO.CDPRODESTO,
                                                    PRODUTO.VRFATOCONV, SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMSOLI
                                              WHERE (ITEMSOLI.IDITMCONS = 'N')
                                                AND (NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                                                AND (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (PRODUTO.CDARVPROD   BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                                                AND (ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN)
                                              GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV
                                           ) COMP,
                                           ( SELECT ITEMAUTF.CDFILDEST AS CDFILIAL, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO,
                                                    SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMAUTF, AUTOFORNE
                                              WHERE (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST)
                                                AND (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC)
                                                AND (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN)
                                                AND (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (AUTOFORNE.IDSITUATUAAF IS NULL)
                                                AND (AUTOFORNE.IDAFFORALIM = 'N')
                                                AND (AUTOFORNE.IDAUTOFORNEX = 'N')
                                                AND (ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN)
                                                AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                              GROUP BY ITEMAUTF.CDFILDEST, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO
                                           ) JACOMP
                                     WHERE COMP.CDFILIAL = JACOMP.CDFILIAL (+)
                                       AND COMP.DTPROGENTR = JACOMP.DTENTRITMSOL (+)
                                       AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                                       AND ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0
                                  ) PRODACOMPRAR, FILIAL
                            WHERE (FILIAL.CDFILCENTCMP = P_CDFILIAL OR FILIAL.CDFILIAL = P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL)
                              AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                              AND (FILIAL.CDFILIAL = PRODACOMPRAR.CDFILIAL)
                         ) PRODACOMPRAR
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COMPLETO.CDPRODUTO = PRODACOMPRAR.CDPRODUTO
                     AND COMPLETO.CDREGIAO  = PRODACOMPRAR.CDREGIAO
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND NOT EXISTS ( SELECT 1
                                        FROM REFORFIL
                                       WHERE REFORFIL.CDFORNECED = COMPLETO.CDFORNECED
                                         AND REFORFIL.CDFILIAL  = PRODACOMPRAR.CDFILIAL
                                         AND REFORFIL.CDPERIENTR IS NULL)

                  UNION ALL

                  SELECT COMPLETO.CDREGIAO, COMPLETO.NMREGIAO, COMPLETO.CDOPERADOR, COMPLETO.NMOPERADOR,
                         COMPLETO.CDFORNECED, COMPLETO.NRINSJURFORN, COMPLETO.IDTPIJURFORN, COMPLETO.NMRAZSOCFORN,
                         COMPLETO.NMFANTFORN, COMPLETO.CDPRODUTO, COMPLETO.NMPRODUTO, COMPLETO.SGUNIDADE,
                         COMPLETO.CDPRODESTO, COMPLETO.IDTPFRETFORN, COMPLETO.CDMARCA, COMPLETO.NMMARCA,
                         COMPLETO.CDMARCAPADR, COMPLETO.CDARVPROD, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                    FROM PARASUPRI,
                         ( SELECT REGIAO.CDREGIAO, REGIAO.NMREGIAO, OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR,
                                  PRODFORNCOMP.CDFORNECED, FORNECEDOR.NRINSJURFORN, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NMRAZSOCFORN,
                                  FORNECEDOR.NMFANTFORN, PRODUTO.CDPRODUTO, PRODUTO.NMPRODUTO, PRODUTO.SGUNIDADE, PRODUTO.CDPRODESTO,
                                  FORNECEDOR.IDTPFRETFORN, NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
                                  REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                                  PRODUTO.CDARVPROD, PARASUPRI.CDMARCA AS CDMARCAPADR
                             FROM OPERADOR, MARCA, PRODUTO, PRODFORNCOMP, MARCPRODCOMP, FORNECEDOR, REGIAO, PARASUPRI
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0
                              AND PARASUPRI.CDFILIAL = P_CDFILIAL
                              AND ((NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'N') OR (NVL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
                                                                               PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO))
                              AND ((PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN) OR (P_TPRODUTO = 'T'))
                              AND INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0
                              AND INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0
                              AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
                              AND MARCA.IDMARCAATIVA       = 'A'
                              AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA(+)), MARCPRODCOMP.CDMARCA(+))<> 0
                              AND FORNECEDOR.CDFORNECED = PRODFORNCOMP.CDFORNECED
                              AND PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                              AND PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL(+)
                              AND MARCA.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                              AND (NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S')
                              AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                                 FROM REFOREG
                                                WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                                  AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                              AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                             FROM PRODCOMP, PRODUTO PR
                                            WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                              AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                              AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                              AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                                                 FROM QUALIFICACAO
                                                WHERE (FORNECEDOR.CDQUALIF       = QUALIFICACAO.CDQUALIF)
                                                  AND (FORNECEDOR.IDFORNAUTO     = 'N')
                                                  AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ  = 'D' AND
                                                                                             TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF) OR (PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                                                                            TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                              AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                                                 FROM QFOMARPROD
                                                WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO)
                                                  AND (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))
                                                  AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND
                                                                                                                           ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                                                             TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                                                                                                                            (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                              AND EXISTS ( SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                                             FROM QFOMARPROD
                                            WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                              AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                            UNION
                                           SELECT PARASUPRI.CDMARCA
                                             FROM PARASUPRI
                                            WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                              AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                              AND NOT EXISTS ( SELECT QFOPRODFORN.CDPRODUTO /* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                                                 FROM QFOPRODFORN
                                                WHERE (QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)
                                                  AND (QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED)
                                                  AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND
                                                        QFOPRODFORN.IDFORNAUTOR = 'N') OR (QFOPRODFORN.IDFORNAPROV = 'S' AND
                                                                                           ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                                             TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                                                                                            (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                             TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                              AND EXISTS (  SELECT 1
                                              FROM MARCFORNPEDCOL
                                             WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                               AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                             UNION ALL
                                            SELECT 1
                                              FROM DUAL
                                             WHERE NOT EXISTS (  SELECT 1
                                                                   FROM MARCFORNPEDCOL
                                                                  WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                         ) COMPLETO,
                         ( SELECT FILIAL.CDREGIAO, PRODACOMPRAR.CDFILIAL, PRODACOMPRAR.CDPRODUTO, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR
                             FROM ( SELECT COMP.CDFILIAL, COMP.DTPROGENTR, COMP.CDPRODUTO, ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                                      FROM ( SELECT ITEMSOLI.CDFILSOLI AS CDFILIAL, ITEMSOLI.DTPROGENTR, PRODUTO.CDPRODUTO, PRODUTO.CDPRODESTO, PRODUTO.VRFATOCONV,
                                                    SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMSOLI
                                              WHERE (ITEMSOLI.IDITMCONS = 'N')
                                                AND (NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                                                AND (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (PRODUTO.CDARVPROD   BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                                                AND (ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN)
                                              GROUP BY ITEMSOLI.CDFILSOLI, ITEMSOLI.DTPROGENTR, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV
                                           ) COMP,
                                           ( SELECT ITEMAUTF.CDFILDEST AS CDFILIAL, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO,
                                                    SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                               FROM PRODUTO, ITEMAUTF, AUTOFORNE
                                              WHERE (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST)
                                                AND (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC)
                                                AND (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN)
                                                AND (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO)
                                                AND (AUTOFORNE.IDSITUATUAAF IS NULL)
                                                AND (AUTOFORNE.IDAFFORALIM = 'N')
                                                AND (AUTOFORNE.IDAUTOFORNEX = 'N')
                                                AND (ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN)
                                                AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                              GROUP BY ITEMAUTF.CDFILDEST, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODESTO
                                           ) JACOMP
                                     WHERE COMP.CDFILIAL = JACOMP.CDFILIAL (+)
                                       AND COMP.DTPROGENTR = JACOMP.DTENTRITMSOL (+)
                                       AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                                       AND ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0
                                  ) PRODACOMPRAR, FILIAL
                            WHERE (FILIAL.CDFILCENTCMP = P_CDFILIAL OR FILIAL.CDFILIAL = P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL)
                              AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                              AND (FILIAL.CDFILIAL = PRODACOMPRAR.CDFILIAL)
                         ) PRODACOMPRAR,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S'
                         ) PARAMPRODSUP
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COMPLETO.CDPRODUTO = PRODACOMPRAR.CDPRODUTO
                     AND COMPLETO.CDREGIAO  = PRODACOMPRAR.CDREGIAO
                     AND PARAMPRODSUP.CDPRODUTO = COMPLETO.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = COMPLETO.CDREGIAO
                     AND NOT EXISTS ( SELECT 1
                                        FROM REFORFIL
                                       WHERE REFORFIL.CDFORNECED = COMPLETO.CDFORNECED
                                         AND REFORFIL.CDFILIAL  = PRODACOMPRAR.CDFILIAL
                                         AND REFORFIL.CDPERIENTR IS NULL)
                )
          GROUP BY CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
                  IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
                  CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD;
   BEGIN
      FOR CONTADOR IN PED_COL_ACOMP LOOP
         V_PIPE.EXTEND;
         V_PIPE(V_INDICE) := CONTADOR;
         PIPE ROW(V_PIPE(V_INDICE));
         V_INDICE := V_INDICE+1;
      END LOOP;
      RETURN;
   END PED_COL_ACOMP;

   FUNCTION PED_COL_COTACAO( P_CDCOMPRADOR   VARCHAR2,
                             P_CDFILIAL      VARCHAR2,
                             P_CDPRODINI     VARCHAR2,
                             P_CDPRODFIN     VARCHAR2,
                             P_TPRODUTO      VARCHAR2,
                             P_CDFORNECED    VARCHAR2,
                             P_CDREGIAO      VARCHAR2,
                             P_CDMARCA       VARCHAR2,
                             P_CDFILIPROC    VARCHAR2,
                             P_NRCOLEPRECO   VARCHAR2,
                             P_DTINI         DATE,
                             P_DTFIN         DATE) RETURN TABELA PIPELINED IS

      V_PIPE TABELA := TABELA();
      V_INDICE NUMBER := 1;

      CURSOR PED_COL_COTACAO IS
         SELECT A.CDREGIAO, A.NMREGIAO, A.CDOPERADOR, A.NMOPERADOR, A.CDFORNECED, A.NRINSJURFORN,
                A.IDTPIJURFORN, A.NMRAZSOCFORN, A.NMFANTFORN, A.CDPRODUTO, A.NMPRODUTO, A.SGUNIDADE,
                A.CDPRODESTO, A.IDTPFRETFORN, A.CDMARCA, A.NMMARCA, A.CDMARCAPADR, A.CDARVPROD,
                A.QTACOMPRAR, ' ' AS NRCOMPRA
           FROM ( SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, FORNECEDOR.DTVALQUALIF, FORNECEDOR.IDFORNAUTO, FORNECEDOR.CDQUALIF,
                         PARASUPRI.IDULTIDTVALQ, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN,
                         NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO,
                         OPERADOR.NMOPERADOR, REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                         MARCA.CDMARCA AS CDMARCAPADR, ' ' AS NRCOMPRA
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, FILIAL FILI,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN,
                                  DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COLETAPR.CDFILIAL    = P_CDFILIAL
                     AND COLETAPR.NRCOLEPRECO = P_NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR  = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL    = P_CDFILIAL
                     AND ITEMCOLE.NRCOLEPRECO = COLETAPR.NRCOLEPRECO
                     AND (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA  = 'A'
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND EXISTS (   SELECT 1
                                      FROM MARCFORNPEDCOL
                                     WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                       AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                     UNION ALL
                                    SELECT 1
                                      FROM DUAL
                                     WHERE NOT EXISTS (SELECT 1
                                                         FROM MARCFORNPEDCOL
                                                        WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))


                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, FORNECEDOR.DTVALQUALIF, FORNECEDOR.IDFORNAUTO, FORNECEDOR.CDQUALIF,
                         PARASUPRI.IDULTIDTVALQ, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR,
                         REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR, REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                         MARCA.CDMARCA AS CDMARCAPADR, ' ' AS NRCOMPRA
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN,
                                  DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COLETAPR.CDFILIAL    = P_CDFILIAL
                     AND COLETAPR.NRCOLEPRECO = P_NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR  = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL    = P_CDFILIAL
                     AND ITEMCOLE.NRCOLEPRECO = COLETAPR.NRCOLEPRECO
                     AND (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND PARAMPRODSUP.CDPRODUTO = ITEMCOLE.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = ITEMCOLE.CDREGIAO
                     AND EXISTS ( SELECT 1
                                    FROM MARCFORNPEDCOL
                                   WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                     AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                   UNION ALL
                                  SELECT 1
                                    FROM DUAL
                                   WHERE NOT EXISTS (SELECT 1
                                                       FROM MARCFORNPEDCOL
                                                      WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))

                  /*################################## IDCONSPRSOL DA PARASUPRI #############################################*/

                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, FORNECEDOR.DTVALQUALIF, FORNECEDOR.IDFORNAUTO, FORNECEDOR.CDQUALIF,
                         PARASUPRI.IDULTIDTVALQ, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR,
                         REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR, REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                         MARCA.CDMARCA AS CDMARCAPADR, ' ' AS NRCOMPRA
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, FILIAL FILI,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 )  OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN, DTVALQUALIF,
                                  IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COLETAPR.CDFILIAL    = P_CDFILIAL
                     AND COLETAPR.NRCOLEPRECO = P_NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR  = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL    = P_CDFILIAL
                     AND ITEMCOLE.NRCOLEPRECO = COLETAPR.NRCOLEPRECO
                     AND (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA  = 'A'
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND EXISTS ( SELECT 1
                                    FROM MARCFORNPEDCOL
                                   WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                     AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                   UNION ALL
                                  SELECT 1
                                    FROM DUAL
                                   WHERE NOT EXISTS ( SELECT 1
                                                        FROM MARCFORNPEDCOL
                                                       WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))

                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, FORNECEDOR.DTVALQUALIF, FORNECEDOR.IDFORNAUTO, FORNECEDOR.CDQUALIF,
                         PARASUPRI.IDULTIDTVALQ, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR,
                         REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR, REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                         MARCA.CDMARCA AS CDMARCAPADR, ' ' AS NRCOMPRA
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 )  OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN, DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP

                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COLETAPR.CDFILIAL    = P_CDFILIAL
                     AND COLETAPR.NRCOLEPRECO = P_NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR  = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL    = P_CDFILIAL
                     AND ITEMCOLE.NRCOLEPRECO = COLETAPR.NRCOLEPRECO
                     AND (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND PARAMPRODSUP.CDPRODUTO = ITEMCOLE.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = ITEMCOLE.CDREGIAO
                     AND EXISTS ( SELECT 1
                                    FROM MARCFORNPEDCOL
                                   WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                     AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                   UNION ALL
                                  SELECT 1
                                    FROM DUAL
                                   WHERE NOT EXISTS (SELECT 1
                                                       FROM MARCFORNPEDCOL
                                                      WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                ) A, MARCPRODCOMP, PARASUPRI, PRODFORNCOMP
          WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
            AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
            AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA(+)), MARCPRODCOMP.CDMARCA(+)) <> 0
            AND A.CDFORNECED = PRODFORNCOMP.CDFORNECED
            AND A.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
            AND PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL(+)
            AND A.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
            AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                               FROM REFOREG
                              WHERE REFOREG.CDREGIAO = A.CDREGIAO
                                AND REFOREG.CDFORNECED = A.CDFORNECED)
            AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                           FROM PRODCOMP, PRODUTO PR
                          WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                            AND A.CDARVPROD LIKE PR.CDARVPROD || '%'
                            AND A.CDOPERADOR = PRODCOMP.CDOPERADOR)
            AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                               FROM QUALIFICACAO
                              WHERE (A.CDQUALIF   = QUALIFICACAO.CDQUALIF)
                                AND (A.IDFORNAUTO = 'N')
                                AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR
                                    ((A.IDULTIDTVALQ = 'D'   AND TO_DATE(SYSDATE) > A.DTVALQUALIF) OR
                                    (A.IDULTIDTVALQ = 'M'    AND TO_DATE(SYSDATE) > LAST_DAY(A.DTVALQUALIF)))))
            AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                               FROM QFOMARPROD
                              WHERE (QFOMARPROD.CDPRODUTO    = A.CDPRODUTO) AND
                                    (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)) AND
                                    ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N')   OR
                                    ((QFOMARPROD.IDAPRMARPRO = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                      TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                                    (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
            AND EXISTS ( SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                           FROM QFOMARPROD
                          WHERE QFOMARPROD.CDPRODUTO = A.CDPRODUTO
                            AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                          UNION
                         SELECT PARASUPRI.CDMARCA
                           FROM PARASUPRI
                          WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                            AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
            AND NOT EXISTS ( SELECT QFOPRODFORN.CDPRODUTO /* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                               FROM QFOPRODFORN
                              WHERE (QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)
                                AND (QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED)
                                AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR
                                    ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                    ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                      TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                                      (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                       TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
            AND EXISTS ( SELECT 1
                           FROM MARCFORNPEDCOL
                          WHERE MARCFORNPEDCOL.CDFORNECED = A.CDFORNECED
                            AND MARCFORNPEDCOL.CDMARCA    = A.CDMARCA
                          UNION ALL
                         SELECT 1
                           FROM DUAL
                          WHERE NOT EXISTS (SELECT 1
                                              FROM MARCFORNPEDCOL
                                             WHERE MARCFORNPEDCOL.CDFORNECED = A.CDFORNECED))
          GROUP BY A.CDFORNECED, A.IDTPIJURFORN, A.NRINSJURFORN, A.NMRAZSOCFORN, A.IDTPFRETFORN,
                   A.NMREGIAO, A.CDMARCA, A.CDPRODESTO, A.CDOPERADOR, A.CDARVPROD, A.SGUNIDADE,
                   A.NMPRODUTO, A.NMFANTFORN, A.QTACOMPRAR, A.CDREGIAO, A.CDPRODUTO, A.NMOPERADOR,
                   A.NMMARCA, A.CDMARCAPADR;

   BEGIN
      FOR CONTADOR IN PED_COL_COTACAO LOOP
         V_PIPE.EXTEND;
         V_PIPE(V_INDICE) := CONTADOR;
         PIPE ROW(V_PIPE(V_INDICE));
         V_INDICE := V_INDICE+1;
      END LOOP;
      RETURN;
   END PED_COL_COTACAO;

   FUNCTION PED_COL_COTAFORN( P_CDCOMPRADOR   VARCHAR2,
                              P_CDFILIAL      VARCHAR2,
                              P_CDPRODINI     VARCHAR2,
                              P_CDPRODFIN     VARCHAR2,
                              P_TPRODUTO      VARCHAR2,
                              P_CDFORNECED    VARCHAR2,
                              P_CDREGIAO      VARCHAR2,
                              P_CDMARCA       VARCHAR2,
                              P_CDFILIPROC    VARCHAR2,
                              P_NRCOLEPRECO   VARCHAR2,
                              P_DTINI         DATE,
                              P_DTFIN         DATE) RETURN TABELA PIPELINED IS

      V_PIPE TABELA := TABELA();
      V_INDICE NUMBER := 1;

      CURSOR PED_COL_COTAFORN IS
         SELECT A.CDREGIAO, A.NMREGIAO, A.CDOPERADOR, A.NMOPERADOR, A.CDFORNECED, A.NRINSJURFORN,
                A.IDTPIJURFORN, A.NMRAZSOCFORN, A.NMFANTFORN, A.CDPRODUTO, A.NMPRODUTO, A.SGUNIDADE,
                A.CDPRODESTO, A.IDTPFRETFORN, A.CDMARCA, A.NMMARCA, A.CDMARCAPADR, A.CDARVPROD,
                A.QTACOMPRAR, ' ' AS NRCOMPRA
           FROM ( SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, FORNECEDOR.DTVALQUALIF, FORNECEDOR.IDFORNAUTO, FORNECEDOR.CDQUALIF,
                         PARASUPRI.IDULTIDTVALQ, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR,
                         REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR, REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                         MARCA.CDMARCA AS CDMARCAPADR, ' ' AS NRCOMPRA
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, FILIAL FILI,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 )REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 )OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN, DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(P_CDFORNECED, CDFORNECED) <> 0  )FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COLETAPR.CDFILIAL    = P_CDFILIAL
                     AND COLETAPR.NRCOLEPRECO = P_NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR  = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL    = P_CDFILIAL
                     AND ITEMCOLE.NRCOLEPRECO = P_NRCOLEPRECO
                     AND (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA  = 'A'
                     AND NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S'
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA  = 'A'
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND EXISTS (SELECT 1
                                   FROM MARCFORNPEDCOL
                                  WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                    AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                  UNION ALL
                                 SELECT 1
                                   FROM DUAL
                                  WHERE NOT EXISTS (SELECT 1
                                                      FROM MARCFORNPEDCOL
                                                     WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))
                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN, FORNECEDOR.IDTPFRETFORN,
                         FORNECEDOR.DTVALQUALIF, FORNECEDOR.IDFORNAUTO, FORNECEDOR.CDQUALIF, PARASUPRI.IDULTIDTVALQ, REGIAO.NMREGIAO, MARCA.CDMARCA,
                         PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR, PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN,
                         NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR, ' ' AS NRCOMPRA
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 )REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 )OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN, DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(P_CDFORNECED, CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COLETAPR.CDFILIAL    = P_CDFILIAL
                     AND COLETAPR.NRCOLEPRECO = P_NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR  = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL    = P_CDFILIAL
                     AND ITEMCOLE.NRCOLEPRECO = P_NRCOLEPRECO
                     AND (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA  = 'A'
                     AND (NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S')
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND PARAMPRODSUP.CDPRODUTO = ITEMCOLE.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = ITEMCOLE.CDREGIAO
                     AND EXISTS ( SELECT 1
                                    FROM MARCFORNPEDCOL
                                   WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                     AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                   UNION ALL
                                  SELECT 1
                                    FROM DUAL
                                   WHERE NOT EXISTS ( SELECT 1
                                                        FROM MARCFORNPEDCOL
                                                       WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))

                  /*################################## IDCONSPRSOL DA PARASUPRI #############################################*/
                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, FORNECEDOR.DTVALQUALIF, FORNECEDOR.IDFORNAUTO, FORNECEDOR.CDQUALIF, PARASUPRI.IDULTIDTVALQ,
                         REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR, PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE,
                         PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO,
                         OPERADOR.NMOPERADOR, REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR,
                         ' ' AS NRCOMPRA
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, FILIAL FILI,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN, DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(P_CDFORNECED, CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COLETAPR.CDFILIAL    = P_CDFILIAL
                     AND COLETAPR.NRCOLEPRECO = P_NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR  = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL    = P_CDFILIAL
                     AND ITEMCOLE.NRCOLEPRECO = P_NRCOLEPRECO
                     AND (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA  = 'A'
                     AND NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S'
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND EXISTS ( SELECT 1
                                    FROM MARCFORNPEDCOL
                                   WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                     AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                   UNION ALL
                                  SELECT 1
                                    FROM DUAL
                                   WHERE NOT EXISTS (SELECT 1
                                                       FROM MARCFORNPEDCOL
                                                      WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))

                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN, FORNECEDOR.IDTPFRETFORN,
                         FORNECEDOR.DTVALQUALIF, FORNECEDOR.IDFORNAUTO, FORNECEDOR.CDQUALIF, PARASUPRI.IDULTIDTVALQ, REGIAO.NMREGIAO, MARCA.CDMARCA,
                         PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR, PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN,
                         NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR, ' ' AS NRCOMPRA
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN, DTVALQUALIF, IDFORNAUTO,
                                  CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(P_CDFORNECED, CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COLETAPR.CDFILIAL    = P_CDFILIAL
                     AND COLETAPR.NRCOLEPRECO = P_NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR  = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL    = P_CDFILIAL
                     AND ITEMCOLE.NRCOLEPRECO = P_NRCOLEPRECO
                     AND (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA  = 'A'
                     AND NVL(PRODUTO.IDPRODATIVPR, 'N') =  'S'
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND PARAMPRODSUP.CDPRODUTO = ITEMCOLE.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = ITEMCOLE.CDREGIAO
                     AND EXISTS ( SELECT 1
                                    FROM MARCFORNPEDCOL
                                   WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                     AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                   UNION ALL
                                  SELECT 1
                                    FROM DUAL
                                   WHERE NOT EXISTS ( SELECT 1
                                                        FROM MARCFORNPEDCOL
                                                       WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))

                ) A, PARASUPRI, PRODFORNCOMP LEFT JOIN MARCPRODCOMP
                                                    ON PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL
          WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
            AND NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL
            AND INSTR(NVL(P_CDMARCA, MARCPRODCOMP.CDMARCA), MARCPRODCOMP.CDMARCA) <> 0
            AND A.CDFORNECED = PRODFORNCOMP.CDFORNECED
            AND A.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
            AND A.CDMARCA = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
            AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                               FROM REFOREG
                              WHERE REFOREG.CDREGIAO = A.CDREGIAO
                                AND REFOREG.CDFORNECED = A.CDFORNECED )
            AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                           FROM PRODCOMP, PRODUTO PR
                          WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                            AND A.CDARVPROD LIKE PR.CDARVPROD || '%'
                            AND A.CDOPERADOR = PRODCOMP.CDOPERADOR)
            AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                               FROM QUALIFICACAO
                              WHERE A.CDQUALIF   = QUALIFICACAO.CDQUALIF
                                AND A.IDFORNAUTO = 'N'
                                AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((A.IDULTIDTVALQ = 'D' AND
                                                                           TO_DATE(SYSDATE) > A.DTVALQUALIF) OR (A.IDULTIDTVALQ = 'M' AND
                                                                                                                 TO_DATE(SYSDATE) > LAST_DAY(A.DTVALQUALIF)))))
            AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                               FROM QFOMARPROD
                              WHERE QFOMARPROD.CDPRODUTO     = A.CDPRODUTO
                                AND QFOMARPROD.CDMARCA       = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND
                                      QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND
                                                                        ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                          TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                                                                   TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
            AND EXISTS (SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                          FROM QFOMARPROD
                         WHERE QFOMARPROD.CDPRODUTO = A.CDPRODUTO
                           AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                         UNION
                        SELECT PARASUPRI.CDMARCA
                          FROM PARASUPRI
                         WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                           AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
            AND NOT EXISTS ( SELECT QFOPRODFORN.CDPRODUTO /* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                               FROM QFOPRODFORN
                              WHERE QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                                AND QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED
                                AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND
                                      QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                                                         ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                                           TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                                                                                                     TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
            AND EXISTS ( SELECT 1
                           FROM MARCFORNPEDCOL
                          WHERE MARCFORNPEDCOL.CDFORNECED = A.CDFORNECED
                            AND MARCFORNPEDCOL.CDMARCA    = A.CDMARCA
                          UNION ALL
                         SELECT 1
                           FROM DUAL
                          WHERE NOT EXISTS (SELECT 1
                                              FROM MARCFORNPEDCOL
                                             WHERE MARCFORNPEDCOL.CDFORNECED = A.CDFORNECED))
          GROUP BY A.CDFORNECED, A.IDTPIJURFORN, A.NRINSJURFORN, A.NMRAZSOCFORN, A.IDTPFRETFORN, A.NMREGIAO, A.CDMARCA, A.CDPRODESTO,
                A.CDOPERADOR, A.CDARVPROD, A.SGUNIDADE, A.NMPRODUTO, A.NMFANTFORN, A.QTACOMPRAR, A.CDREGIAO, A.CDPRODUTO, A.NMOPERADOR,
                A.NMMARCA, A.CDMARCAPADR;
   BEGIN
      FOR CONTADOR IN PED_COL_COTAFORN LOOP
         V_PIPE.EXTEND;
         V_PIPE(V_INDICE) := CONTADOR;
         PIPE ROW(V_PIPE(V_INDICE));
         V_INDICE := V_INDICE+1;
      END LOOP;
      RETURN;
   END PED_COL_COTAFORN;

   FUNCTION PED_COL_GERALISTPREC( P_CDCOMPRADOR   VARCHAR2,
                                  P_CDFILIAL      VARCHAR2,
                                  P_CDPRODINI     VARCHAR2,
                                  P_CDPRODFIN     VARCHAR2,
                                  P_TPRODUTO      VARCHAR2,
                                  P_CDFORNECED    VARCHAR2,
                                  P_CDREGIAO      VARCHAR2,
                                  P_CDMARCA       VARCHAR2,
                                  P_CDFILIPROC    VARCHAR2,
                                  P_NRSEQPRELIST  VARCHAR2,
                                  P_DTINI         DATE,
                                  P_DTFIN         DATE) RETURN TABELA PIPELINED IS

      V_PIPE TABELA := TABELA();
      V_INDICE NUMBER := 1;

      CURSOR PED_COL_GERALISTPREC IS
         SELECT CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
                IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
                CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD, SUM(QTACOMPRAR) AS QTACOMPRAR,
                NRCOLEPRECO AS NRCOMPRA
           FROM ( SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, ITEMCOLE.NRCOLEPRECO,
                         NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, MARCPRODCOMP, FILIAL FILI,
                         ( SELECT COMP.CDREGIAO, COMP.CDPRODUTO, ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) AS QTACOMPRAR
                             FROM ( SELECT FILIAL.CDREGIAO, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO, ESTOQUE.VRFATOCONV,
                                           SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV/ESTOQUE.VRFATOCONV) AS QTDECOMP
                                      FROM PRODUTO ESTOQUE, ITEMSOLI, FILIAL, PRODUTO
                                     WHERE ITEMSOLI.CDFILSOLI = FILIAL.CDFILIAL
                                       AND ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND PRODUTO.CDPRODESTO = ESTOQUE.CDPRODESTO
                                       AND ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN
                                       AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                                       AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                                       AND ITEMSOLI.IDITMCONS = 'N'
                                       AND NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S'
                                     GROUP BY FILIAL.CDREGIAO, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO, ESTOQUE.VRFATOCONV) COMP,
                                  ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMAUTF, AUTOFORNE, FILIAL, PRODUTO
                                     WHERE AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                       AND AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                       AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN
                                       AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                                       AND AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND AUTOFORNE.IDAFFORALIM = 'N'
                                       AND AUTOFORNE.IDAUTOFORNEX = 'N'
                                       AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO) JACOMP
                            WHERE COMP.CDREGIAO = JACOMP.CDREGIAO(+)
                              AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                              AND COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0) > 0) PRODACOMPRAR,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COLETAPR.CDFILIAL     = ITEMCOLE.CDFILIAL
                     AND COLETAPR.NRCOLEPRECO  = ITEMCOLE.NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR   = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL     = P_CDFILIAL
                     AND ITEMCOLE.NRSEQPRELIST = P_NRSEQPRELIST
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND ITEMCOLE.CDREGIAO = PRODACOMPRAR.CDREGIAO(+)
                     AND ITEMCOLE.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDPRODUTO  = MARCPRODCOMP.CDPRMARCOMPL
                     AND ITEMCOLE.CDMARCA    = MARCPRODCOMP.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND MARCPRODCOMP.CDMARCA = MARCA.CDMARCA
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     
                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, ITEMCOLE.NRCOLEPRECO,
                         NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, MARCPRODCOMP,
                         ( SELECT COMP.CDREGIAO, COMP.CDPRODUTO, ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) AS QTACOMPRAR
                             FROM ( SELECT FILIAL.CDREGIAO, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO, ESTOQUE.VRFATOCONV,
                                           SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV/ESTOQUE.VRFATOCONV) AS QTDECOMP
                                      FROM PRODUTO ESTOQUE, ITEMSOLI, FILIAL, PRODUTO
                                     WHERE ITEMSOLI.CDFILSOLI = FILIAL.CDFILIAL
                                       AND ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND PRODUTO.CDPRODESTO = ESTOQUE.CDPRODESTO
                                       AND ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN
                                       AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                                       AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                                       AND ITEMSOLI.IDITMCONS = 'N'
                                       AND NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S'
                                     GROUP BY FILIAL.CDREGIAO, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO, ESTOQUE.VRFATOCONV) COMP,
                                  ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMAUTF, AUTOFORNE, FILIAL, PRODUTO
                                     WHERE AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                       AND AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                       AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN
                                       AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                                       AND AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND AUTOFORNE.IDAFFORALIM = 'N'
                                       AND AUTOFORNE.IDAUTOFORNEX = 'N'
                                       AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO) JACOMP
                            WHERE COMP.CDREGIAO = JACOMP.CDREGIAO (+)
                              AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                              AND COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0) > 0) PRODACOMPRAR,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COLETAPR.CDFILIAL     = ITEMCOLE.CDFILIAL
                     AND COLETAPR.NRCOLEPRECO  = ITEMCOLE.NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR   = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL     = P_CDFILIAL
                     AND ITEMCOLE.NRSEQPRELIST = P_NRSEQPRELIST
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND ITEMCOLE.CDREGIAO = PRODACOMPRAR.CDREGIAO(+)
                     AND ITEMCOLE.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDPRODUTO  = MARCPRODCOMP.CDPRMARCOMPL
                     AND ITEMCOLE.CDMARCA    = MARCPRODCOMP.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND MARCPRODCOMP.CDMARCA = MARCA.CDMARCA
                     AND PARAMPRODSUP.CDPRODUTO = ITEMCOLE.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = ITEMCOLE.CDREGIAO

                  /*################################## IDCONSPRSOL DA PARASUPRI #############################################*/

                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, ITEMCOLE.NRCOLEPRECO,
                         NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, MARCPRODCOMP, FILIAL FILI,
                         ( SELECT COMP.CDREGIAO, COMP.CDPRODUTO, ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                             FROM ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV,
                                           SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMSOLI, FILIAL, PRODUTO
                                     WHERE ITEMSOLI.CDFILSOLI = FILIAL.CDFILIAL
                                       AND ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN
                                       AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                                       AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                                       AND ITEMSOLI.IDITMCONS = 'N'
                                       AND NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV) COMP,
                                  ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMAUTF, AUTOFORNE, FILIAL, PRODUTO
                                     WHERE AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                       AND AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                       AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN
                                       AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                                       AND AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND AUTOFORNE.IDAFFORALIM = 'N'
                                       AND AUTOFORNE.IDAUTOFORNEX = 'N'
                                       AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO) JACOMP
                            WHERE COMP.CDREGIAO = JACOMP.CDREGIAO (+)
                              AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                              AND ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0) PRODACOMPRAR,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COLETAPR.CDFILIAL     = ITEMCOLE.CDFILIAL
                     AND COLETAPR.NRCOLEPRECO  = ITEMCOLE.NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR   = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL     = P_CDFILIAL
                     AND ITEMCOLE.NRSEQPRELIST = P_NRSEQPRELIST
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND ITEMCOLE.CDREGIAO = PRODACOMPRAR.CDREGIAO(+)
                     AND ITEMCOLE.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDPRODUTO  = MARCPRODCOMP.CDPRMARCOMPL
                     AND ITEMCOLE.CDMARCA    = MARCPRODCOMP.CDMARCA
                     AND MARCPRODCOMP.CDMARCA = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))

                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, ITEMCOLE.NRCOLEPRECO,
                         NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, MARCPRODCOMP,
                         ( SELECT COMP.CDREGIAO, COMP.CDPRODUTO, ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                             FROM ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV,
                                           SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMSOLI, FILIAL, PRODUTO
                                     WHERE ITEMSOLI.CDFILSOLI = FILIAL.CDFILIAL
                                       AND ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND ITEMSOLI.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN
                                       AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                                       AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                                       AND ITEMSOLI.IDITMCONS = 'N'
                                       AND NVL(ITEMSOLI.IDSOLIAPROV,'S') = 'S'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV) COMP,
                                  ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMAUTF, AUTOFORNE, FILIAL, PRODUTO
                                     WHERE AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                       AND AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                       AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN
                                       AND INSTR(NVL(P_CDREGIAO, FILIAL.CDREGIAO), FILIAL.CDREGIAO) <> 0
                                       AND AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND AUTOFORNE.IDAFFORALIM = 'N'
                                       AND AUTOFORNE.IDAUTOFORNEX = 'N'
                                       AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO) JACOMP
                            WHERE COMP.CDREGIAO = JACOMP.CDREGIAO (+)
                              AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                              AND ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0) PRODACOMPRAR,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COLETAPR.CDFILIAL     = ITEMCOLE.CDFILIAL
                     AND COLETAPR.NRCOLEPRECO  = ITEMCOLE.NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR   = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL     = P_CDFILIAL
                     AND ITEMCOLE.NRSEQPRELIST = P_NRSEQPRELIST
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND ITEMCOLE.CDREGIAO = PRODACOMPRAR.CDREGIAO(+)
                     AND ITEMCOLE.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDPRODUTO  = MARCPRODCOMP.CDPRMARCOMPL
                     AND ITEMCOLE.CDMARCA    = MARCPRODCOMP.CDMARCA
                     AND MARCPRODCOMP.CDMARCA = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND PARAMPRODSUP.CDPRODUTO = ITEMCOLE.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = ITEMCOLE.CDREGIAO) A
                GROUP BY CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
            IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
            CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD, NRCOLEPRECO;

   BEGIN
      FOR CONTADOR IN PED_COL_GERALISTPREC LOOP
         V_PIPE.EXTEND;
         V_PIPE(V_INDICE) := CONTADOR;
         PIPE ROW(V_PIPE(V_INDICE));
         V_INDICE := V_INDICE+1;
      END LOOP;
      RETURN;
   END PED_COL_GERALISTPREC;

   FUNCTION PED_COL_LISTAPREC( P_CDCOMPRADOR   VARCHAR2,
                               P_CDFILIAL      VARCHAR2,
                               P_CDPRODINI     VARCHAR2,
                               P_CDPRODFIN     VARCHAR2,
                               P_TPRODUTO      VARCHAR2,
                               P_CDFORNECED    VARCHAR2,
                               P_CDREGIAO      VARCHAR2,
                               P_CDMARCA       VARCHAR2,
                               P_CDFILIPROC    VARCHAR2,
                               P_NRSEQPRELIST  VARCHAR2,
                               P_DTINI         DATE,
                               P_DTFIN         DATE) RETURN TABELA PIPELINED IS

      V_PIPE TABELA := TABELA();
      V_INDICE NUMBER := 1;

      CURSOR PED_COL_LISTAPREC IS
         SELECT CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
                IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
                CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD, SUM(QTACOMPRAR) AS QTACOMPRAR,
                ' ' AS NRCOMPRA
           FROM ( SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN,
                         NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, FILIAL FILI,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN, DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         PRODFORNCOMP LEFT JOIN MARCPRODCOMP
                                             ON PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COLETAPR.CDFILIAL     = ITEMCOLE.CDFILIAL
                     AND COLETAPR.NRCOLEPRECO  = ITEMCOLE.NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR   = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL     = P_CDFILIAL
                     AND ITEMCOLE.NRSEQPRELIST = P_NRSEQPRELIST
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                        FROM REFOREG
                                       WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                         AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                     AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                    FROM PRODCOMP, PRODUTO PR
                                   WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                     AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                     AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                     AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                                        FROM QUALIFICACAO
                                       WHERE (FORNECEDOR.CDQUALIF   = QUALIFICACAO.CDQUALIF)
                                         AND (FORNECEDOR.IDFORNAUTO = 'N')
                                         AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR
                                              ((PARASUPRI.IDULTIDTVALQ = 'D'   AND TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF) OR
                                              (PARASUPRI.IDULTIDTVALQ = 'M'    AND TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                     AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                                        FROM QFOMARPROD
                                       WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO) AND
                                             (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))     AND
                                             ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N')   OR
                                             ((QFOMARPROD.IDAPRMARPRO = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                               TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                                             (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                     AND EXISTS ( SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                                    FROM QFOMARPROD
                                   WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                     AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                   UNION
                                  SELECT PARASUPRI.CDMARCA
                                    FROM PARASUPRI
                                   WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                     AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                     AND NOT EXISTS (SELECT QFOPRODFORN.CDPRODUTO/* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                                       FROM QFOPRODFORN
                                      WHERE (QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)
                                        AND (QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED)
                                        AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR
                                             ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                               ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                  TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                                                 (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                  TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                     AND EXISTS ( SELECT 1
                                    FROM MARCFORNPEDCOL
                                   WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                     AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                   UNION ALL
                                  SELECT 1
                                    FROM DUAL
                                   WHERE NOT EXISTS (SELECT 1
                                                       FROM MARCFORNPEDCOL
                                                      WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))


                  UNION ALL
                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN,
                         NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN,
                                  DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP,
                         PRODFORNCOMP LEFT JOIN MARCPRODCOMP
                                             ON PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COLETAPR.CDFILIAL     = ITEMCOLE.CDFILIAL
                     AND COLETAPR.NRCOLEPRECO  = ITEMCOLE.NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR   = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL     = P_CDFILIAL
                     AND ITEMCOLE.NRSEQPRELIST = P_NRSEQPRELIST
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND PARAMPRODSUP.CDPRODUTO = ITEMCOLE.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = ITEMCOLE.CDREGIAO
                     AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                        FROM REFOREG
                                       WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                         AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED )
                     AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                    FROM PRODCOMP, PRODUTO PR
                                   WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                     AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                     AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                     AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                                        FROM QUALIFICACAO
                                       WHERE (FORNECEDOR.CDQUALIF   = QUALIFICACAO.CDQUALIF)
                                         AND (FORNECEDOR.IDFORNAUTO = 'N')
                                         AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR
                                             ((PARASUPRI.IDULTIDTVALQ = 'D'   AND TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF) OR
                                             (PARASUPRI.IDULTIDTVALQ = 'M'    AND TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                     AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                                        FROM QFOMARPROD
                                       WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO) AND
                                             (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))     AND
                                             ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N')   OR
                                             ((QFOMARPROD.IDAPRMARPRO = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                               TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                                             (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                     AND EXISTS ( SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                                    FROM QFOMARPROD
                                   WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                     AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                   UNION
                                  SELECT PARASUPRI.CDMARCA
                                    FROM PARASUPRI
                                   WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                     AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                     AND NOT EXISTS ( SELECT QFOPRODFORN.CDPRODUTO /* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                                        FROM QFOPRODFORN
                                       WHERE QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                                         AND QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED
                                         AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR
                                             ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                               ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                  TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                                                 (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                  TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                     AND EXISTS ( SELECT 1
                                    FROM MARCFORNPEDCOL
                                   WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                     AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                   UNION ALL
                                  SELECT 1
                                    FROM DUAL
                                   WHERE NOT EXISTS (SELECT 1
                                                       FROM MARCFORNPEDCOL
                                                      WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))

                  /*################################## IDCONSPRSOL DA PARASUPRI #############################################*/
                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN,
                         NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO, FILIAL FILI,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN, DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         PRODFORNCOMP LEFT JOIN MARCPRODCOMP
                                             ON PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COLETAPR.CDFILIAL     = ITEMCOLE.CDFILIAL
                     AND COLETAPR.NRCOLEPRECO  = ITEMCOLE.NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR   = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL     = P_CDFILIAL
                     AND ITEMCOLE.NRSEQPRELIST = P_NRSEQPRELIST
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND FILI.CDFILIAL = P_CDFILIPROC
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                        FROM REFOREG
                                       WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                         AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED )
                     AND EXISTS ( SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                    FROM PRODCOMP, PRODUTO PR
                                   WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                     AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                     AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                     AND NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                                        FROM QUALIFICACAO
                                       WHERE (FORNECEDOR.CDQUALIF   = QUALIFICACAO.CDQUALIF)
                                         AND (FORNECEDOR.IDFORNAUTO = 'N')
                                         AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR
                                             ((PARASUPRI.IDULTIDTVALQ = 'D'   AND TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF) OR
                                             (PARASUPRI.IDULTIDTVALQ = 'M'    AND TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                     AND NOT EXISTS ( SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                                        FROM QFOMARPROD
                                       WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO) AND
                                             (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))     AND
                                             ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N')   OR
                                             ((QFOMARPROD.IDAPRMARPRO = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                               TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                                             (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                     AND EXISTS ( SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                                    FROM QFOMARPROD
                                   WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                     AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                   UNION
                                  SELECT PARASUPRI.CDMARCA
                                    FROM PARASUPRI
                                   WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                     AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                     AND NOT EXISTS ( SELECT QFOPRODFORN.CDPRODUTO /* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                                        FROM QFOPRODFORN
                                       WHERE QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                                         AND QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED
                                         AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR
                                             ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                               ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                  TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                                                 (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                  TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                     AND EXISTS ( SELECT 1
                                    FROM MARCFORNPEDCOL
                                   WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                     AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                   UNION ALL
                                  SELECT 1
                                    FROM DUAL
                                   WHERE NOT EXISTS (SELECT 1
                                                       FROM MARCFORNPEDCOL
                                                      WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED))

                  UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJuRFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN,
                         NVL(ITEMCOLE.QTACMPITMCOL, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR
                    FROM PARASUPRI, COLETAPR, ITEMCOLE, PRODUTO,
                         ( SELECT CDREGIAO, NMREGIAO
                             FROM REGIAO
                            WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0 ) REGIAO,
                         ( SELECT CDOPERADOR, NMOPERADOR
                             FROM OPERADOR
                            WHERE INSTR(NVL(P_CDCOMPRADOR, OPERADOR.CDOPERADOR), OPERADOR.CDOPERADOR) <> 0 ) OPERADOR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN, DTVALQUALIF, IDFORNAUTO, CDQUALIF
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, MARCA.IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL
                            WHERE FILIAL.CDFILIAL = P_CDFILIPROC
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP,
                         PRODFORNCOMP LEFT JOIN MARCPRODCOMP
                                             ON PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL
                   WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COLETAPR.CDFILIAL     = ITEMCOLE.CDFILIAL
                     AND COLETAPR.NRCOLEPRECO  = ITEMCOLE.NRCOLEPRECO
                     AND COLETAPR.CDOPERADOR   = OPERADOR.CDOPERADOR
                     AND ITEMCOLE.CDFILIAL     = P_CDFILIAL
                     AND ITEMCOLE.NRSEQPRELIST = P_NRSEQPRELIST
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND ITEMCOLE.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND ITEMCOLE.CDREGIAO   = REGIAO.CDREGIAO
                     AND ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND ITEMCOLE.CDMARCA    = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA  = 'A'
                     AND PARAMPRODSUP.CDPRODUTO = ITEMCOLE.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = ITEMCOLE.CDREGIAO
                     AND NOT EXISTS ( SELECT REFOREG.CDREGIAO, REFOREG.CDFORNECED
                                        FROM REFOREG
                                       WHERE REFOREG.CDREGIAO = REGIAO.CDREGIAO
                                         AND REFOREG.CDFORNECED = FORNECEDOR.CDFORNECED)
                     AND EXISTS (SELECT PRODCOMP.CDPRODUTO, PRODCOMP.CDOPERADOR
                                   FROM PRODCOMP, PRODUTO PR
                                  WHERE PRODCOMP.CDPRODUTO = PR.CDPRODUTO
                                    AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                                    AND OPERADOR.CDOPERADOR = PRODCOMP.CDOPERADOR)
                     AND NOT EXISTS (SELECT QUALIFICACAO.CDQUALIF   /* QUALIFICACAO DO FORNECEDOR */
                                       FROM QUALIFICACAO
                                      WHERE (FORNECEDOR.CDQUALIF   = QUALIFICACAO.CDQUALIF)
                                        AND (FORNECEDOR.IDFORNAUTO = 'N')
                                        AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR
                                            ((PARASUPRI.IDULTIDTVALQ = 'D'   AND TO_DATE(SYSDATE) > FORNECEDOR.DTVALQUALIF) OR
                                            (PARASUPRI.IDULTIDTVALQ = 'M'    AND TO_DATE(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))
                     AND NOT EXISTS (SELECT QFOMARPROD.CDMARCA   /* QUALIFICACAO DE PRODUTO/MARCA */
                                       FROM QFOMARPROD
                                      WHERE (QFOMARPROD.CDPRODUTO    = PRODUTO.CDPRODUTO) AND
                                            (QFOMARPROD.CDMARCA      = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA))     AND
                                            ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N')   OR
                                            ((QFOMARPROD.IDAPRMARPRO = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                              TO_DATE(SYSDATE) > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                                            (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) > QFOMARPROD.DTVALAPROVA)))))
                     AND EXISTS (SELECT QFOMARPROD.CDMARCA /* QUALIFICACAO DE PRODUTO/MARCA */
                                   FROM QFOMARPROD
                                  WHERE QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO
                                    AND QFOMARPROD.CDMARCA   = NVL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA)
                                  UNION
                                 SELECT PARASUPRI.CDMARCA
                                   FROM PARASUPRI
                                  WHERE PARASUPRI.CDFILIAL    = P_CDFILIAL
                                    AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))
                     AND NOT EXISTS (SELECT QFOPRODFORN.CDPRODUTO /* QUALIFICACAO DE PRODUTO/FORNECEDOR */
                                       FROM QFOPRODFORN
                                      WHERE QFOPRODFORN.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                                        AND QFOPRODFORN.CDFORNECED= PRODFORNCOMP.CDFORNECED
                                        AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR
                                            ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                                              ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                                                 TO_DATE(SYSDATE) > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                                                (PARASUPRI.IDULTIDTVALQ = 'D' AND
                                                 TO_DATE(SYSDATE) > QFOPRODFORN.DTVALPRFORN)))))
                     AND EXISTS (SELECT 1
                                   FROM MARCFORNPEDCOL
                                  WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED
                                    AND MARCFORNPEDCOL.CDMARCA    = MARCA.CDMARCA
                                  UNION ALL
                                 SELECT 1
                                   FROM DUAL
                                  WHERE NOT EXISTS (SELECT 1
                                                      FROM MARCFORNPEDCOL
                                                     WHERE MARCFORNPEDCOL.CDFORNECED = FORNECEDOR.CDFORNECED)))
        GROUP BY CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
              IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
              CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD;

   BEGIN
      FOR CONTADOR IN PED_COL_LISTAPREC LOOP
         V_PIPE.EXTEND;
         V_PIPE(V_INDICE) := CONTADOR;
         PIPE ROW(V_PIPE(V_INDICE));
         V_INDICE := V_INDICE+1;
      END LOOP;
      RETURN;
   END PED_COL_LISTAPREC;

   FUNCTION PED_COMPRA( P_CDPRODINI     VARCHAR2,
                        P_CDPRODFIN     VARCHAR2,
                        P_TPRODUTO      VARCHAR2,
                        P_CDFORNECED    VARCHAR2,
                        P_CDMARCA       VARCHAR2,
                        P_NRCOMPRA      VARCHAR2,
                        P_DTINI         DATE,
                        P_DTFIN         DATE) RETURN TABELA PIPELINED IS

      V_PIPE TABELA := TABELA();
      V_INDICE NUMBER := 1;

      CURSOR PED_COMPRA IS
         SELECT CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
                IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
                CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD, QTACOMPRAR,
                NRCOMPRA
           FROM ( SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN, FORNECEDOR.IDTPFRETFORN,
                         REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR, PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE,
                         PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR, REGIAO.CDREGIAO,
                         PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR, REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                         MARCA.CDMARCA AS CDMARCAPADR, PRODCOMPRA.NRCOMPRA
                    FROM PARASUPRI, COMPRA, PRODCOMPRA, FORPRCOMPRA, PRODUTO, MARCPRODCOMP, FILIAL FILI,
                         ( SELECT COMP.CDREGIAO, COMP.CDPRODUTO, ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                             FROM ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV,
                                           SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM FILIAL, PRODUTO, PRODCOMPRA, REGIAO, ITEMSOLI
                                     WHERE PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                                       AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                                       AND PRODCOMPRA.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND PRODCOMPRA.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN
                                       AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                                       AND PRODCOMPRA.NRCOMPRA = P_NRCOMPRA
                                       AND PRODCOMPRA.CDFILSOLI = ITEMSOLI.CDFILSOLI
                                       AND PRODCOMPRA.CDFILLAN = ITEMSOLI.CDFILLAN
                                       AND PRODCOMPRA.NRSOLICMP = ITEMSOLI.NRSOLICMP
                                       AND PRODCOMPRA.DTPROGENTR = ITEMSOLI.DTPROGENTR
                                       AND PRODCOMPRA.CDPRODUTO = ITEMSOLI.CDPRODUTO
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV) COMP,
                                  ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMAUTF, AUTOFORNE, FILIAL, PRODUTO, PRODCOMPRA, REGIAO
                                     WHERE AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                       AND AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                       AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND PRODCOMPRA.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                                       AND ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN
                                       AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                                       AND AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND AUTOFORNE.IDAFFORALIM = 'N'
                                       AND AUTOFORNE.IDAUTOFORNEX = 'N'
                                       AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO) JACOMP
                            WHERE COMP.CDREGIAO = JACOMP.CDREGIAO (+)
                              AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                              AND ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0) PRODACOMPRAR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         REGIAO, OPERADOR
                   WHERE FILI.CDFILIAL = PRODCOMPRA.CDFILSOLI
                     AND PARASUPRI.CDFILIAL = NVL(FILI.CDFILCENTCMP, FILI.CDFILIAL)
                     AND FILI.CDREGIAO = REGIAO.CDREGIAO
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COMPRA.NRCOMPRA = P_NRCOMPRA
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND COMPRA.CDCOMPRADOR  = OPERADOR.CDOPERADOR
                     AND COMPRA.NRCOMPRA = PRODCOMPRA.NRCOMPRA
                     AND PRODCOMPRA.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND PRODCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND FORPRCOMPRA.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND PRODCOMPRA.CDPRODUTO  = MARCPRODCOMP.CDPRMARCOMPL
                     AND MARCPRODCOMP.CDMARCA = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))
                     AND FORPRCOMPRA.NRCOMPRA = COMPRA.NRCOMPRA

                   UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN,
                         NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR,
                         REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA, MARCA.CDMARCA AS CDMARCAPADR,
                         PRODCOMPRA.NRCOMPRA
                    FROM PARASUPRI, COMPRA, PRODCOMPRA, FORPRCOMPRA, PRODUTO, MARCPRODCOMP, REGIAO, FILIAL, OPERADOR,
                         ( SELECT COMP.CDREGIAO, COMP.CDPRODUTO, ROUND(COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) AS QTACOMPRAR
                             FROM ( SELECT FILIAL.CDREGIAO, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO, ESTOQUE.VRFATOCONV,
                                           SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV/ESTOQUE.VRFATOCONV) AS QTDECOMP
                                      FROM PRODUTO ESTOQUE,  FILIAL, PRODUTO, PRODCOMPRA, REGIAO, ITEMSOLI
                                     WHERE PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                                       AND PRODCOMPRA.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN
                                       AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                                       AND PRODCOMPRA.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND PRODUTO.CDPRODESTO = ESTOQUE.CDPRODESTO
                                       AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                                       AND PRODCOMPRA.CDFILSOLI = ITEMSOLI.CDFILSOLI
                                       AND PRODCOMPRA.CDFILLAN = ITEMSOLI.CDFILLAN
                                       AND PRODCOMPRA.NRSOLICMP = ITEMSOLI.NRSOLICMP
                                       AND PRODCOMPRA.DTPROGENTR = ITEMSOLI.DTPROGENTR
                                       AND PRODCOMPRA.CDPRODUTO = ITEMSOLI.CDPRODUTO
                                     GROUP BY FILIAL.CDREGIAO, ESTOQUE.CDPRODESTO, ESTOQUE.CDPRODUTO, ESTOQUE.VRFATOCONV) COMP,
                                  ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMAUTF, AUTOFORNE, FILIAL, PRODUTO, REGIAO
                                     WHERE AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                       AND AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                       AND ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN
                                       AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                       AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                                       AND AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND AUTOFORNE.IDAFFORALIM = 'N'
                                       AND AUTOFORNE.IDAUTOFORNEX = 'N'
                                       AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO) JACOMP
                            WHERE COMP.CDREGIAO = JACOMP.CDREGIAO (+)
                              AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                              AND COMP.QTDECOMP-NVL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0) > 0)PRODACOMPRAR,

                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL, PRODCOMPRA
                            WHERE PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL, PRODCOMPRA
                            WHERE PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
                   WHERE COMPRA.NRCOMPRA = P_NRCOMPRA
                     AND FILIAL.CDFILIAL = PRODCOMPRA.CDFILSOLI
                     AND PARASUPRI.CDFILIAL = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') <> 'S'
                     AND COMPRA.NRCOMPRA = PRODCOMPRA.NRCOMPRA
                     AND PRODCOMPRA.NRCOMPRA = FORPRCOMPRA.NRCOMPRA
                     AND COMPRA.CDCOMPRADOR  = OPERADOR.CDOPERADOR
                     AND PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                     AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND PRODCOMPRA.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND PRODCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND FORPRCOMPRA.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND PRODCOMPRA.CDPRODUTO  = MARCPRODCOMP.CDPRMARCOMPL
                     AND MARCPRODCOMP.CDMARCA = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND PARAMPRODSUP.CDPRODUTO = PRODCOMPRA.CDPRODUTO

                  /*################################## IDCONSPRSOL DA PARASUPRI #############################################*/

                   UNION ALL
                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN, FORNECEDOR.IDTPFRETFORN,
                         REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR, PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE,
                         PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN, NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR, REGIAO.CDREGIAO,
                         PRODUTO.CDPRODUTO, OPERADOR.NMOPERADOR, REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                         MARCA.CDMARCA AS CDMARCAPADR, PRODCOMPRA.NRCOMPRA
                    FROM PARASUPRI, PRODUTO, MARCPRODCOMP, FILIAL FILI, COMPRA, PRODCOMPRA, FORPRCOMPRA, REGIAO, OPERADOR,
                         ( SELECT COMP.CDREGIAO, COMP.CDPRODUTO, ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                             FROM ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV,
                                           SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM FILIAL, PRODUTO, PRODCOMPRA, REGIAO, ITEMSOLI
                                     WHERE PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                                       AND PRODCOMPRA.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND PRODCOMPRA.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN
                                       AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                                       AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                                       AND PRODCOMPRA.CDFILSOLI = ITEMSOLI.CDFILSOLI
                                       AND PRODCOMPRA.CDFILLAN = ITEMSOLI.CDFILLAN
                                       AND PRODCOMPRA.NRSOLICMP = ITEMSOLI.NRSOLICMP
                                       AND PRODCOMPRA.DTPROGENTR = ITEMSOLI.DTPROGENTR
                                       AND PRODCOMPRA.CDPRODUTO = ITEMSOLI.CDPRODUTO
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV) COMP,
                                  ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMAUTF, AUTOFORNE, FILIAL, PRODUTO, PRODCOMPRA, REGIAO
                                     WHERE AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                       AND AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                       AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN
                                       AND PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                                       AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                                       AND AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND AUTOFORNE.IDAFFORALIM = 'N'
                                       AND AUTOFORNE.IDAUTOFORNEX = 'N'
                                       AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO) JACOMP
                            WHERE COMP.CDREGIAO = JACOMP.CDREGIAO (+)
                              AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                              AND ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0) PRODACOMPRAR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA
                   WHERE FILI.CDFILIAL = PRODCOMPRA.CDFILSOLI
                     AND PARASUPRI.CDFILIAL = NVL(FILI.CDFILCENTCMP, FILI.CDFILIAL)
                     AND FILI.CDREGIAO = REGIAO.CDREGIAO
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COMPRA.NRCOMPRA = P_NRCOMPRA
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND COMPRA.CDCOMPRADOR  = OPERADOR.CDOPERADOR
                     AND COMPRA.NRCOMPRA = PRODCOMPRA.NRCOMPRA
                     AND FORPRCOMPRA.NRCOMPRA = PRODCOMPRA.NRCOMPRA
                     AND PRODCOMPRA.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND PRODCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND FORPRCOMPRA.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND PRODCOMPRA.CDPRODUTO  = MARCPRODCOMP.CDPRMARCOMPL
                     AND MARCPRODCOMP.CDMARCA = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))

                   UNION ALL

                  SELECT FORNECEDOR.CDFORNECED, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMRAZSOCFORN,
                         FORNECEDOR.IDTPFRETFORN, REGIAO.NMREGIAO, MARCA.CDMARCA, PRODUTO.CDPRODESTO, OPERADOR.CDOPERADOR,
                         PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, PRODUTO.NMPRODUTO, FORNECEDOR.NMFANTFORN,
                         NVL(PRODACOMPRAR.QTACOMPRAR, 0) AS QTACOMPRAR, REGIAO.CDREGIAO, PRODUTO.CDPRODUTO,
                         OPERADOR.NMOPERADOR, REPLACE(REPLACE(MARCA.NMMARCA, CHR(13), ''), CHR(10), '') NMMARCA,
                         MARCA.CDMARCA AS CDMARCAPADR, PRODCOMPRA.NRCOMPRA
                    FROM PARASUPRI, COMPRA, PRODCOMPRA, FORPRCOMPRA, PRODUTO, MARCPRODCOMP, REGIAO, OPERADOR, FILIAL,
                         ( SELECT COMP.CDREGIAO, COMP.CDPRODUTO, ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                             FROM ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV,
                                           SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM FILIAL, PRODUTO, PRODCOMPRA, REGIAO, ITEMSOLI
                                     WHERE PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                                       AND PRODCOMPRA.DTPROGENTR BETWEEN P_DTINI AND P_DTFIN
                                       AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                                       AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                                       AND PRODCOMPRA.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND PRODCOMPRA.CDFILSOLI = ITEMSOLI.CDFILSOLI
                                       AND PRODCOMPRA.CDFILLAN = ITEMSOLI.CDFILLAN
                                       AND PRODCOMPRA.NRSOLICMP = ITEMSOLI.NRSOLICMP
                                       AND PRODCOMPRA.DTPROGENTR = ITEMSOLI.DTPROGENTR
                                       AND PRODCOMPRA.CDPRODUTO = ITEMSOLI.CDPRODUTO
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV) COMP,
                                  ( SELECT FILIAL.CDREGIAO, PRODUTO.CDPRODESTO, SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                                      FROM ITEMAUTF, AUTOFORNE, FILIAL, PRODUTO, PRODCOMPRA, REGIAO
                                     WHERE AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                       AND AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL
                                       AND ITEMAUTF.DTENTRITMSOL BETWEEN P_DTINI AND P_DTFIN
                                       AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
                                       AND PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                                       AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                                       AND AUTOFORNE.IDSITUATUAAF IS NULL
                                       AND AUTOFORNE.IDAFFORALIM = 'N'
                                       AND AUTOFORNE.IDAUTOFORNEX = 'N'
                                       AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5'
                                     GROUP BY FILIAL.CDREGIAO, PRODUTO.CDPRODESTO) JACOMP
                            WHERE COMP.CDREGIAO = JACOMP.CDREGIAO (+)
                              AND COMP.CDPRODESTO = JACOMP.CDPRODESTO (+)
                              AND ROUND((COMP.QTDECOMP-NVL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0)PRODACOMPRAR,
                         ( SELECT CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, IDTPFRETFORN
                             FROM FORNECEDOR
                            WHERE INSTR(NVL(P_CDFORNECED, FORNECEDOR.CDFORNECED), FORNECEDOR.CDFORNECED) <> 0 ) FORNECEDOR,
                         ( SELECT CDMARCA, NMMARCA, IDMARCAATIVA
                             FROM MARCA
                            WHERE INSTR(NVL(P_CDMARCA, CDMARCA), CDMARCA) <> 0) MARCA,
                         ( SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL, PRODCOMPRA
                            WHERE PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                              AND FILIAL.IDFUNCAOFILI = 'C'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGCOR = 'S'
                            UNION ALL
                           SELECT PARAMPRODSUP.CDREGIAO, PARAMPRODSUP.CDPRODUTO
                             FROM PARAMPRODSUP, FILIAL, PRODCOMPRA
                            WHERE PRODCOMPRA.CDFILSOLI = FILIAL.CDFILIAL
                              AND FILIAL.IDFUNCAOFILI = 'R'
                              AND FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL
                              AND PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
                   WHERE COMPRA.NRCOMPRA = PRODCOMPRA.NRCOMPRA
                     AND PRODCOMPRA.NRCOMPRA = FORPRCOMPRA.NRCOMPRA
                     AND COMPRA.NRCOMPRA = P_NRCOMPRA
                     AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN
                     AND FILIAL.CDFILIAL = PRODCOMPRA.CDFILSOLI
                     AND PARASUPRI.CDFILIAL = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)
                     AND FILIAL.CDREGIAO = REGIAO.CDREGIAO
                     AND NVL(PARASUPRI.IDCONSPRSOL, 'N') = 'S'
                     AND COMPRA.CDCOMPRADOR  = OPERADOR.CDOPERADOR
                     AND PRODCOMPRA.CDPRODUTO = PRODACOMPRAR.CDPRODUTO(+)
                     AND PRODCOMPRA.CDPRODUTO  = PRODUTO.CDPRODUTO
                     AND FORPRCOMPRA.CDFORNECED = FORNECEDOR.CDFORNECED
                     AND PRODCOMPRA.CDPRODUTO  = MARCPRODCOMP.CDPRMARCOMPL
                     AND MARCPRODCOMP.CDMARCA = MARCA.CDMARCA
                     AND MARCA.IDMARCAATIVA       = 'A'
                     AND PARAMPRODSUP.CDPRODUTO = PRODCOMPRA.CDPRODUTO
                     AND PARAMPRODSUP.CDREGIAO  = FILIAL.CDREGIAO) A
          GROUP BY CDREGIAO, NMREGIAO, CDOPERADOR, NMOPERADOR, CDFORNECED, NRINSJURFORN,
                IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN, CDPRODUTO, NMPRODUTO, SGUNIDADE,
                CDPRODESTO, IDTPFRETFORN, CDMARCA, NMMARCA, CDMARCAPADR, CDARVPROD, QTACOMPRAR, NRCOMPRA;

   BEGIN
      FOR CONTADOR IN PED_COMPRA LOOP
         V_PIPE.EXTEND;
         V_PIPE(V_INDICE) := CONTADOR;
         PIPE ROW(V_PIPE(V_INDICE));
         V_INDICE := V_INDICE+1;
      END LOOP;
      RETURN;
   END PED_COMPRA;

   FUNCTION GETPEDCOLETA( P_IDPEDCOL         IN VARCHAR2,
                          P_NRCOTACAO        IN VARCHAR2,
                          P_COMPRADOR        IN VARCHAR2,
                          P_MARCA            IN VARCHAR2,
                          P_FORNECED         IN VARCHAR2,
                          P_REGIAO           IN VARCHAR2,
                          P_PRODINI          IN VARCHAR2,
                          P_PRODFIN          IN VARCHAR2,
                          P_CDFILIAL         IN VARCHAR2,
                          P_CDFILIPROC       IN VARCHAR2,
                          P_NRCOMPRA         IN VARCHAR2,
                          P_CDLEILAO         IN VARCHAR2,
                          P_NRSEQPRELIST     IN VARCHAR2,
                          P_CDOPERLANC       IN VARCHAR2,
                          P_DESCFORNECEDOR   IN VARCHAR2,
                          P_LISTFORNECEDOR   IN VARCHAR2,
                          P_QTMESES          IN VARCHAR2,
                          P_DTINI            IN DATE,
                          P_DTFIN            IN DATE,
                          P_DTEXPIRAPEDCOL   IN DATE,
                          P_BOPEDEMAIL       IN VARCHAR2,
                          P_IDPEDGERALREG    IN VARCHAR2,
                          P_IDPEDGERALFORN   IN VARCHAR2,
                          P_IDCURVAABCAF     IN VARCHAR2,
                          P_IDENVMERCADUM    IN VARCHAR2,
                          P_BOACRESITEM      IN VARCHAR2,
                          P_IDCONSFORNAF     IN VARCHAR2,
                          P_NRORG         VARCHAR2 DEFAULT '1') RETURN TABELA PIPELINED IS
      V_PIPE TABELA := TABELA();
      V_INDICE NUMBER := 1;

      V_PRODINI      PRODUTO.CDARVPROD%TYPE;
      V_PRODFIN      PRODUTO.CDARVPROD%TYPE;
      V_TPRODUTO     VARCHAR2(1);
      V_IDSISDOS     VARCHAR2(1);
      V_CDMARCA      VARCHAR2(1000);
      V_CDREGIAO     VARCHAR2(1000);
      V_CDFORNECED   VARCHAR2(1000);
      V_DATAINICURVA DATE;
      V_DATAFINCURVA DATE;

      CURSOR C_PEDCOLTODOS IS SELECT CDREGIAO,     NMREGIAO,     CDOPERADOR,   NMOPERADOR,  CDFORNECED,   NRINSJURFORN,
                                     IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN,   CDPRODUTO,   NMPRODUTO,    SGUNIDADE,
                                     CDPRODESTO,   IDTPFRETFORN, CDMARCA,      NMMARCA,     CDMARCAPADR,  CDARVPROD,
                                     QTACOMPRAR,   NRCOMPRA
                                FROM TABLE(PED_COL_TODOS(P_COMPRADOR, P_CDFILIAL, V_PRODINI, V_PRODFIN, V_TPRODUTO, V_CDFORNECED, V_CDREGIAO,
                                                         V_CDMARCA, P_CDFILIPROC, P_DTINI, P_DTFIN))
                               ORDER BY 3,5,1,11;

      CURSOR C_PEDCOLACOMP IS SELECT CDREGIAO,     NMREGIAO,     CDOPERADOR,   NMOPERADOR,  CDFORNECED,   NRINSJURFORN,
                                     IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN,   CDPRODUTO,   NMPRODUTO,    SGUNIDADE,
                                     CDPRODESTO,   IDTPFRETFORN, CDMARCA,      NMMARCA,     CDMARCAPADR,  CDARVPROD,
                                     QTACOMPRAR,   NRCOMPRA
                                FROM TABLE(PED_COL_ACOMP(P_COMPRADOR, P_CDFILIAL, V_PRODINI, V_PRODFIN, V_TPRODUTO, V_CDFORNECED, V_CDREGIAO,
                                                         V_CDMARCA, P_CDFILIPROC, P_DTINI, P_DTFIN))
                               ORDER BY 3,5,1,11;

      CURSOR C_PEDCOMPRA IS SELECT CDREGIAO,     NMREGIAO,     CDOPERADOR,   NMOPERADOR,  CDFORNECED,   NRINSJURFORN,
                                   IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN,   CDPRODUTO,   NMPRODUTO,    SGUNIDADE,
                                   CDPRODESTO,   IDTPFRETFORN, CDMARCA,      NMMARCA,     CDMARCAPADR,  CDARVPROD,
                                   QTACOMPRAR,   NRCOMPRA
                              FROM TABLE(PED_COMPRA(V_PRODINI, V_PRODFIN, V_TPRODUTO, V_CDFORNECED, V_CDMARCA, P_NRCOMPRA, P_DTINI, P_DTFIN))
                             ORDER BY 3,5,1,11;
      CURSOR C_GERALISPREC IS SELECT CDREGIAO,     NMREGIAO,     CDOPERADOR,   NMOPERADOR,  CDFORNECED,   NRINSJURFORN,
                                     IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN,   CDPRODUTO,   NMPRODUTO,    SGUNIDADE,
                                     CDPRODESTO,   IDTPFRETFORN, CDMARCA,      NMMARCA,     CDMARCAPADR,  CDARVPROD,
                                     QTACOMPRAR,   NRCOMPRA 
                                FROM TABLE(PED_COL_GERALISTPREC(P_COMPRADOR, P_CDFILIAL, V_PRODINI, V_PRODFIN, V_TPRODUTO, V_CDFORNECED, 
                                                                V_CDREGIAO, V_CDMARCA, P_CDFILIPROC, P_NRSEQPRELIST, P_DTINI, P_DTFIN))
                               ORDER BY 3,5,1,11;
      CURSOR C_LISTAPREC IS SELECT CDREGIAO,     NMREGIAO,     CDOPERADOR,   NMOPERADOR,  CDFORNECED,   NRINSJURFORN,
                                   IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN,   CDPRODUTO,   NMPRODUTO,    SGUNIDADE,
                                   CDPRODESTO,   IDTPFRETFORN, CDMARCA,      NMMARCA,     CDMARCAPADR,  CDARVPROD,
                                   QTACOMPRAR,   NRCOMPRA 
                              FROM TABLE(PED_COL_LISTAPREC(P_COMPRADOR, P_CDFILIAL, V_PRODINI, V_PRODFIN, V_TPRODUTO, V_CDFORNECED, 
                                                           V_CDREGIAO, V_CDMARCA, P_CDFILIPROC, P_NRSEQPRELIST, P_DTINI, P_DTFIN))
                             ORDER BY 3,5,1,11;
      CURSOR C_COTACAO IS SELECT CDREGIAO,     NMREGIAO,     CDOPERADOR,   NMOPERADOR,  CDFORNECED,   NRINSJURFORN,
                                 IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN,   CDPRODUTO,   NMPRODUTO,    SGUNIDADE,
                                 CDPRODESTO,   IDTPFRETFORN, CDMARCA,      NMMARCA,     CDMARCAPADR,  CDARVPROD,
                                 QTACOMPRAR,   NRCOMPRA 
                            FROM TABLE(PED_COL_COTACAO(P_COMPRADOR, P_CDFILIAL, V_PRODINI, V_PRODFIN, V_TPRODUTO, V_CDFORNECED, 
                                                       V_CDREGIAO, V_CDMARCA, P_CDFILIPROC, P_NRCOTACAO, P_DTINI, P_DTFIN))
                           ORDER BY 3,5,1,11;
      CURSOR C_COTACAOFORN IS SELECT CDREGIAO,     NMREGIAO,     CDOPERADOR,   NMOPERADOR,  CDFORNECED,   NRINSJURFORN,
                                     IDTPIJURFORN, NMRAZSOCFORN, NMFANTFORN,   CDPRODUTO,   NMPRODUTO,    SGUNIDADE,
                                     CDPRODESTO,   IDTPFRETFORN, CDMARCA,      NMMARCA,     CDMARCAPADR,  CDARVPROD,
                                     QTACOMPRAR,   NRCOMPRA 
                                FROM TABLE(PED_COL_COTAFORN(P_COMPRADOR, P_CDFILIAL, V_PRODINI, V_PRODFIN, V_TPRODUTO, V_CDFORNECED, 
                                                            V_CDREGIAO, V_CDMARCA, P_CDFILIPROC, P_NRCOTACAO, P_DTINI, P_DTFIN))
                               ORDER BY 3,5,1,11;
   BEGIN
      IF ((P_PRODINI IS NULL) AND (P_PRODFIN IS NULL)) THEN
         V_PRODINI   := '0';
         V_PRODFIN   := RPAD('Z', 20, 'Z');
         V_TPRODUTO  := 'T';
      ELSE
         V_PRODINI   := P_PRODINI;
         V_PRODFIN   := RPAD(P_PRODFIN, 20, 'Z');
         V_TPRODUTO  := ' ';
      END IF;

      IF P_MARCA = 'T' OR P_MARCA = ' ' THEN
         V_CDMARCA := '';
      ELSE
         V_CDMARCA := P_MARCA;
      END IF;

      IF P_FORNECED = 'T' OR P_FORNECED = ' ' THEN
         V_CDFORNECED := '';
      ELSE
         V_CDFORNECED := P_FORNECED;
      END IF;

      IF P_REGIAO = 'T' OR P_REGIAO = ' ' THEN
         V_CDREGIAO := '';
      ELSE
         V_CDREGIAO := P_REGIAO;
      END IF;

      BEGIN
         SELECT TO_DATE('01/'||TO_CHAR(ADD_MONTHS(SYSDATE, - NVL(P_QTMESES, 1)), 'MM/YYYY'), 'DD/MM/YYYY') AS DTINICIAL,
                LAST_DAY(ADD_MONTHS(SYSDATE, -1)) AS DTFINAL,
                IDSISDOS
           INTO V_DATAINICURVA, V_DATAFINCURVA, V_IDSISDOS
           FROM PARAMGERAL;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_IDSISDOS     := '1';
            V_DATAINICURVA := P_DTINI;
            V_DATAFINCURVA := P_DTFIN;
      END;

      IF P_NRCOMPRA IS NOT NULL THEN
         FOR CONTADOR IN C_PEDCOMPRA LOOP
            V_PIPE.EXTEND;
            V_PIPE(V_INDICE) := CONTADOR;
            PIPE ROW(V_PIPE(V_INDICE));
            V_INDICE := V_INDICE+1;
         END LOOP;
         RETURN;
      ELSE
         IF P_NRSEQPRELIST IS NOT NULL THEN
            IF V_IDSISDOS = '3' THEN
               /*adqGeraListaPrec.SQL;*/
               FOR CONTADOR IN C_GERALISPREC LOOP
                  V_PIPE.EXTEND;
                  V_PIPE(V_INDICE) := CONTADOR;
                  PIPE ROW(V_PIPE(V_INDICE));
                  V_INDICE := V_INDICE+1;
               END LOOP;
               RETURN;
            ELSE
               /*adqListaPrec.SQL;*/ 
               FOR CONTADOR IN C_LISTAPREC LOOP
                  V_PIPE.EXTEND;
                  V_PIPE(V_INDICE) := CONTADOR;
                  PIPE ROW(V_PIPE(V_INDICE));
                  V_INDICE := V_INDICE+1;
               END LOOP;
               RETURN;
            END IF;
         ELSE
            IF P_NRCOTACAO IS NOT NULL THEN
               IF P_DESCFORNECEDOR = 'N' THEN
                  /*adqCotacao.SQL*/ 
                  FOR CONTADOR IN C_COTACAO LOOP
                     V_PIPE.EXTEND;
                     V_PIPE(V_INDICE) := CONTADOR;
                     PIPE ROW(V_PIPE(V_INDICE));
                     V_INDICE := V_INDICE+1;
                  END LOOP;
                  RETURN;
               ELSE
                  /*adqCotacaoForn.SQL*/ 
                  FOR CONTADOR IN C_COTACAOFORN LOOP
                     V_PIPE.EXTEND;
                     V_PIPE(V_INDICE) := CONTADOR;
                     PIPE ROW(V_PIPE(V_INDICE));
                     V_INDICE := V_INDICE+1;
                  END LOOP;
                  RETURN;
               END IF;
            ELSE
               IF P_IDPEDCOL = '0' THEN
                  FOR CONTADOR IN C_PEDCOLTODOS LOOP
                     V_PIPE.EXTEND;
                     V_PIPE(V_INDICE) := CONTADOR;
                     PIPE ROW(V_PIPE(V_INDICE));
                     V_INDICE := V_INDICE+1;
                  END LOOP;
                  RETURN;
               ELSE
                  FOR CONTADOR IN C_PEDCOLACOMP LOOP
                     V_PIPE.EXTEND;
                     V_PIPE(V_INDICE) := CONTADOR;
                     PIPE ROW(V_PIPE(V_INDICE));
                     V_INDICE := V_INDICE+1;
                  END LOOP;
                  RETURN;
               END IF;
            END IF;
         END IF;
      END IF;
   END GETPEDCOLETA;   
   
    FUNCTION SELECT_PEDCOLETA(P_CDFILIAL    IN FILIAL.CDFILIAL%TYPE,
                              P_NRPEDIDOCOL IN PEDCOLETA.NRPEDIDOCOL%TYPE,
                              P_CDFORNECED  IN FORNECEDOR.CDFORNECED%TYPE,
                              P_NRORG       IN PRMARCPEDCOL.NRORG%TYPE) RETURN TAB_PEDCOLETA PIPELINED
    IS
        V_IDORDPLCOT       PARASUPRI.IDORDPLCOT%TYPE;
        V_QTDIASPRAZOEXPED PRAZOFORNEXPEDFILPROD.QTDIASPRAZOEXPED%TYPE;
        V_VRMINFORNREG     PRAZOFORNEXPEDFILPROD.VRMINFORNREG%TYPE;
        V_QTMINFORNREG     PRAZOFORNEXPEDFILPROD.QTMINFORNREG%TYPE;
        
        OUT_RECORD REG_PEDCOLETA;
        
    BEGIN
        BEGIN
            SELECT NVL(IDORDPLCOT, 2)
              INTO V_IDORDPLCOT
              FROM PARASUPRI
             WHERE CDFILIAL = P_CDFILIAL;
        EXCEPTION
            WHEN NO_DATA_FOUND THEN
                V_IDORDPLCOT := 2;
        END;
        
        FOR C_ITENS IN (SELECT PRODUTO.CDARVPROD,
                               PRODUTO.NMPRODUTO,
                               PRODUTO.CDPRODUTO,
                               PRODUTO.CDPRODESTO,
                               PRODUTO.SGUNIDADE,
                               PRODUTO.DSOBSNUTR,
                               PRMARCPEDCOL.IDPRODINCLFOR,
                               PRMARCPEDCOL.CDFILIAL,
                               PRMARCPEDCOL.VRPRECREN,
                               PRMARCPEDCOL.NRPEDIDOCOL,
                               PRMARCPEDCOL.QTDISPPRODMARC,
                               PRMARCPEDCOL.VRPRECUNIPRMARC,
                               PRMARCPEDCOL.VRULTPRECPRMARC,
                               PRMARCPEDCOL.VRPRECOOBJETIVO,
                               PRMARCPEDCOL.IDITPEDPRIONEG,
                               PRMARCPEDCOL.DSOBSRENEGOCIA,
                               PRMARCPEDCOL.NRORG,
                               MARCA.CDMARCA,
                               MARCA.NMMARCA,
                               PRODFORNCOMP.VRPERVARPREPRFO, 
                               PRODFORNCOMP.VRPERVARDESCPRFO, 
                               FORNECEDOR.VRPERVARPREC,
                               FORNECEDOR.VRPERVARDESCPREC,
                               FORNECEDOR.VRMINAUTFOR,
                               FORNECEDOR.QTMINAUTFOT,
                               ITEMPEDCOL.QTPRODPEDCOL,
                               ITEMPEDCOL.IDITEMPEDCOLALT,
                               ITEMPEDCOL.VRPERDESPEDCOL,
                               PEDCOLGERAL.IDRENEGOCIAPCOL
                          FROM PRMARCPEDCOL
                          JOIN PRODUTO     ON PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
                                          AND PRMARCPEDCOL.NRORG = PRODUTO.NRORG
                          JOIN MARCA       ON PRMARCPEDCOL.CDMARCA = MARCA.CDMARCA
                                          AND PRMARCPEDCOL.NRORG = MARCA.NRORG
                          JOIN FORNECEDOR  ON PRMARCPEDCOL.NRORG = FORNECEDOR.NRORG
                                          AND FORNECEDOR.CDFORNECED = P_CDFORNECED
                          JOIN PEDCOLGERAL ON PRMARCPEDCOL.NRPEDIDOCOL = PEDCOLGERAL.NRPEDIDOCOL
                                          AND PRMARCPEDCOL.CDFILIAL = PEDCOLGERAL.CDFILIAL
                                          AND PRMARCPEDCOL.NRORG = PEDCOLGERAL.NRORG
                          LEFT JOIN (SELECT SUM(NVL(QTPRODPEDCOL, 0)) AS QTPRODPEDCOL,
                                            ITEMPEDCOL.VRPERDESPEDCOL,
                                            ITEMPEDCOL.CDFILIAL,
                                            ITEMPEDCOL.CDPRODUTO,
                                            ITEMPEDCOL.CDMARCA,
                                            ITEMPEDCOL.IDITEMPEDCOLALT,
                                            ITEMPEDCOL.NRORG
                                       FROM ITEMPEDCOL
                                      WHERE ITEMPEDCOL.CDFILIAL = P_CDFILIAL
                                        AND ITEMPEDCOL.CDFORNECED = P_CDFORNECED
                                        AND ITEMPEDCOL.NRORG = P_NRORG
                                        AND EXISTS (SELECT 1
                                                      FROM PEDCOLETA
                                                     WHERE PEDCOLETA.CDFILIAL = ITEMPEDCOL.CDFILIAL
                                                       AND PEDCOLETA.NRPEDCOLETA = ITEMPEDCOL.NRPEDCOLETA
                                                       AND PEDCOLETA.CDFORNECED = ITEMPEDCOL.CDFORNECED
                                                       AND PEDCOLETA.CDREGIAO = ITEMPEDCOL.CDREGIAO
                                                       AND PEDCOLETA.NRORG = ITEMPEDCOL.NRORG
                                                       AND PEDCOLETA.CDFILIAL = P_CDFILIAL
                                                       AND PEDCOLETA.NRPEDIDOCOL = P_NRPEDIDOCOL)
                                      GROUP BY ITEMPEDCOL.VRPERDESPEDCOL,
                                               ITEMPEDCOL.CDFILIAL, 
                                               ITEMPEDCOL.CDPRODUTO,
                                               ITEMPEDCOL.CDMARCA,
                                               ITEMPEDCOL.IDITEMPEDCOLALT,
                                               ITEMPEDCOL.NRORG) ITEMPEDCOL 
                            ON PRMARCPEDCOL.CDFILIAL = ITEMPEDCOL.CDFILIAL 
                           AND PRMARCPEDCOL.CDPRODUTO = ITEMPEDCOL.CDPRODUTO
                           AND PRMARCPEDCOL.CDMARCA = ITEMPEDCOL.CDMARCA 
                           AND PRMARCPEDCOL.NRORG = ITEMPEDCOL.NRORG  
                          LEFT JOIN (SELECT CDPRODCOMPL, 
                                            CDFORNECED, 
                                            VRPERVARPREPRFO, 
                                            VRPERVARDESCPRFO, 
                                            NRORG
                                       FROM PRODFORNCOMP
                                      WHERE PRODFORNCOMP.CDFORNECED = P_CDFORNECED) PRODFORNCOMP
                            ON PRMARCPEDCOL.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL
                           AND PRMARCPEDCOL.NRORG = PRODFORNCOMP.NRORG
                         WHERE PRMARCPEDCOL.CDFILIAL = P_CDFILIAL
                           AND PRMARCPEDCOL.NRPEDIDOCOL = P_NRPEDIDOCOL
                           AND PRMARCPEDCOL.NRORG = P_NRORG)
        LOOP
            OUT_RECORD.IDORDPLCOT        := V_IDORDPLCOT;
            OUT_RECORD.IDPRODINCLFOR     := C_ITENS.IDPRODINCLFOR;
			OUT_RECORD.CDFILIAL    		 := C_ITENS.CDFILIAL;			
			OUT_RECORD.VRPRECREN         := NVL(C_ITENS.VRPRECREN, 0); 
			OUT_RECORD.NRPEDIDOCOL       := C_ITENS.NRPEDIDOCOL;
			OUT_RECORD.QTDISPPRODMARC    := NVL(C_ITENS.QTDISPPRODMARC, 0);
			OUT_RECORD.VRPRECUNIPRMARC   := C_ITENS.VRPRECUNIPRMARC;
			OUT_RECORD.VRULTPRECPRMARC   := C_ITENS.VRULTPRECPRMARC;
			OUT_RECORD.VRPRECOOBJETIVO   := C_ITENS.VRPRECOOBJETIVO;
			OUT_RECORD.DSOBSRENEGOCIA    := C_ITENS.DSOBSRENEGOCIA;
			OUT_RECORD.IDITPEDPRIONEG    := C_ITENS.IDITPEDPRIONEG;
			OUT_RECORD.NRORG             := C_ITENS.NRORG;
			OUT_RECORD.CDPRODUTO         := C_ITENS.CDPRODUTO;
			OUT_RECORD.CDARVPROD         := C_ITENS.CDARVPROD;
			OUT_RECORD.CDPRODESTO        := C_ITENS.CDPRODESTO;
			OUT_RECORD.NMPRODUTO         := C_ITENS.NMPRODUTO;
			OUT_RECORD.SGUNIDADE         := C_ITENS.SGUNIDADE;
			OUT_RECORD.DSOBSNUTR         := C_ITENS.DSOBSNUTR;
			OUT_RECORD.CDMARCA           := C_ITENS.CDMARCA;
			OUT_RECORD.NMMARCA           := C_ITENS.NMMARCA;
			OUT_RECORD.VRPERVARPREPRFO   := NVL(C_ITENS.VRPERVARPREPRFO, C_ITENS.VRPERVARPREC);
			OUT_RECORD.VRPERVARDESCPRFO  := NVL(C_ITENS.VRPERVARDESCPRFO, C_ITENS.VRPERVARDESCPREC);
			OUT_RECORD.QTPRODPEDCOL      := C_ITENS.QTPRODPEDCOL;
			OUT_RECORD.IDITEMPEDCOLALT   := C_ITENS.IDITEMPEDCOLALT;
			OUT_RECORD.VRPERDESPEDCOL    := C_ITENS.VRPERDESPEDCOL;
			OUT_RECORD.IDRENEGOCIAPCOL   := C_ITENS.IDRENEGOCIAPCOL;
			
			BEGIN
			    SELECT QTDIASPRAZOEXPED, VRMINFORNREG, QTMINFORNREG
			      INTO V_QTDIASPRAZOEXPED, V_VRMINFORNREG, V_QTMINFORNREG
                  FROM PRAZOFORNEXPEDFILPROD PZ
                  JOIN PRODUTO PR ON PZ.CDPRODUTO = PR.CDPRODUTO
                  JOIN (SELECT MAX(PR.CDARVPROD) CDARVPROD
                          FROM PRAZOFORNEXPEDFILPROD PZ
                          JOIN PRODUTO PR ON PZ.CDPRODUTO = PR.CDPRODUTO
                         WHERE PZ.CDFORNECED = P_CDFORNECED
                           AND PZ.CDFILIAL = P_CDFILIAL
                           AND C_ITENS.CDARVPROD LIKE PR.CDARVPROD || '%') PP 
                    ON PR.CDARVPROD = PP.CDARVPROD
                 WHERE PZ.CDFORNECED = P_CDFORNECED
                   AND PZ.CDFILIAL = P_CDFILIAL;
                
                OUT_RECORD.QTDIASPRAZOEXPED := V_QTDIASPRAZOEXPED;
                OUT_RECORD.VRMINFORNREG     := V_VRMINFORNREG;
                OUT_RECORD.QTMINFORNREG     := V_QTMINFORNREG;
            EXCEPTION
                WHEN NO_DATA_FOUND THEN
                    OUT_RECORD.VRMINFORNREG := C_ITENS.VRMINAUTFOR;
                    OUT_RECORD.QTMINFORNREG := C_ITENS.QTMINAUTFOT;
            END;                                   
			
			PIPE ROW (OUT_RECORD);
        END LOOP;
    END SELECT_PEDCOLETA;
END PEDIDO_COLETA;
/